@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 #include <assets/header.h>
+#include <filter/css.h>
 #include <filter/url.h>
 #include <filter/string.h>
 #include <config/globals.h>
@@ -29,15 +30,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <webserver/request.h>
 #include <database/config/general.h>
 #include <database/config/bible.h>
+#include <database/cache.h>
 
 
-Assets_Header::Assets_Header (string title, void * webserver_request_in)
+Assets_Header::Assets_Header (string title, void * webserver_request)
 {
-  includeJQueryTouch = false;
-  includeTouchCSS = false;
-  includeNotifIt = false;
-  displayNavigator = false;
-  webserver_request = webserver_request_in;
+  m_webserver_request = webserver_request;
   view = new Assets_View ();
   view->set_variable ("title", title);
 }
@@ -77,7 +75,7 @@ void Assets_Header::setNavigator ()
 // Display the user's basic stylesheet.css.
 void Assets_Header::setStylesheet ()
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(m_webserver_request);
   string bible = request->database_config_user()->getBible ();
   string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
   includedStylesheet = stylesheet;
@@ -87,7 +85,7 @@ void Assets_Header::setStylesheet ()
 // Display the user's editor stylesheet.css.
 void Assets_Header::setEditorStylesheet ()
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(m_webserver_request);
   string bible = request->database_config_user()->getBible ();
   string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
   includedEditorStylesheet = stylesheet;
@@ -97,7 +95,7 @@ void Assets_Header::setEditorStylesheet ()
 // Whether to display the topbar.
 bool Assets_Header::displayTopbar ()
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(m_webserver_request);
   // If the topbar is in the query: Don't display the top bar.
   if (request->query.count ("topbar")) {
     return false;
@@ -112,8 +110,9 @@ void Assets_Header::refresh (int seconds, string url)
 {
   string content = convert_to_string (seconds);
   if (!url.empty ()) content.append (";URL=" + url);
-  string headline = "<META HTTP-EQUIV=\"refresh\" CONTENT=\"" + content + "\">";
-  headLines.push_back (headline);
+  stringstream ss;
+  ss << "<META HTTP-EQUIV=" << quoted("refresh") << " CONTENT=" << quoted(content) << ">";
+  headLines.push_back (ss.str());
 }
 
 
@@ -127,14 +126,14 @@ void Assets_Header::setFadingMenu (string html)
 // Add one breadcrumb $item with $text.
 void Assets_Header::addBreadCrumb (string item, string text)
 {
-  breadcrumbs.push_back (make_pair (item, text));
+  breadcrumbs.push_back (pair (item, text));
 }
 
 
 // Runs the header.
 string Assets_Header::run ()
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(m_webserver_request);
 
   string page;
   
@@ -178,7 +177,7 @@ string Assets_Header::run ()
     view->set_variable ("included_editor_stylesheet", includedEditorStylesheet);
   }
 
-  bool basic_mode = config_logic_basic_mode (webserver_request);
+  bool basic_mode = config_logic_basic_mode (m_webserver_request);
   string basicadvanced;
   if (basic_mode) basicadvanced = "basic";
   else basicadvanced = "advanced";
@@ -201,32 +200,39 @@ string Assets_Header::run ()
     string menublock;
     string item = request->query ["item"];
     bool main_menu_always_on = false;
+    if (config_logic_indonesian_cloud_free_simple ()) {
+      main_menu_always_on = true;
+      view->set_variable ("mainmenualwayson", convert_to_string (main_menu_always_on));
+    }
     if (item.empty ())
-      if (request->database_config_user ()->getMainMenuAlwaysVisible ())
+      if (request->database_config_user ()->getMainMenuAlwaysVisible ()) {
         main_menu_always_on = true;
+        // Add the main menu status as a Javascript variable.
+        view->set_variable ("mainmenualwayson", convert_to_string (main_menu_always_on));
+			}
     if ((item == "main") || main_menu_always_on) {
       if (basic_mode) {
         // Basic mode gives basic menu, but nothing in tabbed mode.
         if (!tabbed_mode_on) {
-          menublock = menu_logic_basic_categories (webserver_request);
+          menublock = menu_logic_basic_categories (m_webserver_request);
         }
       } else {
         string devnull;
-        menublock = menu_logic_main_categories (webserver_request, devnull);
+        menublock = menu_logic_main_categories (m_webserver_request, devnull);
       }
       start_button = false;
     } else if (item == menu_logic_translate_menu ()) {
-      menublock = menu_logic_translate_category (webserver_request);
+      menublock = menu_logic_translate_category (m_webserver_request);
     } else if (item == menu_logic_search_menu ()) {
-      menublock = menu_logic_search_category (webserver_request);
+      menublock = menu_logic_search_category (m_webserver_request);
     } else if (item == menu_logic_tools_menu ()) {
-      menublock = menu_logic_tools_category (webserver_request);
+      menublock = menu_logic_tools_category (m_webserver_request);
     } else if (item == menu_logic_settings_menu ()) {
-      menublock = menu_logic_settings_category (webserver_request);
+      menublock = menu_logic_settings_category (m_webserver_request);
     } else if (item == menu_logic_settings_resources_menu ()) {
-      menublock = menu_logic_settings_resources_category (webserver_request);
+      menublock = menu_logic_settings_resources_category (m_webserver_request);
     } else if (item == "help") {
-      menublock = menu_logic_help_category (webserver_request);
+      menublock = menu_logic_help_category (m_webserver_request);
     }
     view->set_variable ("mainmenu", menublock);
 
@@ -237,7 +243,7 @@ string Assets_Header::run ()
     if (start_button) {
       view->enable_zone ("start_button");
       string tooltip;
-      menu_logic_main_categories (webserver_request, tooltip);
+      menu_logic_main_categories (m_webserver_request, tooltip);
       view->set_variable ("starttooltip", tooltip);
     }
     
@@ -245,13 +251,14 @@ string Assets_Header::run ()
       view->enable_zone ("fading_menu");
       view->set_variable ("fadingmenu", fadingmenu);
       string delay = convert_to_string (request->database_config_user ()->getWorkspaceMenuFadeoutDelay ()) + "000";
+      if (config_logic_indonesian_cloud_free_simple ()) delay = "false";
       view->set_variable ("fadingmenudelay", delay);
       fadingmenu.clear ();
     }
 
     if (displayNavigator) {
       view->enable_zone ("display_navigator");
-      // string bible = access_bible_clamp (request, request->database_config_user()->getBible ());
+      // string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
       // The clamping above does not work for public feedback as it would reset the Bible always.
       string bible = request->database_config_user()->getBible ();
       view->set_variable ("navigation_code", Navigation_Passage::code (bible));
@@ -260,10 +267,32 @@ string Assets_Header::run ()
 
   vector <string> embedded_css;
   int fontsize = request->database_config_user ()->getGeneralFontSize ();
+  // Indonesian Cloud Free
+  // All of the accessible user defined variable in Indonesian Cloud Free
+  // Simple version uses filebased database as explained in ./ipc/focus.cpp
+  // line 37 to 44. 
+  string filename = general_font_size_filebased_cache_filename (request->session_identifier);
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    if (database_filebased_cache_exists (filename)) {
+      fontsize = convert_to_int (database_filebased_cache_get (filename));
+    } else {
+      database_filebased_cache_put (filename, "100");
+      fontsize = 100;
+    }
+  }
   if (fontsize != 100) {
     embedded_css.push_back ("body { font-size: " + convert_to_string (fontsize) + "%; }");
   }
   fontsize = request->database_config_user ()->getMenuFontSize ();
+  filename = menu_font_size_filebased_cache_filename (request->session_identifier);
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    if (database_filebased_cache_exists (filename)) {
+      fontsize = convert_to_int (database_filebased_cache_get (filename));
+    } else {
+      database_filebased_cache_put (filename, "100");
+      fontsize = 100;
+    }
+  }
   if (fontsize != 100) {
     embedded_css.push_back (".menu-advanced, .menu-basic { font-size: " + convert_to_string (fontsize) + "%; }");
   }
@@ -272,49 +301,88 @@ string Assets_Header::run ()
     embedded_css.push_back (".bibleeditor { font-size: " + convert_to_string (fontsize) + "% !important; }");
   }
   fontsize = request->database_config_user ()->getResourcesFontSize ();
+  filename = resource_font_size_filebased_cache_filename (request->session_identifier);
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    if (database_filebased_cache_exists (filename)) {
+      fontsize = convert_to_int (database_filebased_cache_get (filename));
+    } else {
+      database_filebased_cache_put (filename, "100");
+      fontsize = 100;
+    }
+  }
   if (fontsize != 100) {
     embedded_css.push_back (".resource { font-size: " + convert_to_string (fontsize) + "% !important; }");
   }
   fontsize = request->database_config_user ()->getHebrewFontSize ();
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    if (database_filebased_cache_exists (filename)) {
+      fontsize = convert_to_int (database_filebased_cache_get (filename));
+    } else {
+      database_filebased_cache_put (filename, "100");
+      fontsize = 100;
+    }
+  }
   if (fontsize != 100) {
     embedded_css.push_back (".hebrew { font-size: " + convert_to_string (fontsize) + "%!important; }");
   }
   fontsize = request->database_config_user ()->getGreekFontSize ();
+  filename = greek_font_size_filebased_cache_filename (request->session_identifier);
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    if (database_filebased_cache_exists (filename)) {
+      fontsize = convert_to_int (database_filebased_cache_get (filename));
+    } else {
+      database_filebased_cache_put (filename, "100");
+      fontsize = 100;
+    }
+  }
   if (fontsize != 100) {
     embedded_css.push_back (".greek { font-size: " + convert_to_string (fontsize) + "%!important; }");
   }
   if (!embedded_css.empty ()) {
     view->set_variable ("embedded_css", filter_string_implode (embedded_css, "\n"));
   }
-  
+
+  int current_theme_index = request->database_config_user ()->getCurrentTheme ();
+  filename = current_theme_filebased_cache_filename (request->session_identifier);
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    if (database_filebased_cache_exists (filename)) {
+      current_theme_index = convert_to_int (database_filebased_cache_get (filename));
+    } else {
+      database_filebased_cache_put (filename, "1");
+      current_theme_index = 1;
+    }
+  }
+  // Add the theme color css class selector name on the body element,..
+  view->set_variable ("body_theme_color", Filter_Css::theme_picker (current_theme_index, 0));
+  // ..workspacewrapper div element..
+  view->set_variable ("workspace_theme_color", Filter_Css::theme_picker (current_theme_index, 4));
+  // ..and as a variable for JavaScript.
+  view->set_variable ("themecolorfortabs", Filter_Css::theme_picker (current_theme_index, 1));
+
   if (request->database_config_user ()->getDisplayBreadcrumbs ()) {
     if (!breadcrumbs.empty ()) {
       // No bread crumbs in basic mode.
       // The crumbs would be incorrect anyway, because they show the trail of advanced mode.
-      if (!config_logic_basic_mode (webserver_request)) {
-        string track;
-        track.append ("<a href=\"/");
-        track.append (index_index_url ());
-        track.append ("\">");
-        track.append (menu_logic_menu_text (""));
-        track.append ("</a>");
+      if (!config_logic_basic_mode (m_webserver_request)) {
+        stringstream track;
+        track << "<a href=" << quoted(index_index_url ()) << ">";
+        track << menu_logic_menu_text ("") << "</a>";
         for (auto & crumb : breadcrumbs) {
-          track.append (" » ");
+          track << " » ";
           if (!crumb.first.empty ()) {
-            track.append ("<a href=\"/");
-            track.append (menu_logic_menu_url (crumb.first));
-            track.append ("\">");
+            track << "<a href=" << quoted("/" + menu_logic_menu_url (crumb.first)) << ">";
           }
-          track.append (crumb.second);
+          track << crumb.second;
           if (!crumb.first.empty ()) {
-            track.append ("</a>");
+            track << "</a>";
           }
         }
-        view->set_variable ("breadcrumbs", track);
+        view->enable_zone("breadcrumbs");
+        view->set_variable ("breadcrumbs", track.str());
       }
     }
   }
-  
+
   page += view->render("assets", "xhtml_start");
   page += view->render("assets", "header");
   page += view->render("assets", "workspacewrapper_start");
