@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,19 +17,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ASSETS_HEADER_H
-#define INCLUDED_ASSETS_HEADER_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <assets/view.h>
 
-
 class Assets_Header
 {
 public:
   Assets_Header (string title, void * webserver_request_in);
   ~Assets_Header ();
+  Assets_Header(const Assets_Header&) = delete;
+  Assets_Header operator=(const Assets_Header&) = delete;
   void jQueryTouchOn ();
   void touchCSSOn ();
   void notifItOn ();
@@ -42,19 +41,17 @@ public:
   void addBreadCrumb (string item, string text);
   string run ();
 private:
-  Assets_View * view;
-  bool includeJQueryTouch;
-  bool includeTouchCSS;
-  bool includeNotifIt;
-  vector <string> headLines;
-  bool displayNavigator;
-  string includedStylesheet;
-  string includedEditorStylesheet;
-  void * webserver_request;
-  string loginrequest;
-  string fadingmenu;
-  vector <pair <string, string> > breadcrumbs;
+  Assets_View * view {nullptr};
+  bool includeJQueryTouch {false};
+  bool includeTouchCSS {false};
+  bool includeNotifIt {false};
+  vector <string> headLines {};
+  bool displayNavigator {false};
+  string includedStylesheet {};
+  string includedEditorStylesheet {};
+  void * m_webserver_request {nullptr};
+  string loginrequest {};
+  string fadingmenu {};
+  vector <pair <string, string> > breadcrumbs {};
 };
 
-
-#endif
