@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ASSETS_VIEW_H
-#define INCLUDED_ASSETS_VIEW_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Assets_View
 {
 public:
@@ -34,10 +31,7 @@ public:
   void add_iteration (string key, map <string, string> value);
   string render (string tpl1, string tpl2);
 private:
-  map <string, string> variables;
-  map <string, bool> zones;
-  map <string, vector < map <string, string> > > iterations;
+  map <string, string> variables {};
+  map <string, bool> zones {};
+  map <string, vector < map <string, string> > > iterations {};
 };
-
-
-#endif
