@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ bool bible_css_acl (void * webserver_request)
 
 string bible_css (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   string page;
   
@@ -60,7 +60,7 @@ string bible_css (void * webserver_request)
   Assets_View view;
   
   // The name of the Bible.
-  string bible = access_bible_clamp (request, request->query ["bible"]);
+  string bible = AccessBible::Clamp (request, request->query ["bible"]);
   view.set_variable ("bible", escape_special_xml_characters (bible));
   
   // Data submission.
@@ -92,7 +92,7 @@ string bible_css (void * webserver_request)
     float letterspacing = convert_to_float (request->post["letterspacing"]);
     if (letterspacing < -3) letterspacing = -3;
     if (letterspacing > 3) letterspacing = 3;
-    Database_Config_Bible::setLetterSpacing (bible, 10 * letterspacing);
+    Database_Config_Bible::setLetterSpacing (bible, static_cast<int>(10 * letterspacing));
     
     page += Assets_Page::success ("The information was saved.");
     
@@ -102,7 +102,7 @@ string bible_css (void * webserver_request)
   view.enable_zone ("client");
 #endif
   
-  string font = Fonts_Logic::getTextFont (bible);
+  string font = Fonts_Logic::get_text_font (bible);
   view.set_variable ("font", font);
 
   int direction = Database_Config_Bible::getTextDirection (bible);
@@ -120,17 +120,17 @@ string bible_css (void * webserver_request)
   int lineheight = Database_Config_Bible::getLineHeight (bible);
   view.set_variable ("lineheight", convert_to_string (lineheight));
 
-  float letterspacing = Database_Config_Bible::getLetterSpacing (bible);
+  float letterspacing = static_cast<float> (Database_Config_Bible::getLetterSpacing (bible));
   letterspacing /= 10;
   view.set_variable ("letterspacing", convert_to_string (letterspacing));
 
-  string cls = Filter_Css::getClass (bible);
-  view.set_variable ("custom_class", cls);
-  view.set_variable ("custom_css", Filter_Css::getCss
-                     (cls,
-                      Fonts_Logic::getFontPath (font), direction,
-                      lineheight,
-                      Database_Config_Bible::getLetterSpacing (bible)));
+  string custom_class = Filter_Css::getClass (bible);
+  view.set_variable ("custom_class", custom_class);
+  string custom_css = Filter_Css::get_css (custom_class,
+                                          Fonts_Logic::get_font_path (font), direction,
+                                          lineheight,
+                                          Database_Config_Bible::getLetterSpacing (bible));
+  view.set_variable ("custom_css", custom_css);
 
   page += view.render ("bb", "css");
   
