@@ -48,7 +48,7 @@ void bible_logic_client_mail_pending_bible_updates (string user);
 void bible_logic_client_no_write_access_mail (const string & bible, int book, int chapter,
                                               const string & user,
                                               const string & oldusfm, const string & newusfm);
-void bible_logic_recent_save_email (const string & bible, int book, int chapter, int verse,
+void bible_logic_recent_save_email (const string & bible, int book, int chapter,
                                     const string & user,
                                     const string & old_usfm, const string & new_usfm);
 void bible_logic_optional_merge_irregularity_email (const string & bible, int book, int chapter,
