@@ -38,8 +38,10 @@
 #include <menu/logic.h>
 #include <demo/logic.h>
 #include <search/logic.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
-
+#pragma GCC diagnostic pop
 
 using namespace pugi;
 
