@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 // Creates book template with ID $book in Bible $bible.
 // If a $chapter is given instead of -1, it creates that chapter only.
+// If the $chapter is -1, it creates all chapters within that book.
 bool book_create (string bible, int book, int chapter, vector <string> & feedback)
 {
   Database_Bibles database_bibles;
@@ -47,7 +48,7 @@ bool book_create (string bible, int book, int chapter, vector <string> & feedbac
   }
   
   // The chapters that have been created.
-  vector <int> chaptersCreated;
+  vector <int> chapters_created;
   
   // The USFM created.
   string data;
@@ -58,7 +59,7 @@ bool book_create (string bible, int book, int chapter, vector <string> & feedbac
     data += "\\h "     + Database_Books::getEnglishFromId (book) + "\n";
     data += "\\toc2 "  + Database_Books::getEnglishFromId (book) + "\n";
     bible_logic_store_chapter (bible, book, 0, data);
-    chaptersCreated.push_back (0);
+    chapters_created.push_back (0);
   }
   
   
@@ -66,9 +67,9 @@ bool book_create (string bible, int book, int chapter, vector <string> & feedbac
   string versification = Database_Config_Bible::getVersificationSystem (bible);
   vector <Passage> versification_data = database_versifications.getBooksChaptersVerses (versification);
   for (auto & row : versification_data) {
-    if (book == row.book) {
-      int ch = row.chapter;
-      int verse = convert_to_int (row.verse);
+    if (book == row.m_book) {
+      int ch = row.m_chapter;
+      int verse = convert_to_int (row.m_verse);
       if ((chapter < 0) || (chapter == ch)) {
         data  = "\\c " + convert_to_string (ch) + "\n";
         data += "\\p\n";
@@ -76,20 +77,20 @@ bool book_create (string bible, int book, int chapter, vector <string> & feedbac
           data += "\\v " + convert_to_string (i) + "\n";
         }
         bible_logic_store_chapter (bible, book, ch, data);
-        chaptersCreated.push_back (ch);
+        chapters_created.push_back (ch);
       }
     }
   }
   
   // Done.
-  if (chaptersCreated.size () == 0) {
+  if (chapters_created.size () == 0) {
     feedback.push_back (translate("No chapters have been created"));
     return false;
   }
   string created;
-  for (auto & chapter : chaptersCreated) {
+  for (auto & chapter_created : chapters_created) {
     if (!created.empty ()) created.append (" ");
-    created.append (convert_to_string (chapter));
+    created.append (convert_to_string (chapter_created));
   }
   feedback.push_back (translate("The following chapters have been created:") + " " + created);
   return true;
