@@ -44,6 +44,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <manage/write.h>
 #include <manage/privileges.h>
 #include <system/index.h>
+#include <system/googletranslate.h>
 #include <collaboration/index.h>
 #include <collaboration/settings.h>
 #include <styles/indexm.h>
@@ -207,6 +208,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <session/confirm.h>
 #include <resource/comparative9edit.h>
 #include <resource/comparative1edit.h>
+#include <resource/translated9edit.h>
+#include <resource/translated1edit.h>
 #include <developer/logic.h>
 #include <developer/delay.h>
 #include <images/index.h>
@@ -251,8 +254,8 @@ void bootstrap_index (void * webserver_request)
   /*
   if (!request->post.empty () && config_logic_demo_enabled ()) {
     string contents;
-    int seconds = filter_date_seconds_since_epoch ();
-    string rfc822time = filter_date_rfc822 (seconds);
+    int seconds = filter::date::seconds_since_epoch ();
+    string rfc822time = filter::date::rfc822 (seconds);
     contents.append (rfc822time + "\n");
     contents.append (request->get + "\n");
     string query;
@@ -274,14 +277,17 @@ void bootstrap_index (void * webserver_request)
   string extension = filter_url_get_extension (request->get);
   string url = request->get.substr (1);
   
-  // Serve graphics, stylesheets, JavaScript, fonts, with direct streaming for low memory usage.
+  
+  // Serve graphics, stylesheets, JavaScript, fonts, and so on.
+  // Use direct streaming for low memory usage.
   if (   (extension == "ico")
       || (filter_url_is_image (extension))
       || (extension == "css")
       || (extension == "js")
-      || (Fonts_Logic::isFont (extension))
+      || (Fonts_Logic::is_font (extension))
       || (extension == "sh")
       || (extension == "map")
+      || (extension == "webmanifest")
       ) {
     http_stream_file (request, true);
     return;
@@ -701,6 +707,10 @@ void bootstrap_index (void * webserver_request)
     return;
   }
 
+  if ((url == system_googletranslate_url ()) && browser_request_security_okay (request) && system_googletranslate_acl (request)) {
+    request->reply = system_googletranslate (request);
+    return;
+  }
 
   if ((url == email_index_url ()) && browser_request_security_okay (request) && email_index_acl (request)) {
     request->reply = email_index (request);
@@ -1245,6 +1255,16 @@ void bootstrap_index (void * webserver_request)
     return;
   }
 
+  if ((url == resource_translated9edit_url ()) && browser_request_security_okay (request) && resource_translated9edit_acl (request)) {
+    request->reply = resource_translated9edit (request);
+    return;
+  }
+  
+  if ((url == resource_translated1edit_url ()) && browser_request_security_okay (request) && resource_translated1edit_acl (request)) {
+    request->reply = resource_translated1edit (request);
+    return;
+  }
+
   if ((url == developer_delay_url ()) && developer_delay_acl (request)) {
     request->reply = developer_delay (request);
     return;
