@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,10 @@
 #include <changes/statistics.h>
 #include <changes/manage.h>
 #include <tasks/logic.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 #include <locale/translate.h>
 #include <index/listing.h>
 #include <database/logs.h>
@@ -133,8 +136,8 @@ void changes_clear_notifications_user (string jobid, string username)
   int total_cleared = 0;
   
   // Feedback.
-  database_jobs.setPercentage (convert_to_int (jobid), 0);
-  database_jobs.setProgress (convert_to_int (jobid), translate ("Total:") + " " + convert_to_string (identifiers.size()));
+  database_jobs.set_percentage (convert_to_int (jobid), 0);
+  database_jobs.set_progress (convert_to_int (jobid), translate ("Total:") + " " + convert_to_string (identifiers.size()));
 
 
   // The amount of notifications it clears in the next iteration.
@@ -143,14 +146,14 @@ void changes_clear_notifications_user (string jobid, string username)
     cleared_count_in_one_go = database_modifications.clearNotificationsUser (username);
     total_cleared += cleared_count_in_one_go;
     if (!identifiers.empty ()) {
-      database_jobs.setPercentage (convert_to_int (jobid), 100 * total_cleared / identifiers.size());
+      database_jobs.set_percentage (convert_to_int (jobid), 100 * total_cleared / static_cast<int> (identifiers.size()));
     }
   } while (cleared_count_in_one_go);
   
   Webserver_Request request;
   request.database_config_user ()->setUserChangeNotificationsChecksum (username, "");
   
-  database_jobs.setResult (convert_to_int (jobid), translate ("Ready clearing change notifications"));
+  database_jobs.set_result (convert_to_int (jobid), translate ("Ready clearing change notifications"));
   
   Database_Logs::log (translate ("Ready clearing change notifications") + " " + username);
 }
