@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,10 @@
 #include <database/statistics.h>
 
 
+// Internal function declarations.
+void changes_statistics_add (Assets_View & view, const string & date, int count);
+
+
 string changes_statistics_url ()
 {
   return "changes/statistics";
@@ -53,16 +57,15 @@ void changes_statistics_add (Assets_View & view, const string & date, int count)
 }
 
 
-string changes_statistics (void * webserver_request)
+string changes_statistics ([[maybe_unused]] void * webserver_request)
 {
 #ifdef HAVE_CLIENT
-  (void) webserver_request;
-  return "";
+  return string();
 #endif
 
 #ifdef HAVE_CLOUD
 
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
 
   string page;
