@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -99,8 +99,8 @@ void Checks_Sentences::check (map <int, string> texts)
       fullText += " ";
     }
     // Split the UTF-8 text into characters and add them to the arrays of verse_numbers / characters.
-    int count = unicode_string_length (text);
-    for (int i = 0; i < count; i++) {
+    size_t count = unicode_string_length (text);
+    for (size_t i = 0; i < count; i++) {
       character = unicode_string_substr (text, i, 1);
       // Skip characters to be disregarded.
       if (in_array (character, disregards)) continue;
@@ -114,8 +114,7 @@ void Checks_Sentences::check (map <int, string> texts)
   }
   
   // Go through the characters.
-  int characterCount = characters.size ();
-  for (int i = 0; i < characterCount; i++) {
+  for (size_t i = 0; i < characters.size (); i++) {
     // Store current verse number in the object.
     verseNumber = verse_numbers [i];
     // Get the current character.
@@ -196,32 +195,32 @@ void Checks_Sentences::paragraphs (vector <string> paragraph_start_markers,
 
     // Get the first character of the paragraph.
     int verse = verses_paragraph.begin()->first;
-    string character = verses_paragraph.begin()->second;
-    if (!character.empty ()) {
-      character = unicode_string_substr (character, 0, 1);
+    string character2 = verses_paragraph.begin()->second;
+    if (!character2.empty ()) {
+      character2 = unicode_string_substr (character2, 0, 1);
     }
     
     // Check that the paragraph starts with a capital.
-    isCapital = in_array (character, capitals);
+    isCapital = in_array (character2, capitals);
     if (!isCapital) {
       string paragraph_marker = paragraph_start_markers [p];
       if (!in_array (paragraph_marker, within_sentence_paragraph_markers)) {
         string context = verses_paragraph.begin()->second;
         context = unicode_string_substr (context, 0, 15);
-        checkingResults.push_back (make_pair (verse, translate ("Paragraph does not start with a capital:") + " " + context));
+        checkingResults.push_back (pair (verse, translate ("Paragraph does not start with a capital:") + " " + context));
       }
     }
     
     // Get the last two characters of the paragraph.
     verse = verses_paragraph.rbegin()->first;
-    character = verses_paragraph.rbegin()->second;
-    if (!character.empty ()) {
-      size_t length = unicode_string_length (character);
-      character = unicode_string_substr (character, length - 1, 1);
+    character2 = verses_paragraph.rbegin()->second;
+    if (!character2.empty ()) {
+      size_t length = unicode_string_length (character2);
+      character2 = unicode_string_substr (character2, length - 1, 1);
     }
     string previous_character = verses_paragraph.rbegin()->second;
     if (!previous_character.empty ()) {
-      size_t length = unicode_string_length (character);
+      size_t length = unicode_string_length (character2);
       if (length >= 2) {
         previous_character = unicode_string_substr (previous_character, length - 2, 1);
       } else {
@@ -230,7 +229,7 @@ void Checks_Sentences::paragraphs (vector <string> paragraph_start_markers,
     }
     
     // Check that the paragraph ends with correct punctuation.
-    isEndMark = in_array (character, this->end_marks) || in_array (previous_character, this->end_marks);
+    isEndMark = in_array (character2, this->end_marks) || in_array (previous_character, this->end_marks);
     if (!isEndMark) {
       // If the next paragraph starts with a marker that indicates it should not necessarily be capitalized,
       // then the current paragraph may have punctuation that would be incorrect otherwise.
@@ -241,11 +240,11 @@ void Checks_Sentences::paragraphs (vector <string> paragraph_start_markers,
       }
       if (next_paragraph_marker.empty () || (!in_array (next_paragraph_marker, within_sentence_paragraph_markers))) {
         string context = verses_paragraph.rbegin()->second;
-        int length = unicode_string_length (character);
+        size_t length = unicode_string_length (character2);
         if (length >= 15) {
           context = unicode_string_substr (context, length - 15, 15);
         }
-        checkingResults.push_back (make_pair (verse, translate ("Paragraph does not end with an end marker:") + " " + context));
+        checkingResults.push_back (pair (verse, translate ("Paragraph does not end with an end marker:") + " " + context));
       }
     }
     
@@ -264,7 +263,10 @@ void Checks_Sentences::addResult (string text, int modifier)
   // Get previous and next text fragment.
   int start = currentPosition - 25;
   if (start < 0) start = 0;
-  string previousFragment = unicode_string_substr (fullText, start, currentPosition - start - 1);
+  string previousFragment =
+    unicode_string_substr (fullText,
+                           static_cast <size_t> (start),
+                           static_cast <size_t> (currentPosition - start - 1));
   int iterations = 5;
   while (iterations) {
     size_t pos = previousFragment.find (" ");
@@ -275,7 +277,8 @@ void Checks_Sentences::addResult (string text, int modifier)
     }
     iterations--;
   }
-  string nextFragment = unicode_string_substr (fullText, currentPosition, 25);
+  string nextFragment = unicode_string_substr (fullText,
+                                               static_cast <size_t> (currentPosition), 25);
   while (nextFragment.length () > 10) {
     size_t pos = nextFragment.rfind (" ");
     if (pos == string::npos) nextFragment.erase (nextFragment.length () - 1, 1);
@@ -296,7 +299,7 @@ void Checks_Sentences::addResult (string text, int modifier)
     text += ": " + previousFragment + character + nextFragment;
   }
   // Store checking result.
-  checkingResults.push_back (make_pair (verseNumber, text));
+  checkingResults.push_back (pair (verseNumber, text));
 }
 
 
