@@ -24,20 +24,23 @@
 #include <locale/translate.h>
 
 
-void Checks_Space::doubleSpaceUsfm (string bible, int book, int chapter, int verse, string data)
+namespace checks::space {
+
+
+void double_space_usfm (string bible, int book, int chapter, int verse, string data)
 {
   size_t pos = data.find ("  ");
   if (pos != string::npos) {
     int start = static_cast<int>(pos) - 10;
     if (start < 0) start = 0;
-    string fragment = data.substr (start, 20);
+    string fragment = data.substr (static_cast <size_t> (start), 20);
     Database_Check database_check;
     database_check.recordOutput (bible, book, chapter, verse, translate ("Double space:") + " ... " + fragment + " ...");
   }
 }
 
 
-void Checks_Space::spaceBeforePunctuation (string bible, int book, int chapter, map <int, string> texts)
+void space_before_punctuation (string bible, int book, int chapter, map <int, string> texts)
 {
   Database_Check database_check;
   for (auto element : texts) {
@@ -65,16 +68,16 @@ void Checks_Space::spaceBeforePunctuation (string bible, int book, int chapter,
 }
 
 
-void Checks_Space::spaceEndVerse (string bible, int book, int chapter, string usfm)
+void space_end_verse (string bible, int book, int chapter, string usfm)
 {
   Database_Check database_check;
-  vector <int> verses = usfm_get_verse_numbers (usfm);
+  vector <int> verses = filter::usfm::get_verse_numbers (usfm);
   for (auto verse : verses) {
     if (!verse) continue;
-    string text = usfm_get_verse_text (usfm, verse);
-    vector <string> items = usfm_get_markers_and_text (text);
+    string text = filter::usfm::get_verse_text (usfm, verse);
+    vector <string> items = filter::usfm::get_markers_and_text (text);
     for (auto item : items) {
-      if (usfm_is_usfm_marker (item)) {
+      if (filter::usfm::is_usfm_marker (item)) {
         text = filter_string_str_replace (item, "", text);
       }
     }
@@ -90,7 +93,7 @@ void Checks_Space::spaceEndVerse (string bible, int book, int chapter, string us
 }
 
 
-bool Checks_Space::transposeNoteSpace (string & usfm)
+bool transpose_note_space (string & usfm)
 {
   // Samples of footnote and cross reference markers that have spacing to be transposed.
   // \v 1 Verse\f + \fr 3.1\fk  keyword\ft  Text.\f* one.
@@ -112,3 +115,21 @@ bool Checks_Space::transposeNoteSpace (string & usfm)
   }
   return transposed;
 }
+
+
+void space_before_final_note_markup (string bible, int book, int chapter, int verse, string data)
+{
+  Database_Check database_check;
+  if (data.find (R"( \f*)") != string::npos) {
+    database_check.recordOutput (bible, book, chapter, verse, translate ("Space before final note markup"));
+  }
+  if (data.find (R"( \fe*)") != string::npos) {
+    database_check.recordOutput (bible, book, chapter, verse, translate ("Space before final note markup"));
+  }
+  if (data.find (R"( \x*)") != string::npos) {
+    database_check.recordOutput (bible, book, chapter, verse, translate ("Space before final cross reference markup"));
+  }
+}
+
+
+}
