@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,26 +17,19 @@
  */
 
 
-#ifndef INCLUDED_CLASSES_MERGE_H
-#define INCLUDED_CLASSES_MERGE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-class Merge_Conflict
+struct Merge_Conflict
 {
 public:
-  string base;
-  string change;
-  string prioritized_change;
-  string result;
-  string subject;
-  // The following show the passage where the conflict occurred.
-  // But this is not yet implemented throughout, only where it matters.
-  int book = 0;
-  int chapter = 0;
+  string base {};
+  string change {};
+  string prioritized_change {};
+  string result {};
+  string subject {};
+  // The following shows the passage where the conflict occurred.
+  int book {0};
+  int chapter {0};
 };
-
-
-#endif
