@@ -33,7 +33,10 @@
 #include <assets/header.h>
 #include <menu/logic.h>
 #include <bb/manage.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 
 
 using namespace pugi;
