@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -46,32 +46,43 @@ void config_logic_load_settings ()
 {
   string path;
   // Read the setting whether to log network connections.
-  path = filter_url_create_root_path (config_logic_config_folder (), "log-net");
-  config_globals_log_incoming_connections = file_or_dir_exists (path);
+  path = filter_url_create_root_path ({config_logic_config_folder (), "log-network"});
+  config_globals_log_network = file_or_dir_exists (path);
 }
 
 
 // Return the network port configured for the server.
 string config_logic_http_network_port ()
 {
+  // If a port number is known already, take that.
+  if (!config_globals_negotiated_port_number.empty()) return config_globals_negotiated_port_number;
   // Read the port number from file.
-  string path = filter_url_create_root_path (config_logic_config_folder (), "network-port");
-  string port = filter_url_file_get_contents (path);
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "network-port"});
+  config_globals_negotiated_port_number = filter_url_file_get_contents (path);
   // Remove white-space, e.g. a new line, that easily makes its way into the configuration file.
-  port = filter_string_trim (port);
-  // Default value.
-  if (port.empty ()) port = "9876";
+  config_globals_negotiated_port_number = filter_string_trim (config_globals_negotiated_port_number);
+  // Default port number.
+  if (config_globals_negotiated_port_number.empty ()) config_globals_negotiated_port_number = "8080";
   // Done.
-  return port;
+  return config_globals_negotiated_port_number;
 }
 
 
 // Return the secure network port for the secure server.
-int config_logic_https_network_port ()
+string config_logic_https_network_port ()
 {
-  int port = convert_to_int (config_logic_http_network_port ());
-  // The secure port is the plain http port plus one.
-  port++;
+  // Read the port number from file.
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "network-port-secure"});
+  string port = filter_url_file_get_contents (path);
+  // Remove white-space, e.g. a new line, that easily makes its way into the configuration file.
+  port = filter_string_trim (port);
+  // Default value.
+  if (port.empty ()) {
+    // The secure port is the plain http port plus one.
+    int iport = convert_to_int (config_logic_http_network_port ());
+    iport++;
+    port = convert_to_string (iport);
+  }
   return port;
 }
 
@@ -79,7 +90,7 @@ int config_logic_https_network_port ()
 // Returns whether demo mode is enabled during configure.
 bool config_logic_demo_enabled ()
 {
-  string path = filter_url_create_root_path (config_logic_config_folder (), "demo");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "demo"});
   return file_or_dir_exists (path);
 }
 
@@ -87,7 +98,7 @@ bool config_logic_demo_enabled ()
 // The configured admin's username.
 string config_logic_admin_username ()
 {
-  string path = filter_url_create_root_path (config_logic_config_folder (), "admin-username");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "admin-username"});
   return filter_string_trim (filter_url_file_get_contents (path));
 }
 
@@ -95,7 +106,7 @@ string config_logic_admin_username ()
 // The configured admin's password.
 string config_logic_admin_password ()
 {
-  string path = filter_url_create_root_path (config_logic_config_folder (), "admin-password");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "admin-password"});
   return filter_string_trim (filter_url_file_get_contents (path));
 }
 
@@ -103,7 +114,7 @@ string config_logic_admin_password ()
 // The configured admin's email.
 string config_logic_admin_email ()
 {
-  string path = filter_url_create_root_path (config_logic_config_folder (), "admin-email");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "admin-email"});
   return filter_string_trim (filter_url_file_get_contents (path));
 }
 
@@ -112,7 +123,7 @@ string config_logic_admin_email ()
 int my_stoi (const string& str, void * idx, int base)
 {
 #ifdef HAVE_STOI
-  size_t * index = (size_t *) idx;
+  size_t * index = static_cast<size_t *> (idx);
   return stoi (str, index, base);
 #else
   char ** endptr = reinterpret_cast <char **> (idx);
@@ -125,7 +136,7 @@ int my_stoi (const string& str, void * idx, int base)
 // Returns whether the interface is supposed to be in basic mode.
 bool config_logic_basic_mode (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   bool basic_mode = request->database_config_user ()->getBasicInterfaceMode ();
   return basic_mode;
 }
@@ -141,12 +152,12 @@ string config_logic_site_url (void * webserver_request)
   
   // If a webserver request is passed, take the host from there.
   // The results is that in a situation where 192.168.2.6 is the same as localhost,
-  // uses can connect from localhost and also from 192.168.2.6.
+  // user can connect from localhost and also from 192.168.2.6.
   // In the past there was a situation that the admin set up a central server for the whole team on his localhost.
   // Then team members that connected to 192.168.2.6 were forwarded to localhost (which of course failed).
   // This solution deals with that.
   if (webserver_request) {
-    Webserver_Request * request = (Webserver_Request *) webserver_request;
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
     if (!request->host.empty ()) {
       url = get_base_url (request);
       return url;
@@ -168,7 +179,7 @@ string config_logic_manual_user_facing_url ()
   return "";
 #else
   // Read the configuration file.
-  string path = filter_url_create_root_path (config_logic_config_folder (), "userfacingurl.conf");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "userfacingurl.conf"});
   string url = filter_url_file_get_contents (path);
   // Remove white space.
   url = filter_string_trim (url);
@@ -187,10 +198,10 @@ string config_logic_manual_user_facing_url ()
 string config_logic_server_key_path ()
 {
   // Try the correct config file first.
-  string path = filter_url_create_root_path (config_logic_config_folder (), "privkey.pem");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "privkey.pem"});
   if (file_or_dir_exists (path)) return path;
   // Try the file for localhost next.
-  path = filter_url_create_root_path (config_logic_config_folder (), "local.privkey.pem");
+  path = filter_url_create_root_path ({config_logic_config_folder (), "local.privkey.pem"});
   if (file_or_dir_exists (path)) return path;
   // Nothing found.
   return "";
@@ -202,10 +213,10 @@ string config_logic_server_key_path ()
 string config_logic_server_certificate_path ()
 {
   // Try the correct config file first.
-  string path = filter_url_create_root_path (config_logic_config_folder (), "cert.pem");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "cert.pem"});
   if (file_or_dir_exists (path)) return path;
   // Try the file for localhost next.
-  path = filter_url_create_root_path (config_logic_config_folder (), "local.cert.pem");
+  path = filter_url_create_root_path ({config_logic_config_folder (), "local.cert.pem"});
   if (file_or_dir_exists (path)) return path;
   // Nothing found.
   return "";
@@ -221,10 +232,10 @@ string config_logic_server_certificate_path ()
 string config_logic_authorities_certificates_path ()
 {
   // Try the correct config file first.
-  string path = filter_url_create_root_path (config_logic_config_folder (), "chain.pem");
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "chain.pem"});
   if (file_or_dir_exists (path)) return path;
   // Try the file for localhost next.
-  path = filter_url_create_root_path (config_logic_config_folder (), "local.chain.pem");
+  path = filter_url_create_root_path ({config_logic_config_folder (), "local.chain.pem"});
   if (file_or_dir_exists (path)) return path;
   // Nothing found.
   return "";
@@ -234,20 +245,20 @@ string config_logic_authorities_certificates_path ()
 // Whether to enforce https traffic for browser communications.
 bool config_logic_enforce_https_browser ()
 {
-  return file_or_dir_exists (filter_url_create_root_path (config_logic_config_folder (), "browser.https"));
+  return file_or_dir_exists (filter_url_create_root_path ({config_logic_config_folder (), "browser.https"}));
 }
 
 
 // Whether to enforce https traffic for client communications.
 bool config_logic_enforce_https_client ()
 {
-  return file_or_dir_exists (filter_url_create_root_path (config_logic_config_folder (), "client.https"));
+  return file_or_dir_exists (filter_url_create_root_path ({config_logic_config_folder (), "client.https"}));
 }
 
 
 void config_logic_swipe_enabled (void * webserver_request, string & script)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   string true_false = "false";
   if (request->session_logic ()->touchEnabled ()) {
@@ -263,8 +274,86 @@ void config_logic_swipe_enabled (void * webserver_request, string & script)
 }
 
 
-// Whether to log incoming IP connections to the journal.
-bool config_logic_log_incoming_connections ()
+// Whether the free Indonesian Cloud is enabled.
+bool config_logic_indonesian_cloud_free ()
 {
-  return config_globals_log_incoming_connections;
+  // Keep status in memory once it has been read from disk.
+  // This is to speed up things.
+  static bool read = false;
+  static bool status = false;
+  if (read) return status;
+
+  // Read the status from disk and cache it.
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "indonesiancloudfree"});
+  status = file_or_dir_exists (path);
+  read = true;
+ 
+  return status;
+}
+
+
+// Whether the free Indonesian Cloud Free Simple is enabled.
+// It is just like the regular demo setup with less feature:
+// 1. It only has an account with Consultant access level registered.
+// 2. It gives no access to account creation from menu
+// 3. It has different workspace defaults.
+bool config_logic_indonesian_cloud_free_simple ()
+{
+  // Keep status in memory once it has been read from disk.
+  // This is to speed up things.
+  static bool read = false;
+  static bool status = false;
+  if (read) return status;
+
+  // Read the status from disk and cache it.
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "indonesiancloudfreesimple"});
+  status = file_or_dir_exists (path);
+  read = true;
+ 
+  return status;
+}
+
+
+// Whether the free Indonesian Cloud Free Individual is enabled.
+// It is just like the default Indonesian Cloud Free,
+// but with no access to the consultation notes feature.
+bool config_logic_indonesian_cloud_free_individual ()
+{
+  // Keep status in memory once it has been read from disk.
+  // This is to speed up things.
+  static bool read = false;
+  static bool status = false;
+  if (read) return status;
+
+  // Read the status from disk and cache it.
+  string path = filter_url_create_root_path ({config_logic_config_folder (), "indonesiancloudfreeindividual"});
+  status = file_or_dir_exists (path);
+  read = true;
+ 
+  return status;
+}
+
+
+// Whether the default Bibledit configuration is enabled.
+bool config_logic_default_bibledit_configuration ()
+{
+  // Keep status in memory once it has been read from disk.
+  // This is to speed up things.
+  static bool read = false;
+  static bool status = true;
+  if (read) return status;
+
+  // If any of the special configurations is enabled, the default configuration is disabled.
+  if (config_logic_indonesian_cloud_free ()) status = false;
+  if (config_logic_indonesian_cloud_free_simple ()) status = false;
+  if (config_logic_indonesian_cloud_free_individual ()) status = false;
+  read = true;
+  
+  return status;
+}
+
+
+string config_logic_google_translate_json_key_path ()
+{
+  return filter_url_create_root_path ({config_logic_config_folder (), "googletranslate.json"});
 }
