@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,18 +17,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_CONFIG_LOGIC_H
-#define INCLUDED_CONFIG_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 const char * config_logic_config_folder ();
 const char * config_logic_version ();
 void config_logic_load_settings ();
 string config_logic_http_network_port ();
-int config_logic_https_network_port ();
+string config_logic_https_network_port ();
 bool config_logic_demo_enabled ();
 string config_logic_admin_username ();
 string config_logic_admin_password ();
@@ -43,7 +40,8 @@ string config_logic_authorities_certificates_path ();
 bool config_logic_enforce_https_browser ();
 bool config_logic_enforce_https_client ();
 void config_logic_swipe_enabled (void * webserver_request, string & script);
-bool config_logic_log_incoming_connections ();
-
-
-#endif
+bool config_logic_indonesian_cloud_free ();
+bool config_logic_indonesian_cloud_free_simple ();
+bool config_logic_indonesian_cloud_free_individual ();
+bool config_logic_default_bibledit_configuration ();
+string config_logic_google_translate_json_key_path ();
