@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_CONFIG_GENERAL_H
-#define INCLUDED_DATABASE_CONFIG_GENERAL_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <webserver/request.h>
 
-
 class Database_Config_General
 {
 public:
@@ -135,6 +132,24 @@ public:
   static bool getDisableSelectionPopupChromeOS ();
   static void setDisableSelectionPopupChromeOS (bool value);
 
+  static string getNotesVerseSeparator ();
+  static void setNotesVerseSeparator (string url);
+
+  static vector <string> getComparativeResources ();
+  static void setComparativeResources (vector <string> values);
+
+  static vector <string> getTranslatedResources ();
+  static void setTranslatedResources (vector <string> values);
+
+  static vector <string> getActiveResources ();
+  static void setActiveResources (vector <string> values);
+
+  static vector <string> getAccountCreationTimes ();
+  static void setAccountCreationTimes (vector <string> values);
+
+  static bool getKeepResourcesCacheForLong ();
+  static void setKeepResourcesCacheForLong (bool value);
+
 private:
   static string file (const char * key);
   static string getValue (const char * key, const char * default_value);
@@ -146,6 +161,3 @@ private:
   static vector <string> getList (const char * key);
   static void setList (const char * key, vector <string> values);
 };
-
-
-#endif
