@@ -238,7 +238,7 @@ void Database_Config_User::trim ()
   // Reset the sprint month and year after some time.
   // When a user visits the Sprint page after a few days, it will then display the current Sprint.
   // If the Sprint is not reset, the user may enter new tasks in the wrong sprint.
-  int time = filter_date_seconds_since_epoch () - (2 * 24 * 3600);
+  int time = filter::date::seconds_since_epoch () - (2 * 24 * 3600);
   Database_Users database_users;
   vector <string> users = database_users.get_users ();
   for (unsigned int i = 0; i < users.size(); i++) {
@@ -688,7 +688,7 @@ const char * Database_Config_User::keySprintMonth ()
 }
 int Database_Config_User::getSprintMonth ()
 {
-  return getIValue (keySprintMonth (), filter_date_numerical_month (filter_date_seconds_since_epoch ()));
+  return getIValue (keySprintMonth (), filter::date::numerical_month (filter::date::seconds_since_epoch ()));
 }
 void Database_Config_User::setSprintMonth (int value)
 {
@@ -702,7 +702,7 @@ const char * Database_Config_User::keySprintYear ()
 }
 int Database_Config_User::getSprintYear ()
 {
-  return getIValue (keySprintYear (), filter_date_numerical_year (filter_date_seconds_since_epoch ()));
+  return getIValue (keySprintYear (), filter::date::numerical_year (filter::date::seconds_since_epoch ()));
 }
 void Database_Config_User::setSprintYear (int value)
 {
@@ -855,7 +855,7 @@ Passage Database_Config_User::getPrintPassageFromForUser (string user)
 }
 void Database_Config_User::setPrintPassageFrom (Passage value)
 {
-  string s = convert_to_string (value.book) + "." + convert_to_string (value.chapter) + "." + value.verse;
+  string s = convert_to_string (value.m_book) + "." + convert_to_string (value.m_chapter) + "." + value.m_verse;
   setValue ("print-passage-from", s);
 }
 
@@ -870,7 +870,7 @@ Passage Database_Config_User::getPrintPassageToForUser (string user)
 }
 void Database_Config_User::setPrintPassageTo (Passage value)
 {
-  string s = convert_to_string (value.book) + "." + convert_to_string (value.chapter) + "." + value.verse;
+  string s = convert_to_string (value.m_book) + "." + convert_to_string (value.m_chapter) + "." + value.m_verse;
   setValue ("print-passage-to", s);
 }
 
@@ -1466,3 +1466,34 @@ void Database_Config_User::setUseColoredNoteStatusLabels (bool value)
   setBValue (use_colored_note_status_labels_key (), value);
 }
 
+
+const char * notes_date_format_key ()
+{
+  return "notes_date-format";
+}
+int Database_Config_User::getNotesDateFormat ()
+{
+  return getIValue (notes_date_format_key (), 0);
+}
+void Database_Config_User::setNotesDateFormat (int value)
+{
+  setIValue (notes_date_format_key (), value);
+}
+
+
+const char * change_notifications_bibles_key ()
+{
+  return "change-notifications-bibles";
+}
+vector <string> Database_Config_User::getChangeNotificationsBibles ()
+{
+  return getList (change_notifications_bibles_key ());
+}
+vector <string> Database_Config_User::getChangeNotificationsBiblesForUser (const string & user)
+{
+  return getListForUser (user, change_notifications_bibles_key ());
+}
+void Database_Config_User::setChangeNotificationsBibles (const vector <string>& values)
+{
+  setList (change_notifications_bibles_key (), values);
+}
