@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,19 +17,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_KJV_H
-#define INCLUDED_DATABASE_KJV_H
+#pragma once
 
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
 
-class Database_Kjv_Item
+struct Database_Kjv_Item
 {
-public:
-  string strong;
-  string english;
+  string strong {};
+  string english {};
 };
 
 
@@ -51,4 +49,3 @@ private:
 };
 
 
-#endif
