@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,36 +17,31 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_MAIL_H
-#define INCLUDED_DATABASE_MAIL_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-class Database_Mail_User
+struct Database_Mail_User
 {
-public:
-  int rowid;
-  int timestamp;
-  string subject;
+  int rowid {0};
+  int timestamp {0};
+  string subject {};
 };
 
-
-class Database_Mail_Item
+struct Database_Mail_Item
 {
-public:
-  string username;
-  string subject;
-  string body;
+  string username {};
+  string subject {};
+  string body {};
 };
 
-
 class Database_Mail
 {
 public:
   Database_Mail (void * webserver_request_in);
   ~Database_Mail ();
+  Database_Mail(const Database_Mail&) = delete;
+  Database_Mail operator=(const Database_Mail&) = delete;
   void create ();
   void optimize ();
   void trim ();
@@ -57,10 +52,8 @@ public:
   Database_Mail_Item get (int id);
   vector <int> getMailsToSend ();
   void postpone (int id);
+  vector <int> getAllMails ();
 private:
   sqlite3 * connect ();
-  void * webserver_request;
+  void * webserver_request {nullptr};
 };
-
-
-#endif
