@@ -190,7 +190,7 @@ vector <int> Database_Modifications::getTeamDiffChapters (const string& bible, i
     if (bits.size() != 3) continue;
     string path = filter_url_create_path ({teamFolder (), file});
     int time = filter_url_file_modification_time (path);
-    int days = (filter_date_seconds_since_epoch () - time) / 86400;
+    int days = (filter::date::seconds_since_epoch () - time) / 86400;
     if (days > 5) {
       // Unprocessed team changes older than so many days usually indicate a problem.
       // Perhaps the server crashed so it never could process them.
@@ -340,7 +340,7 @@ void Database_Modifications::recordUserSave (const string& username, const strin
   if (!file_or_dir_exists (folder)) filter_url_mkdir (folder);
   // The other data is stored in separate files in the newID folder.
   string timeFile = userTimeFile (username, bible, book, chapter, newID);
-  filter_url_file_put_contents (timeFile, convert_to_string (filter_date_seconds_since_epoch ()));
+  filter_url_file_put_contents (timeFile, convert_to_string (filter::date::seconds_since_epoch ()));
   string oldIDFile = userOldIDFile (username, bible, book, chapter, newID);
   filter_url_file_put_contents (oldIDFile, convert_to_string (oldID));
   string oldTextFile = userOldTextFile (username, bible, book, chapter, newID);
@@ -393,7 +393,7 @@ vector <int> Database_Modifications::getUserChapters (const string& username, co
   for (auto & file : files) {
     string path = filter_url_create_path ({folder, file});
     int time = filter_url_file_modification_time (path);
-    int days = (filter_date_seconds_since_epoch () - time) / 86400;
+    int days = (filter::date::seconds_since_epoch () - time) / 86400;
     if (days > 5) {
       // Unprocessed user changes older than so many days usually indicate a problem.
       // Perhaps the server crashed so it never could process them.
@@ -445,7 +445,7 @@ int Database_Modifications::getUserTimestamp (const string& username, const stri
   string contents = filter_url_file_get_contents (file);
   int time = convert_to_int (contents);
   if (time > 0) return time;
-  return filter_date_seconds_since_epoch ();
+  return filter::date::seconds_since_epoch ();
 }
 
 
@@ -501,7 +501,7 @@ void Database_Modifications::recordNotification (const vector <string> & users,
   // Normally this function is called just after midnight.
   // It would then put the current time on changes made the day before.
   // Make a correction for that by subtracting 6 hours.
-  int timestamp = filter_date_seconds_since_epoch () - 21600;
+  int timestamp = filter::date::seconds_since_epoch () - 21600;
   for (auto & user : users) {
     int identifier = getNextAvailableNotificationIdentifier ();
     SqliteDatabase sql (notificationIdentifierDatabase (identifier));
@@ -546,10 +546,10 @@ void Database_Modifications::indexTrimAllNotifications ()
 
   // Change notifications expire after 30 days.
   // But the more there are, the sooner they expire.
-  int expiry_time = filter_date_seconds_since_epoch () - (30 * 3600 * 24);
-  if (sidentifiers.size () > 10000) expiry_time = filter_date_seconds_since_epoch () - (14 * 3600 * 24);
-  if (sidentifiers.size () > 20000) expiry_time = filter_date_seconds_since_epoch () - (7 * 3600 * 14);
-  if (sidentifiers.size () > 30000) expiry_time = filter_date_seconds_since_epoch () - (4 * 3600 * 14);
+  int expiry_time = filter::date::seconds_since_epoch () - (30 * 3600 * 24);
+  if (sidentifiers.size () > 10000) expiry_time = filter::date::seconds_since_epoch () - (14 * 3600 * 24);
+  if (sidentifiers.size () > 20000) expiry_time = filter::date::seconds_since_epoch () - (7 * 3600 * 14);
+  if (sidentifiers.size () > 30000) expiry_time = filter::date::seconds_since_epoch () - (4 * 3600 * 14);
 
   // Database: Connect and speed it up.
   sqlite3 * db = connect ();
@@ -590,9 +590,9 @@ void Database_Modifications::indexTrimAllNotifications ()
       sql.add ("SELECT count(*) FROM notifications WHERE identifier = ");
       sql.add (identifier);
       sql.add (";");
-      vector <string> result = database_sqlite_query (db, sql.sql) ["count(*)"];
-      if (!result.empty ()) {
-        int count = convert_to_int (result [0]);
+      vector <string> count_result = database_sqlite_query (db, sql.sql) ["count(*)"];
+      if (!count_result.empty ()) {
+        int count = convert_to_int (count_result [0]);
         exists = (count > 0);
       }
     }
@@ -790,7 +790,7 @@ int Database_Modifications::getNotificationTimeStamp (int id)
   sqlite3 * db = connect ();
   vector <string> timestamps = database_sqlite_query (db, sql.sql) ["timestamp"];
   database_sqlite_disconnect (db);
-  int time = filter_date_seconds_since_epoch ();
+  int time = filter::date::seconds_since_epoch ();
   for (auto & stamp : timestamps) {
     time = convert_to_int (stamp);
   }
@@ -846,9 +846,9 @@ Passage Database_Modifications::getNotificationPassage (int id)
   vector <string> chapters = result ["chapter"];
   vector <string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
-    passage.book = convert_to_int (books [i]);
-    passage.chapter = convert_to_int (chapters [i]);
-    passage.verse = verses [i];
+    passage.m_book = convert_to_int (books [i]);
+    passage.m_chapter = convert_to_int (chapters [i]);
+    passage.m_verse = verses [i];
   }
   return passage;
 }
@@ -943,32 +943,32 @@ vector <int> Database_Modifications::clearNotificationMatches (string username,
 
   // Go through each of the personal changes.
   for (auto & personalID : personals) {
-    string bible = getNotificationBible (personalID);
+    string bible2 = getNotificationBible (personalID);
     Passage passage = getNotificationPassage (personalID);
-    int book = passage.book;
-    int chapter = passage.chapter;
-    int verse = convert_to_int (passage.verse);
+    int book = passage.m_book;
+    int chapter = passage.m_chapter;
+    int verse = convert_to_int (passage.m_verse);
     string modification = getNotificationModification (personalID);
     // Get all matching identifiers from the team's change notifications.
-    SqliteSQL sql = SqliteSQL ();
-    sql.add ("SELECT identifier FROM notifications WHERE username =");
-    sql.add (username);
-    sql.add ("AND category =");
-    sql.add (team);
-    sql.add ("AND bible =");
-    sql.add (bible);
-    sql.add ("AND book =");
-    sql.add (book);
-    sql.add ("AND chapter =");
-    sql.add (chapter);
-    sql.add ("AND verse =");
-    sql.add (verse);
-    sql.add ("AND modification =");
-    sql.add (modification);
-    sql.add (";");
+    SqliteSQL sql2 = SqliteSQL ();
+    sql2.add ("SELECT identifier FROM notifications WHERE username =");
+    sql2.add (username);
+    sql2.add ("AND category =");
+    sql2.add (team);
+    sql2.add ("AND bible =");
+    sql2.add (bible2);
+    sql2.add ("AND book =");
+    sql2.add (book);
+    sql2.add ("AND chapter =");
+    sql2.add (chapter);
+    sql2.add ("AND verse =");
+    sql2.add (verse);
+    sql2.add ("AND modification =");
+    sql2.add (modification);
+    sql2.add (";");
     vector <int> teamMatches;
-    vector <string> result = database_sqlite_query (db, sql.sql) ["identifier"];
-    for (auto & item : result) {
+    vector <string> result2 = database_sqlite_query (db, sql2.sql) ["identifier"];
+    for (auto & item : result2) {
       teamMatches.push_back (convert_to_int (item));
     }
     // There should be exactly one candidate for the matches to be removed.
@@ -978,20 +978,20 @@ vector <int> Database_Modifications::clearNotificationMatches (string username,
       // Check there are only two change notifications for this user / Bible / book / chapter / verse.
       // If there are more, we can't be sure that the personal change was not overwritten somehow.
       vector <int> passageMatches;
-      SqliteSQL sql = SqliteSQL ();
-      sql.add ("SELECT identifier FROM notifications WHERE username =");
-      sql.add (username);
-      sql.add ("AND bible =");
-      sql.add (bible);
-      sql.add ("AND book =");
-      sql.add (book);
-      sql.add ("AND chapter =");
-      sql.add (chapter);
-      sql.add ("AND verse =");
-      sql.add (verse);
-      sql.add (";");
-      vector <string> result = database_sqlite_query (db, sql.sql) ["identifier"];
-      for (auto & item : result) {
+      SqliteSQL sql3 = SqliteSQL ();
+      sql3.add ("SELECT identifier FROM notifications WHERE username =");
+      sql3.add (username);
+      sql3.add ("AND bible =");
+      sql3.add (bible2);
+      sql3.add ("AND book =");
+      sql3.add (book);
+      sql3.add ("AND chapter =");
+      sql3.add (chapter);
+      sql3.add ("AND verse =");
+      sql3.add (verse);
+      sql3.add (";");
+      vector <string> result3 = database_sqlite_query (db, sql3.sql) ["identifier"];
+      for (auto & item : result3) {
         passageMatches.push_back (convert_to_int (item));
       }
       if (passageMatches.size () == 2) {
@@ -1022,7 +1022,7 @@ void Database_Modifications::storeClientNotification (int id, string username, s
   // Erase any existing database.
   deleteNotificationFile (id);
   // Timestamp is not used: Just put the current time.
-  int timestamp = filter_date_seconds_since_epoch ();
+  int timestamp = filter::date::seconds_since_epoch ();
   {
     SqliteDatabase sql (notificationIdentifierDatabase (id));
     sql.add (createNotificationsDbSql ());
