@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,30 +17,23 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_MODIFICATIONS_H
-#define INCLUDED_DATABASE_MODIFICATIONS_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
-class Database_Modifications_Id
+struct Database_Modifications_Id
 {
-public:
-  int oldid;
-  int newid;
+  int oldid {0};
+  int newid {0};
 };
 
-
-class Database_Modifications_Text
+struct Database_Modifications_Text
 {
-public:
-  string oldtext;
-  string newtext;
+  string oldtext {};
+  string newtext {};
 };
 
-
 class Database_Modifications
 {
 public:
@@ -108,6 +101,3 @@ private:
   const char * createNotificationsDbSql ();
   void deleteNotificationFile (int identifier);
 };
-
-
-#endif
