@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -77,7 +77,7 @@ void Database_NoteActions::record (const string& username, int note, int action,
   sql.add (",");
   sql.add (note);
   sql.add (",");
-  sql.add (filter_date_seconds_since_epoch ());
+  sql.add (filter::date::seconds_since_epoch ());
   sql.add (",");
   sql.add (action);
   sql.add (",");
