@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -31,8 +31,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/state.h>
 #include <trash/handler.h>
 #include <webserver/request.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <jsonxx/jsonxx.h>
+#pragma GCC diagnostic pop
 #include <database/logic.h>
+#include <time.h>
 
 
 using namespace jsonxx;
@@ -136,13 +140,13 @@ void Database_Notes::create ()
 
 string Database_Notes::database_path ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "notes.sqlite");
+  return filter_url_create_root_path ({database_logic_databases (), "notes.sqlite"});
 }
 
 
 string Database_Notes::checksums_database_path ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "notes_checksums.sqlite");
+  return filter_url_create_root_path ({database_logic_databases (), "notes_checksums.sqlite"});
 }
 
 
@@ -192,19 +196,19 @@ void Database_Notes::trim ()
   vector <string> bits1 = filter_url_scandir (main_folder);
   for (auto bit1 : bits1) {
     if (bit1.length () == 3) {
-      string folder = filter_url_create_path (main_folder, bit1);
-      vector <string> bits2 = filter_url_scandir (folder);
+      string folder1 = filter_url_create_path ({main_folder, bit1});
+      vector <string> bits2 = filter_url_scandir (folder1);
       if (bits2.empty ()) {
-        Database_Logs::log (message + folder);
-        remove (folder.c_str ());
+        Database_Logs::log (message + folder1);
+        remove (folder1.c_str ());
       }
       for (auto bit2 : bits2) {
         if (bit2.length () == 3) {
-          string folder = filter_url_create_path (main_folder, bit1, bit2);
-          vector <string> bits3 = filter_url_scandir (folder);
+          string folder2 = filter_url_create_path ({main_folder, bit1, bit2});
+          vector <string> bits3 = filter_url_scandir (folder2);
           if (bits3.empty ()) {
-            Database_Logs::log (message + folder);
-            remove (folder.c_str());
+            Database_Logs::log (message + folder2);
+            remove (folder2.c_str());
           }
         }
       }
@@ -249,11 +253,11 @@ void Database_Notes::sync ()
     // It used conversion to int before to determine it was a real note,
     // with the result that it missed 10% of the notes, which subsequently got deleted, oops!
     if (bit1.length () == 3) {
-      vector <string> bits2 = filter_url_scandir (filter_url_create_path (main_folder, bit1));
+      vector <string> bits2 = filter_url_scandir (filter_url_create_path ({main_folder, bit1}));
       for (auto & bit2 : bits2) {
         // Old storage mechanism, e.g. folder "425".
         if (bit2.length () == 3) {
-          vector <string> bits3 = filter_url_scandir (filter_url_create_path (main_folder, bit1, bit2));
+          vector <string> bits3 = filter_url_scandir (filter_url_create_path ({main_folder, bit1, bit2}));
           for (auto & bit3 : bits3) {
             if (bit3.length () == 3) {
               int identifier = convert_to_int (bit1 + bit2 + bit3);
@@ -405,7 +409,7 @@ void Database_Notes::update_database_internal (int identifier, int modified, str
 
 string Database_Notes::main_folder_path ()
 {
-  return filter_url_create_root_path ("consultations");
+  return filter_url_create_root_path ({"consultations"});
 }
 
 
@@ -416,7 +420,7 @@ string Database_Notes::note_file (int identifier)
   string sidentifier = convert_to_string (identifier);
   string folder = sidentifier.substr (0, 3);
   string file = sidentifier.substr (3, 6) + ".json";
-  return filter_url_create_path (main_folder_path (), folder, file);
+  return filter_url_create_path ({main_folder_path (), folder, file});
 }
 
 
@@ -501,10 +505,9 @@ vector <int> Database_Notes::get_identifiers ()
 string Database_Notes::assemble_contents (int identifier, string contents)
 {
   string new_contents = get_contents (identifier);
-  int time = filter_date_seconds_since_epoch ();
-  string datetime = convert_to_string (filter_date_numerical_month_day (time)) + "/" + convert_to_string (filter_date_numerical_month (time)) + "/" + convert_to_string (filter_date_numerical_year (time));
-  string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
-
+  string datetime = filter::date::localized_date_format (webserver_request);
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string user = request->session_logic ()->currentUser ();
   // To make the notes more readable, add whitespace between the comments.
   bool is_initial_comment = new_contents.empty ();
   if (!is_initial_comment) {
@@ -619,7 +622,8 @@ int Database_Notes::store_new_note (const string& bible, int book, int chapter,
 // limit: If >= 0, it indicates the starting limit for the selection.
 vector <int> Database_Notes::select_notes (vector <string> bibles, int book, int chapter, int verse, int passage_selector, int edit_selector, int non_edit_selector, const string& status_selector, string bible_selector, string assignment_selector, bool subscription_selector, int severity_selector, int text_selector, const string& search_text, int limit)
 {
-  string username = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string username = request->session_logic ()->currentUser ();
   vector <int> identifiers;
   // SQL SELECT statement.
   string query = notes_select_identifier ();
@@ -663,19 +667,19 @@ vector <int> Database_Notes::select_notes (vector <string> bibles, int book, int
       break;
     case 1:
       // Select notes that have been edited during the last 30 days.
-      time = filter_date_seconds_since_epoch () - 30 * 24 * 3600;
+      time = filter::date::seconds_since_epoch () - 30 * 24 * 3600;
       break;
     case 2:
       // Select notes that have been edited during the last 7 days.
-      time = filter_date_seconds_since_epoch () - 7 * 24 * 3600;
+      time = filter::date::seconds_since_epoch () - 7 * 24 * 3600;
       break;
     case 3:
       // Select notes that have been edited since yesterday.
-      time = filter_date_seconds_since_epoch () - 1 * 24 * 3600 - filter_date_numerical_hour (filter_date_seconds_since_epoch ()) * 3600;
+      time = filter::date::seconds_since_epoch () - 1 * 24 * 3600 - filter::date::numerical_hour (filter::date::seconds_since_epoch ()) * 3600;
       break;
     case 4:
       // Select notes that have been edited today.
-      time = filter_date_seconds_since_epoch () - filter_date_numerical_hour (filter_date_seconds_since_epoch ()) * 3600;
+      time = filter::date::seconds_since_epoch () - filter::date::numerical_hour (filter::date::seconds_since_epoch ()) * 3600;
       break;
   }
   if (time != 0) {
@@ -692,23 +696,23 @@ vector <int> Database_Notes::select_notes (vector <string> bibles, int book, int
       break;
     case 1:
       // Select notes that have not been edited for a day.
-      nonedit = filter_date_seconds_since_epoch () - 1 * 24 * 3600;
+      nonedit = filter::date::seconds_since_epoch () - 1 * 24 * 3600;
       break;
     case 2:
       // Select notes that have not been edited for two days.
-      nonedit = filter_date_seconds_since_epoch () - 2 * 24 * 3600;
+      nonedit = filter::date::seconds_since_epoch () - 2 * 24 * 3600;
       break;
     case 3:
       // Select notes that have not been edited for a week.
-      nonedit = filter_date_seconds_since_epoch () - 7 * 24 * 3600;
+      nonedit = filter::date::seconds_since_epoch () - 7 * 24 * 3600;
       break;
     case 4:
       // Select notes that have not been edited for a month.
-      nonedit = filter_date_seconds_since_epoch () - 30 * 24 * 3600;
+      nonedit = filter::date::seconds_since_epoch () - 30 * 24 * 3600;
       break;
     case 5:
       // Select notes that have not been edited for a year.
-      nonedit = filter_date_seconds_since_epoch () - 365 * 24 * 3600;
+      nonedit = filter::date::seconds_since_epoch () - 365 * 24 * 3600;
       break;
   }
   if (nonedit != 0) {
@@ -897,7 +901,8 @@ void Database_Notes::add_comment (int identifier, const string& comment)
 // Subscribe the current user to the note identified by identifier.
 void Database_Notes::subscribe (int identifier)
 {
-  string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string user = request->session_logic ()->currentUser ();
   subscribe_user (identifier, user);
 }
 
@@ -979,7 +984,8 @@ bool Database_Notes::is_subscribed (int identifier, const string& user)
 // Unsubscribes the currently logged in user from the note identified by identifier.
 void Database_Notes::unsubscribe (int identifier)
 {
-  string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string user = request->session_logic ()->currentUser ();
   unsubscribe_user (identifier, user);
 }
 
@@ -1197,9 +1203,9 @@ Passage Database_Notes::decode_passage (string passage)
   passage = filter_string_trim (passage);
   Passage decodedpassage = Passage ();
   vector <string> lines = filter_string_explode (passage, '.');
-  if (lines.size() > 0) decodedpassage.book = convert_to_int (lines[0]);
-  if (lines.size() > 1) decodedpassage.chapter = convert_to_int (lines[1]);
-  if (lines.size() > 2) decodedpassage.verse = lines[2];
+  if (lines.size() > 0) decodedpassage.m_book = convert_to_int (lines[0]);
+  if (lines.size() > 1) decodedpassage.m_chapter = convert_to_int (lines[1]);
+  if (lines.size() > 2) decodedpassage.m_verse = lines[2];
   return decodedpassage;
 }
 
@@ -1244,7 +1250,7 @@ void Database_Notes::set_passages (int identifier, const vector <Passage>& passa
   string line;
   for (auto & passage : passages) {
     if (!line.empty ()) line.append ("\n");
-    line.append (encode_passage (passage.book, passage.chapter, convert_to_int (passage.verse)));
+    line.append (encode_passage (passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse)));
   }
   // Store it.
   set_raw_passage (identifier, line);
@@ -1382,7 +1388,7 @@ string Database_Notes::get_severity (int identifier)
   int severity = get_raw_severity (identifier);
   vector <string> standard = standard_severities ();
   string severitystring;
-  if ((severity >= 0) && (severity < (int)standard.size())) severitystring = standard [severity];
+  if ((severity >= 0) && (severity < static_cast<int>(standard.size()))) severitystring = standard [static_cast<size_t> (severity)];
   if (severitystring.empty()) severitystring = "Normal";
   severitystring = translate (severitystring.c_str());
   return severitystring;
@@ -1470,7 +1476,7 @@ void Database_Notes::set_public (int identifier, bool value)
 void Database_Notes::note_modified_actions (int identifier)
 {
   // Update 'modified' field.
-  set_modified (identifier, filter_date_seconds_since_epoch());
+  set_modified (identifier, filter::date::seconds_since_epoch());
 }
 
 
@@ -1762,7 +1768,7 @@ vector <int> Database_Notes::get_notes_in_range_for_bibles (int lowId, int highI
 
 string Database_Notes::availability_flag ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "notes.busy");
+  return filter_url_create_root_path ({database_logic_databases (), "notes.busy"});
 }
 
 
@@ -1875,17 +1881,17 @@ vector <string> Database_Notes::set_bulk (string json)
   for (size_t i = 0; i < bulk.size (); i++) {
     
     // Get all the different fields for this note.
-    Object note = bulk.get<Object>(i);
+    Object note = bulk.get<Object>(static_cast<unsigned>(i));
     string assigned = note.get<String> ("a");
     string bible = note.get<String> ("b");
     string contents = note.get<String> ("c");
-    int identifier = note.get<Number> ("i");
-    int modified = note.get<Number> ("m");
+    int identifier = static_cast<int>(note.get<Number> ("i"));
+    int modified = static_cast<int>(note.get<Number> ("m"));
     string passage = note.get<String> ("p");
     string subscriptions = note.get<String> ("sb");
     string summary = note.get<String> ("sm");
     string status = note.get<String> ("st");
-    int severity = note.get<Number> ("sv");
+    int severity = static_cast<int>(note.get<Number> ("sv"));
     
     // Feedback about which note it received in bulk.
     summaries.push_back (summary);
@@ -1904,8 +1910,8 @@ vector <string> Database_Notes::set_bulk (string json)
     note2 << summary_key () << summary;
     note2 << status_key () << status;
     note2 << severity_key () << convert_to_string (severity);
-    string json = note2.json ();
-    filter_url_file_put_contents (path, json);
+    string json2 = note2.json ();
+    filter_url_file_put_contents (path, json2);
     
     // Update the indexes.
     update_database (identifier);
