@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -106,9 +106,9 @@ vector <Passage> Database_OsHb::searchHebrew (string hebrew)
   vector <string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
     Passage passage;
-    passage.book = convert_to_int (books [i]);
-    passage.chapter = convert_to_int (chapters [i]);
-    passage.verse = verses [i];
+    passage.m_book = convert_to_int (books [i]);
+    passage.m_chapter = convert_to_int (chapters [i]);
+    passage.m_verse = verses [i];
     hits.push_back (passage);
   }
   return hits;
