@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -457,19 +457,19 @@ bool Database_Styles::hasWriteAccess (string user, string sheet)
 
 string Database_Styles::databasefolder ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "styles");
+  return filter_url_create_root_path ({database_logic_databases (), "styles"});
 }
 
 
 string Database_Styles::sheetfolder (string sheet)
 {
-  return filter_url_create_path (databasefolder (), sheet);
+  return filter_url_create_path ({databasefolder (), sheet});
 }
 
 
 string Database_Styles::stylefile (string sheet, string marker)
 {
-  return filter_url_create_path (sheetfolder (sheet), marker);
+  return filter_url_create_path ({sheetfolder (sheet), marker});
 }
 
 
@@ -670,34 +670,3 @@ void Database_Styles::cache_defaults ()
 }
 
 
-Database_Styles_Item::Database_Styles_Item ()
-{
-  // Defaults.
-  type = 0;
-  subtype = 0;
-  fontsize = 12;
-  italic = 0;
-  bold = 0;
-  underline = 0;
-  smallcaps = 0;
-  superscript = 0;
-  justification = 0;
-  spacebefore = 0;
-  spaceafter = 0;
-  leftmargin = 0;
-  rightmargin = 0;
-  firstlineindent = 0;
-  spancolumns = false;
-  color = "#000000";
-  print = false;
-  userbool1 = false;
-  userbool2 = false;
-  userbool3 = false;
-  userint1 = 0;
-  userint2 = 0;
-  userint3 = 0;
-  userstring1 = "";
-  userstring2 = "";
-  userstring3 = "";
-  backgroundcolor = "#FFFFFF";
-}
