@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,48 +17,43 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_STYLES_H
-#define INCLUDED_DATABASE_STYLES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-class Database_Styles_Item
+struct Database_Styles_Item
 {
-public:
-  Database_Styles_Item ();
-  string marker;
-  string name;
-  string info;
-  string category;
-  int type;
-  int subtype;
-  float fontsize;
-  int italic;
-  int bold;
-  int underline;
-  int smallcaps;
-  int superscript;
-  int justification;
-  float spacebefore;
-  float spaceafter;
-  float leftmargin;
-  float rightmargin;
-  float firstlineindent;
-  bool spancolumns;
-  string color;
-  bool print;
-  bool userbool1;
-  bool userbool2;
-  bool userbool3;
-  int userint1;
-  int userint2;
-  int userint3;
-  string userstring1;
-  string userstring2;
-  string userstring3;
-  string backgroundcolor;
+  string marker {};
+  string name {};
+  string info {};
+  string category {};
+  int type {0};
+  int subtype {0};
+  float fontsize {12.0f};
+  int italic {0};
+  int bold {0};
+  int underline {0};
+  int smallcaps {0};
+  int superscript {0};
+  int justification {0};
+  float spacebefore {0.0f};
+  float spaceafter {0.0f};
+  float leftmargin {0.0f};
+  float rightmargin {0.0f};
+  float firstlineindent {0.0f};
+  bool spancolumns {false};
+  string color {"#000000"};
+  bool print {false};
+  bool userbool1 {false};
+  bool userbool2 {false};
+  bool userbool3 {false};
+  int userint1 {0};
+  int userint2 {0};
+  int userint3 {0};
+  string userstring1 {};
+  string userstring2 {};
+  string userstring3 {};
+  string backgroundcolor {"#FFFFFF"};
 };
 
 
@@ -115,6 +110,3 @@ private:
   void write_item (string sheet, Database_Styles_Item & item);
   void cache_defaults ();
 };
-
-
-#endif
