@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -52,12 +52,12 @@ void Database_Users::upgrade ()
   SqliteDatabase sql (filename ());
   sql.add ("PRAGMA table_info (users);");
   vector <string> columns = sql.query () ["name"];
-  if (!in_array ((string)"ldap", columns)) {
+  if (!in_array (static_cast<string> ("ldap"), columns)) {
     sql.clear ();
     sql.add ("ALTER TABLE users ADD COLUMN ldap boolean;");
     sql.execute ();
   }
-  if (!in_array ((string)"disabled", columns)) {
+  if (!in_array (static_cast<string> ("disabled"), columns)) {
     sql.clear ();
     sql.add ("ALTER TABLE users ADD COLUMN disabled boolean;");
     sql.execute ();
@@ -268,7 +268,7 @@ void Database_Users::updateUserEmail (string user, string email)
 
 
 // Return an array with the available users.
-vector <string> Database_Users::getUsers ()
+vector <string> Database_Users::get_users ()
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users;");
@@ -320,7 +320,10 @@ bool Database_Users::get_ldap (string user)
   sql.add (user);
   sql.add (";");
   vector <string> result = sql.query () ["ldap"];
-  if (!result.empty()) return convert_to_bool (result [0]);
+  if (!result.empty()) {
+    bool ldap_is_on = convert_to_bool (result [0]);
+    return ldap_is_on;
+  }
   return false;
 }
 
