@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -90,22 +90,34 @@ void Database_Versifications::input (const string& contents, const string& name)
   for (auto line : lines) {
     line = filter_string_trim (line);
     if (line.empty ()) continue;
-    Passage passage = filter_passage_explode_passage (line);
-    if ((passage.book == 0)
-     || (passage.chapter == 0)
-     || (passage.verse.empty ())) {
+    // The line will be something similar to this: 1 Corinthians 1:31
+    // Split the passage entry on the colon (:) to get the verse.
+    vector <string> bits = filter_string_explode(line, ':');
+    if (bits.size() != 2) continue;
+    int verse = convert_to_int(bits[1]);
+    // Split the first bit on the spaces and get the last item as the chapter.
+    bits = filter_string_explode(bits[0], ' ');
+    if (bits.size() < 2) continue;
+    int chapter = convert_to_int(bits[bits.size()-1]);
+    // Remove the last bit so it remains with the book, and get that book.
+    bits.pop_back();
+    string passage_book_string = filter_string_implode(bits, " ");
+    int book = Database_Books::getIdFromEnglish(passage_book_string);
+    // Check result.
+    if ((book == 0) || (chapter == 0)) {
       Database_Logs::log ("Malformed versification entry: " + line);
       continue;
     }
+    // Store result.
     SqliteSQL sql = SqliteSQL ();
     sql.add ("INSERT INTO data (system, book, chapter, verse) VALUES (");
     sql.add (id);
     sql.add (",");
-    sql.add (passage.book);
+    sql.add (book);
     sql.add (",");
-    sql.add (passage.chapter);
+    sql.add (chapter);
     sql.add (",");
-    sql.add (convert_to_int (passage.verse));
+    sql.add (verse);
     sql.add (");");
     database_sqlite_exec (db, sql.sql);
   }
@@ -121,11 +133,11 @@ string Database_Versifications::output (const string& name)
   vector <string> lines;
   vector <Passage> versification_data = getBooksChaptersVerses (name);
   for (Passage & passage : versification_data) {
-    string line = Database_Books::getEnglishFromId (passage.book);
+    string line = Database_Books::getEnglishFromId (passage.m_book);
     line.append (" ");
-    line.append (convert_to_string (passage.chapter));
+    line.append (convert_to_string (passage.m_chapter));
     line.append (":");
-    line.append (passage.verse);
+    line.append (passage.m_verse);
     lines.push_back (line);
   }
   return filter_string_implode (lines, "\n");
@@ -164,7 +176,8 @@ int Database_Versifications::getID (const string& name)
   sqlite3 * db = connect ();
   vector <string> systems = database_sqlite_query (db, sql.sql) ["system"];
   database_sqlite_disconnect (db);
-  for (auto & id : systems) {
+  if (!systems.empty()) {
+    auto id = systems[0];
     return convert_to_int (id);
   }
   return 0;
@@ -230,9 +243,9 @@ vector <Passage> Database_Versifications::getBooksChaptersVerses (const string&
   vector <string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
     Passage passage;
-    passage.book = convert_to_int (books [i]);
-    passage.chapter = convert_to_int (chapters [i]);
-    passage.verse = verses [i];
+    passage.m_book = convert_to_int (books [i]);
+    passage.m_chapter = convert_to_int (chapters [i]);
+    passage.m_verse = verses [i];
     data.push_back (passage);
   }
   return data;
