@@ -28,13 +28,13 @@ class Developer_Logic_Tracer
 public:
   Developer_Logic_Tracer(void * webserver_request);
   ~Developer_Logic_Tracer();
-  int seconds1 = 0;
-  int microseconds1 = 0;
-  string rfc822;
-  string remote_address;
-  string request_get;
-  string request_query;
-  string username;
+  int seconds1 {0};
+  int microseconds1 {0};
+  string rfc822 {};
+  string remote_address {};
+  string request_get {};
+  string request_query {};
+  string username {};
 };
 
 void developer_logic_import_changes ();
