@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,27 +17,23 @@
  */
 
 
-#ifndef INCLUDED_DIALOG_BOOKS_H
-#define INCLUDED_DIALOG_BOOKS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Dialog_Books
 {
 public:
   Dialog_Books (string url, string header, string info_top, string info_bottom, string action, vector <int> inclusions, vector <int> exclusions);
   ~Dialog_Books ();
+  Dialog_Books (const Dialog_Books&) = delete;
+  Dialog_Books operator=(const Dialog_Books&) = delete;
   void add_query (string parameter, string value);
   string run ();
 private:
-  void * assets_view = NULL;
-  string base_url;
-  string selection_action;
-  vector <int> include;
-  vector <int> exclude;
+  void * assets_view {nullptr};
+  string base_url {};
+  string selection_action {};
+  vector <int> include {};
+  vector <int> exclude {};
 };
-
-
-#endif
