@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,24 +17,20 @@
  */
 
 
-#ifndef INCLUDED_DIALOG_COLOR_H
-#define INCLUDED_DIALOG_COLOR_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Dialog_Color
 {
 public:
   Dialog_Color (string url, string question);
   ~Dialog_Color ();
+  Dialog_Color(const Dialog_Color&) = delete;
+  Dialog_Color operator=(const Dialog_Color&) = delete;
   void add_query (string parameter, string value);
   string run ();
 private:
-  void * assets_view = NULL;
-  string base_url;
+  void * assets_view {nullptr};
+  string base_url {};
 };
-
-
-#endif
