@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,25 +17,21 @@
  */
 
 
-#ifndef INCLUDED_DIALOG_UPLOAD_H
-#define INCLUDED_DIALOG_UPLOAD_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Dialog_Upload
 {
 public:
   Dialog_Upload (string url, string question);
   ~Dialog_Upload ();
+  Dialog_Upload(const Dialog_Upload&) = delete;
+  Dialog_Upload operator=(const Dialog_Upload&) = delete;
   void add_upload_query (string parameter, string value);
   string run ();
 private:
-  void * assets_view = NULL;
-  string base_url;
-  map <string, string> upload_query;
+  void * assets_view = {nullptr};
+  string base_url {};
+  map <string, string> upload_query {};
 };
-
-
-#endif
