@@ -53,13 +53,13 @@ string edit_edit (void * webserver_request)
   
   string passage_query = request->query ["passage"];
   Passage passage = filter_integer_to_passage (convert_to_int (passage_query));
-  Ipc_Focus::set (request, passage.book, passage.chapter, convert_to_int (passage.verse));
-  Navigation_Passage::record_history (request, passage.book, passage.chapter, convert_to_int (passage.verse));
+  Ipc_Focus::set (request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
+  Navigation_Passage::record_history (request, passage.m_book, passage.m_chapter, convert_to_int (passage.m_verse));
   
   
   // Check whether a Bible editor is alive.
   int timestamp = request->database_config_user()->getLiveBibleEditor ();
-  bool alive = (timestamp > (filter_date_seconds_since_epoch () - 5));
+  bool alive = (timestamp > (filter::date::seconds_since_epoch () - 5));
   
   
   if (alive) return translate ("The passage has been opened in the existing Bible editor");
