@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -47,15 +47,14 @@ string edit_preview_url ()
 bool edit_preview_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return read;
 }
 
 
 string edit_preview (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   bool touch = request->session_logic ()->touchEnabled ();
   bool timeout = request->query.count ("timeout");
@@ -75,16 +74,16 @@ string edit_preview (void * webserver_request)
   
   // Get active Bible, and check read access to it.
   // If needed, change Bible to one it has read access to.
-  string bible = access_bible_clamp (request, request->database_config_user()->getBible ());
+  string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
   
   string cls = Filter_Css::getClass (bible);
-  string font = Fonts_Logic::getTextFont (bible);
+  string font = Fonts_Logic::get_text_font (bible);
   int direction = Database_Config_Bible::getTextDirection (bible);
   int lineheight = Database_Config_Bible::getLineHeight (bible);
   int letterspacing = Database_Config_Bible::getLetterSpacing (bible);
   view.set_variable ("custom_class", cls);
-  view.set_variable ("custom_css", Filter_Css::getCss (cls,
-                                                       Fonts_Logic::getFontPath (font),
+  view.set_variable ("custom_css", Filter_Css::get_css (cls,
+                                                       Fonts_Logic::get_font_path (font),
                                                        direction,
                                                        lineheight,
                                                        letterspacing));
@@ -99,6 +98,7 @@ string edit_preview (void * webserver_request)
   Editor_Usfm2Html editor_usfm2html;
   editor_usfm2html.load (usfm);
   editor_usfm2html.stylesheet (stylesheet);
+  editor_usfm2html.set_preview();
   editor_usfm2html.run ();
   
   string html = editor_usfm2html.get ();
@@ -109,6 +109,9 @@ string edit_preview (void * webserver_request)
     view.set_variable ("caller", caller);
   }
   
+  // Store the active Bible in the page's javascript.
+  view.set_variable ("navigationCode", Navigation_Passage::code (bible));
+  
   page += view.render ("edit", "preview");
   
   page += Assets_Page::footer ();
