@@ -35,6 +35,7 @@
 #include <fonts/logic.h>
 #include <navigation/passage.h>
 #include <dialog/list.h>
+#include <dialog/list2.h>
 #include <ipc/focus.h>
 #include <menu/logic.h>
 #include <bb/logic.h>
@@ -85,18 +86,25 @@ string editone2_index (void * webserver_request)
       vector <string> bibles = AccessBible::Bibles (request);
       string selected_bible;
       for (auto bible : bibles) {
-        if (bible != filter_indonesian_alkitabkita_ourtranslation_name ()) selected_bible = bible;
+        if (bible != filter::indonesian::ourtranslation ()) selected_bible = bible;
       }
       if (selected_bible.empty ()) {
         // No Bible selected yet: Create the Indonesian Sample Bible and take that.
         string user = request->session_logic ()->currentUser ();
-        selected_bible = filter_indonesian_terjemahanku_mytranslation_name (user);
+        selected_bible = filter::indonesian::mytranslation (user);
         bible_logic_create_empty_bible (selected_bible);
       }
       request->database_config_user()->setBible (selected_bible);
     }
   }
 
+  // Set the user chosen Bible as the current Bible.
+  if (request->post.count ("bibleselect")) {
+    string bibleselect = request->post ["bibleselect"];
+    request->database_config_user ()->setBible (bibleselect);
+    return string();
+  }
+
   string page;
   
   Assets_Header header = Assets_Header (translate("Edit verse"), request);
@@ -109,25 +117,18 @@ string editone2_index (void * webserver_request)
   
   Assets_View view;
   
-  if (request->query.count ("changebible")) {
-    string changebible = request->query ["changebible"];
-    if (changebible == "") {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Select which Bible to open in the editor"), "", "");
-      vector <string> bibles = AccessBible::Bibles (request);
-      for (auto bible : bibles) {
-        dialog_list.add_row (bible, "changebible", bible);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      request->database_config_user()->setBible (changebible);
-    }
-  }
-  
   // Get active Bible, and check read access to it.
+  // Or if the user have used query to preset the active Bible, get the preset Bible.
   // If needed, change Bible to one it has read access to.
+  // Set the chosen Bible on the option HTML tag.
   string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
   if (request->query.count ("bible")) bible = AccessBible::Clamp (request, request->query ["bible"]);
+  string bible_html;
+  vector <string> bibles = AccessBible::Bibles (request);
+  for (auto selectable_bible : bibles) {
+    bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
+  }
+  view.set_variable ("bibleoptags", Options_To_Select::mark_selected (bible, bible_html));
   view.set_variable ("bible", bible);
   
   // Store the active Bible in the page's javascript.
@@ -148,20 +149,20 @@ string editone2_index (void * webserver_request)
   config_logic_swipe_enabled (webserver_request, script);
   view.set_variable ("script", script);
 
-  string cls = Filter_Css::getClass (bible);
-  string font = Fonts_Logic::getTextFont (bible);
-  int current_theme_index = convert_to_int(request->database_config_user ()->getCurrentTheme ());
+  string custom_class = Filter_Css::getClass (bible);
+  string font = Fonts_Logic::get_text_font (bible);
+  int current_theme_index = request->database_config_user ()->getCurrentTheme ();
   int direction = Database_Config_Bible::getTextDirection (bible);
   int lineheight = Database_Config_Bible::getLineHeight (bible);
   int letterspacing = Database_Config_Bible::getLetterSpacing (bible);
   view.set_variable ("editor_theme_color", Filter_Css::theme_picker (current_theme_index, 2));
   view.set_variable ("active_editor_theme_color", Filter_Css::theme_picker (current_theme_index, 3));
-  view.set_variable ("custom_class", cls);
-  view.set_variable ("custom_css", Filter_Css::getCss (cls,
-                                                       Fonts_Logic::getFontPath (font),
-                                                       direction,
-                                                       lineheight,
-                                                       letterspacing));
+  view.set_variable ("custom_class", custom_class);
+  string custom_css = Filter_Css::get_css (custom_class,
+                                          Fonts_Logic::get_font_path (font),
+                                          direction, lineheight, letterspacing);
+  view.set_variable ("custom_css", custom_css);
+
   
   // Whether to enable fast Bible editor switching.
   if (request->database_config_user ()->getFastEditorSwitchingAvailable ()) {
