@@ -21,7 +21,10 @@
 
 #include <config/libraries.h>
 #include <database/styles.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 
 using namespace pugi;
 
@@ -30,10 +33,10 @@ class Editor_Html2Format
 public:
   void load (string html);
   void run ();
-  vector <string> texts;
-  vector <string> formats;
+  vector <string> texts {};
+  vector <string> formats {};
 private:
-  xml_document document; // DOMDocument holding the html.
+  xml_document document {}; // DOMDocument holding the html.
   void preprocess ();
   void postprocess ();
   void process ();
@@ -42,5 +45,5 @@ private:
   void closeElementNode (xml_node node);
   void openInline (string className);
   string update_quill_class (string classname);
-  string current_character_format;
+  string current_character_format {};
 };
