@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_EDITOR_STYLES_H
-#define INCLUDED_EDITOR_STYLES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Editor_Styles
 {
 public:
@@ -38,7 +35,3 @@ private:
   static string mono ();
   static string note ();
 };
-
-
-#endif
-
