@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,9 +32,11 @@
 #include <fonts/logic.h>
 #include <navigation/passage.h>
 #include <dialog/list.h>
+#include <dialog/list2.h>
 #include <ipc/focus.h>
 #include <menu/logic.h>
 #include <bb/logic.h>
+#include <workspace/logic.h>
 
 
 string editusfm_index_url ()
@@ -46,15 +48,14 @@ string editusfm_index_url ()
 bool editusfm_index_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return write;
 }
 
 
 string editusfm_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   bool touch = request->session_logic ()->touchEnabled ();
@@ -66,7 +67,15 @@ string editusfm_index (void * webserver_request)
     int book = convert_to_int (switchbook);
     int chapter = convert_to_int (switchchapter);
     Ipc_Focus::set (request, book, chapter, 1);
-    Navigation_Passage::recordHistory (request, book, chapter, 1);
+    Navigation_Passage::record_history (request, book, chapter, 1);
+  }
+
+
+  // Set the user chosen Bible as the current Bible.
+  if (request->post.count ("bibleselect")) {
+    string bibleselect = request->post ["bibleselect"];
+    request->database_config_user ()->setBible (bibleselect);
+    return string();
   }
   
   
@@ -78,30 +87,21 @@ string editusfm_index (void * webserver_request)
   if (touch) header.jQueryTouchOn ();
   header.notifItOn ();
   page = header.run ();
-  
-  if (request->query.count("changebible")) {
-    string changebible = request->query["changebible"];
-    if (changebible == "") {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Select which Bible to open in the editor"), "", "");
-      vector <string> bibles = access_bible_bibles (request);
-      for (auto & bible : bibles) {
-        dialog_list.add_row (bible, "changebible", bible);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      request->database_config_user()->setBible (changebible);
-    }
-  }
-
-  
   Assets_View view;
 
 
   // Get active Bible, and check read access to it.
+  // Or if the user have used query to preset the active Bible, get the preset Bible.
   // If needed, change Bible to one it has read access to.
-  string bible = access_bible_clamp (request, request->database_config_user()->getBible ());
-  if (request->query.count ("bible")) bible = access_bible_clamp (request, request->query ["bible"]);
+  // Set the chosen Bible on the option HTML tag.
+  string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
+  if (request->query.count ("bible")) bible = AccessBible::Clamp (request, request->query ["bible"]);
+  string bible_html;
+  vector <string> bibles = AccessBible::Bibles (request);
+  for (auto selectable_bible : bibles) {
+    bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
+  }
+  view.set_variable ("bibleoptags", Options_To_Select::mark_selected (bible, bible_html));
   view.set_variable ("bible", bible);
   
   
@@ -110,27 +110,31 @@ string editusfm_index (void * webserver_request)
   
   
   int verticalCaretPosition = request->database_config_user ()->getVerticalCaretPosition ();
-  string script =
-  "var usfmEditorChapterLoaded = \"" + locale_logic_text_loaded () + "\";\n"
-  "var usfmEditorWillSave = \"" + locale_logic_text_will_save () + "\";\n"
-  "var usfmEditorChapterSaving = \"" + locale_logic_text_saving () + "\";\n"
-  "var usfmEditorChapterSaved = \"" + locale_logic_text_saved () + "\";\n"
-  "var usfmEditorChapterRetrying = \"" + locale_logic_text_retrying () + "\";\n"
-  "var usfmEditorVerseUpdatedLoaded = '" + locale_logic_text_reload () + "';\n"
-  "var usfmEditorWriteAccess = true;\n"
-  "var verticalCaretPosition = " + convert_to_string (verticalCaretPosition) + ";\n";
+  stringstream ss;
+  ss << "var usfmEditorChapterLoaded = " << quoted(locale_logic_text_loaded ()) << ";" << endl;
+  ss << "var usfmEditorWillSave = " << quoted(locale_logic_text_will_save ()) << ";" << endl;
+  ss << "var usfmEditorChapterSaving = " << quoted(locale_logic_text_saving ()) << ";" << endl;
+  ss << "var usfmEditorChapterSaved = " << quoted(locale_logic_text_saved ()) << ";" << endl;
+  ss << "var usfmEditorChapterRetrying = " << quoted(locale_logic_text_retrying ()) << ";" << endl;
+  ss << "var usfmEditorVerseUpdatedLoaded = " << quoted(locale_logic_text_reload ()) << ";" << endl;
+  ss << "var usfmEditorWriteAccess = true;" << endl;
+  ss << "var verticalCaretPosition = " << verticalCaretPosition << ";" << endl;
+  string script = ss.str();
   config_logic_swipe_enabled (webserver_request, script);
   view.set_variable ("script", script);
   
 
   string cls = Filter_Css::getClass (bible);
-  string font = Fonts_Logic::getTextFont (bible);
+  string font = Fonts_Logic::get_text_font (bible);
+  int current_theme_index = request->database_config_user ()->getCurrentTheme ();
   int direction = Database_Config_Bible::getTextDirection (bible);
   int lineheight = Database_Config_Bible::getLineHeight (bible);
   int letterspacing = Database_Config_Bible::getLetterSpacing (bible);
+  view.set_variable ("editor_theme_color", Filter_Css::theme_picker (current_theme_index, 2));
+  view.set_variable ("active_editor_theme_color", Filter_Css::theme_picker (current_theme_index, 3));
   view.set_variable ("custom_class", cls);
-  view.set_variable ("custom_css", Filter_Css::getCss (cls,
-                                                             Fonts_Logic::getFontPath (font),
+  view.set_variable ("custom_css", Filter_Css::get_css (cls,
+                                                             Fonts_Logic::get_font_path (font),
                                                              direction,
                                                              lineheight,
                                                              letterspacing));
@@ -139,6 +143,9 @@ string editusfm_index (void * webserver_request)
   if (request->database_config_user ()->getFastEditorSwitchingAvailable ()) {
     view.enable_zone ("fastswitcheditor");
   }
+  if (config_logic_indonesian_cloud_free ()) {
+    view.enable_zone ("fastswitcheditor");
+  }
 
   page += view.render ("editusfm", "index");
   
