@@ -95,7 +95,7 @@ struct cstring {
 
 void init_string (struct cstring *s) {
   s->len = 0;
-  s->ptr = (char *) malloc(s->len+1);
+  s->ptr = static_cast<char *>(malloc(s->len+1));
   s->ptr[0] = '\0';
 }
 
@@ -103,7 +103,7 @@ void init_string (struct cstring *s) {
 size_t writefunc(void *ptr, size_t size, size_t nmemb, struct cstring *s)
 {
   size_t new_len = s->len + size*nmemb;
-  s->ptr = (char *) realloc (s->ptr, new_len+1);
+  s->ptr = static_cast<char *>(realloc (s->ptr, new_len+1));
   memcpy(s->ptr+s->len, ptr, size*nmemb);
   s->ptr[new_len] = '\0';
   s->len = new_len;
@@ -148,7 +148,7 @@ int email_receive_count (string& error, bool verbose)
 
   curl_easy_setopt (curl, CURLOPT_URL, url ().c_str());
 
-  curl_easy_setopt (curl, CURLOPT_USE_SSL, (long)CURLUSESSL_ALL);
+  curl_easy_setopt (curl, CURLOPT_USE_SSL, static_cast<long>(CURLUSESSL_ALL));
   curl_easy_setopt (curl, CURLOPT_SSL_VERIFYPEER, 0); 
   curl_easy_setopt (curl, CURLOPT_SSL_VERIFYHOST, 0); 
 
@@ -171,7 +171,7 @@ int email_receive_count (string& error, bool verbose)
   int mailcount = 0;
   
   if (res == CURLE_OK) {
-    string response = (char *) s.ptr;
+    string response = static_cast<char *>(s.ptr);
     response = filter_string_trim (response);
     mailcount = static_cast<int>(filter_string_explode (response, '\n').size());
   } else {
@@ -209,7 +209,7 @@ string email_receive_message (string& error)
   string message_url = url () + "/1";
   curl_easy_setopt (curl, CURLOPT_URL, message_url.c_str());
 
-  curl_easy_setopt (curl, CURLOPT_USE_SSL, (long)CURLUSESSL_ALL);
+  curl_easy_setopt (curl, CURLOPT_USE_SSL, static_cast<long>(CURLUSESSL_ALL));
   curl_easy_setopt (curl, CURLOPT_SSL_VERIFYPEER, 0); 
   curl_easy_setopt (curl, CURLOPT_SSL_VERIFYHOST, 0); 
 
@@ -227,7 +227,7 @@ string email_receive_message (string& error)
   string body;
   
   if (res == CURLE_OK) {
-    body = (char *) s.ptr;
+    body = static_cast<char *>(s.ptr);
   } else {
     error = curl_easy_strerror (res);
   }
