@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <filter/md5.h>
 #include <filter/date.h>
-#ifndef HAVE_CLIENT
+#ifdef HAVE_CLOUD
 #include <curl/curl.h>
 #endif
 #include <config/globals.h>
@@ -70,9 +70,9 @@ void email_send ()
 
     // In the Cloud, if this username was not found, it could be that the email was addressed to a non-user,
     // and that the To: address was actually contained in the username.
-    if (email == "") {
+    if (email.empty()) {
       email = username;
-      username = "";
+      username.clear();
     }
     
     // In the Cloud, if the email address validates, ok, else remove this mail from the queue and log the action.
@@ -83,17 +83,50 @@ void email_send ()
     }
 
 #endif
-  
+
+    // If there had been a crash while sending an email,
+    // log this email and erase it.
+    // Do not attempt to send it again as it would cause the crash again in an endless loop.
+    if (config_globals_has_crashed_while_mailing) {
+      database_mail.erase (id);
+      Database_Logs::log ("Email to " + email + " with subject \"" + subject + "\" was deleted because it has caused a crash");
+      config_globals_has_crashed_while_mailing = false;
+      continue;
+    }
+    
     // Send the email.
     string result = email_send (email, username, subject, body);
     if (result.empty ()) {
       database_mail.erase (id);
-      result = "Email to " + email + " with subject " + subject + " was sent successfully";
+      stringstream ss;
+      ss << "Email to " << email << " with subject " << quoted(subject) << " was ";
+      result = ss.str();
+#ifdef HAVE_CLOUD
+      result.append ("sent successfully");
+#endif
+#ifdef HAVE_CLIENT
+      result.append ("queued for sending through the Cloud");
+#endif
+      Database_Logs::log (result, Filter_Roles::manager ());
     } else {
-      database_mail.postpone (id);
+      // Special handling of cases that the smart host denied login.
+      bool login_denied = result == "Login denied";
+      // Write result to logbook.
       result.insert (0, "Email to " + email + " could not be sent - reason: ");
+      Database_Logs::log (result, Filter_Roles::manager ());
+      // If the login was denied, then postpone all emails queued for sending,
+      // rather than trying to send them all, and have them all cause a 'login denied' error.
+      if (login_denied) {
+        vector <int> ids = database_mail.getAllMails ();
+        for (auto id2 : ids) {
+          database_mail.postpone (id2);
+        }
+        Database_Logs::log ("Postponing sending " + convert_to_string (ids.size()) + " emails", Filter_Roles::manager ());
+        break;
+      } else {
+        database_mail.postpone (id);
+      }
     }
-    Database_Logs::log (result, Filter_Roles::manager ());
   }
   
   config_globals_mail_send_running = false;
@@ -104,7 +137,7 @@ static vector <string> payload_text;
 
 
 struct upload_status {
-  int lines_read;
+  size_t lines_read;
 };
 
 
@@ -112,14 +145,14 @@ struct upload_status {
 #else
 static size_t payload_source (void *ptr, size_t size, size_t nmemb, void *userp)
 {
-  struct upload_status *upload_ctx = (struct upload_status *)userp;
+  struct upload_status *upload_ctx = static_cast <struct upload_status *> (userp);
   const char *data;
 
   if((size == 0) || (nmemb == 0) || ((size*nmemb) < 1)) {
     return 0;
   }
   
-  if (upload_ctx->lines_read >= (int)payload_text.size()) {
+  if (upload_ctx->lines_read >= payload_text.size()) {
     return 0;
   }
 
@@ -137,10 +170,14 @@ static size_t payload_source (void *ptr, size_t size, size_t nmemb, void *userp)
 // Sends the email as specified by the parameters.
 // If all went well, it returns an empty string.
 // In case of failure, it returns the error message.
-string email_send (string to_mail, string to_name, string subject, string body, bool verbose)
+string email_send ([[maybe_unused]] string to_mail,
+                   string to_name,
+                   string subject,
+                   string body,
+                   [[maybe_unused]] bool verbose)
 {
   // Truncate huge emails because libcurl crashes on it.
-  int length = body.length ();
+  size_t length = body.length ();
   if (length > 100000) {
     body = "This email was " + convert_to_string (length) + " bytes long. It was too long, and could not be sent.";
   }
@@ -153,9 +190,6 @@ string email_send (string to_mail, string to_name, string subject, string body,
   if (!client_logic_client_enabled ()) {
     return "";
   }
-  
-  (void) verbose;
-  (void) to_mail;
 
   Webserver_Request request;
   Sync_Logic sync_logic = Sync_Logic (&request);
@@ -190,10 +224,10 @@ string email_send (string to_mail, string to_name, string subject, string body,
 
   upload_ctx.lines_read = 0;
 
-  int seconds = filter_date_seconds_since_epoch ();
+  int seconds = filter::date::seconds_since_epoch ();
   payload_text.clear();
   string payload;
-  payload = "Date: " + convert_to_string (filter_date_numerical_year (seconds)) + "/" + convert_to_string (filter_date_numerical_month (seconds)) + "/" + convert_to_string (filter_date_numerical_month_day (seconds)) + " " + convert_to_string (filter_date_numerical_hour (seconds)) + ":" + convert_to_string (filter_date_numerical_minute (seconds)) + "\n";
+  payload = "Date: " + convert_to_string (filter::date::numerical_year (seconds)) + "/" + convert_to_string (filter::date::numerical_month (seconds)) + "/" + convert_to_string (filter::date::numerical_month_day (seconds)) + " " + convert_to_string (filter::date::numerical_hour (seconds)) + ":" + convert_to_string (filter::date::numerical_minute (seconds)) + "\n";
   payload_text.push_back (payload);
   payload = "To: <" + to_mail + "> " + to_name + "\n";
   payload_text.push_back (payload);
@@ -207,7 +241,7 @@ string email_send (string to_mail, string to_name, string subject, string body,
   payload = "Subject: " + subject + "\n";
   payload_text.push_back (payload);
   payload_text.push_back ("Mime-version: 1.0\n");
-  payload_text.push_back ("Content-Type: multipart/alternative; boundary=\"------------010001060501040600060905\"");
+  payload_text.push_back (R"(Content-Type: multipart/alternative; boundary="------------010001060501040600060905")");
   // Empty line to divide headers from body, see RFC5322.
   payload_text.push_back ("\n");
   // Plain text part.
@@ -240,8 +274,10 @@ string email_send (string to_mail, string to_name, string subject, string body,
 
   curl = curl_easy_init();
   /* Set username and password */
-  curl_easy_setopt(curl, CURLOPT_USERNAME, Database_Config_General::getMailSendUsername().c_str());
-  curl_easy_setopt(curl, CURLOPT_PASSWORD, Database_Config_General::getMailSendPassword().c_str());
+  string username = Database_Config_General::getMailSendUsername();
+  string password = Database_Config_General::getMailSendPassword();
+  curl_easy_setopt(curl, CURLOPT_USERNAME, username.c_str());
+  curl_easy_setopt(curl, CURLOPT_PASSWORD, password.c_str());
 
   /* This is the URL for your mailserver. Note the use of port 587 here,
    * instead of the normal SMTP port (25). Port 587 is commonly used for
@@ -250,7 +286,8 @@ string email_send (string to_mail, string to_name, string subject, string body,
   string smtp = "smtp://";
   smtp.append (Database_Config_General::getMailSendHost());
   smtp.append (":");
-  smtp.append (Database_Config_General::getMailSendPort());
+  string port = Database_Config_General::getMailSendPort();
+  smtp.append (port);
   curl_easy_setopt(curl, CURLOPT_URL, smtp.c_str());
 
   /* In this example, we'll start with a plain text connection, and upgrade
@@ -258,7 +295,7 @@ string email_send (string to_mail, string to_name, string subject, string body,
    * of using CURLUSESSL_TRY here, because if TLS upgrade fails, the transfer
    * will continue anyway - see the security discussion in the libcurl
    * tutorial for more details. */
-  curl_easy_setopt(curl, CURLOPT_USE_SSL, (long)CURLUSESSL_ALL);
+  if (port != "25") curl_easy_setopt(curl, CURLOPT_USE_SSL, static_cast<long>(CURLUSESSL_ALL));
 
   /* If your server doesn't have a valid certificate, then you can disable
    * part of the Transport Layer Security protection by setting the
@@ -336,26 +373,34 @@ void email_schedule (string to, string subject, string body, int time)
 // If the email sending and receiving has not yet been (completely) set up,
 // it returns information about that.
 // If everything's OK, it returns nothing.
-string email_setup_information ()
+string email_setup_information (bool require_send, bool require_receive)
 {
+#ifdef HAVE_CLIENT
+  (void) require_send;
+  (void) require_receive;
+#endif
 #ifdef HAVE_CLOUD
-  int missing_items = 0;
-  if (Database_Config_General::getSiteMailName ().empty ()) missing_items++;
-  if (Database_Config_General::getSiteMailAddress ().empty ()) missing_items++;
-  if (Database_Config_General::getMailStorageHost ().empty ()) missing_items++;
-  if (Database_Config_General::getMailStorageUsername ().empty ()) missing_items++;
-  if (Database_Config_General::getMailStoragePassword ().empty ()) missing_items++;
-  if (Database_Config_General::getMailStorageProtocol ().empty ()) missing_items++;
-  if (Database_Config_General::getMailStoragePort ().empty ()) missing_items++;
-  if (Database_Config_General::getMailSendHost ().empty ()) missing_items++;
-  if (Database_Config_General::getMailSendUsername ().empty ()) missing_items++;
-  if (Database_Config_General::getMailSendPassword ().empty ()) missing_items++;
-  if (Database_Config_General::getMailSendPort ().empty ()) missing_items++;
-  if (missing_items) {
+  bool incomplete = false;
+  if (Database_Config_General::getSiteMailName ().empty ()) incomplete = true;
+  if (Database_Config_General::getSiteMailAddress ().empty ()) incomplete = true;
+  if (require_receive) {
+    if (Database_Config_General::getMailStorageHost ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailStorageUsername ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailStoragePassword ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailStorageProtocol ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailStoragePort ().empty ()) incomplete = true;
+  }
+  if (require_send) {
+    if (Database_Config_General::getMailSendHost ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailSendUsername ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailSendPassword ().empty ()) incomplete = true;
+    if (Database_Config_General::getMailSendPort ().empty ()) incomplete = true;
+  }
+  if (incomplete) {
     string msg1 = translate ("Cannot send email yet.");
     string msg2 = translate ("The emailer is not yet set up.");
-    return msg1 + " <a href=\"../" + email_index_url () + + "\">" + msg2 + "</a>";
+    return msg1 + R"( <a href="../)" + email_index_url () + + R"(">)" + msg2 + "</a>";
   }
 #endif
-  return "";
+  return string();
 }
