@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ESWORD_TEXT_H
-#define INCLUDED_ESWORD_TEXT_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Esword_Text
 {
 public:
@@ -37,13 +34,9 @@ public:
   void createModule (string filename);
   vector <string> get_sql ();
 private:
-  int currentBook;
-  int currentChapter;
-  int currentVerse;
-  string currentText;
-  vector <string> sql; // Contains the generated SQL.
+  int currentBook {0};
+  int currentChapter {0};
+  int currentVerse {0};
+  string currentText {};
+  vector <string> sql {}; // Contains the generated SQL.
 };
-
-
-#endif
-
