@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,11 +38,11 @@
 
 void export_esword (string bible, bool log)
 {
-  string directory = filter_url_create_path (Export_Logic::bibleDirectory (bible), "esword");
+  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "esword"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
-  string filename = filter_url_create_path (directory, "bible.bblx");
+  string filename = filter_url_create_path ({directory, "bible.bblx"});
 
   
   if (file_or_dir_exists (filename)) filter_url_unlink (filename);
@@ -61,9 +61,7 @@ void export_esword (string bible, bool log)
     vector <int> chapters = database_bibles.getChapters (bible, book);
     for (auto chapter : chapters) {
       string chapter_data = database_bibles.getChapter (bible, book, chapter);
-      chapter_data = usfm_remove_word_level_attributes (chapter_data);
-      chapter_data = filter_string_trim (chapter_data);
-      filter_text_bible.addUsfmCode (chapter_data);
+      filter_text_bible.add_usfm_code (chapter_data);
     }
   }
   filter_text_bible.run (stylesheet);
