@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <database/logs.h>
 #include <database/config/bible.h>
 #include <database/state.h>
+#include <database/bibleimages.h>
 #include <filter/url.h>
 #include <filter/string.h>
 #include <filter/roles.h>
@@ -41,34 +42,35 @@
 void export_html_book (string bible, int book, bool log)
 {
   // Create folders for the html export.
-  string directory = filter_url_create_path (Export_Logic::bibleDirectory (bible), "html");
+  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "html"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
   // Filename for the html file.
   string basename = Export_Logic::baseBookFileName (book);
-  string filename = filter_url_create_path (directory, basename + ".html");
-  string filecss = filter_url_create_path (directory, "stylesheet.css");
+  string filename_html = filter_url_create_path ({directory, basename + ".html"});
+  string stylesheet_css = filter_url_create_path ({directory, "stylesheet.css"});
   
   
   Database_Bibles database_bibles;
-  
+  Database_BibleImages database_bibleimages;
+
   
   string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
   
   
   // Create stylesheet.
   Styles_Sheets styles_sheets;
-  styles_sheets.create (stylesheet, filecss, false, bible);
+  styles_sheets.create (stylesheet, stylesheet_css, false, bible);
   
   
   // Copy font to the output directory.
-  string font = Fonts_Logic::getTextFont (bible);
+  string font = Fonts_Logic::get_text_font (bible);
   if (!font.empty ()) {
-    if (Fonts_Logic::fontExists (font)) {
-      string fontpath = Fonts_Logic::getFontPath (font);
+    if (Fonts_Logic::font_exists (font)) {
+      string fontpath = Fonts_Logic::get_font_path (font);
       string contents = filter_url_file_get_contents (fontpath);
-      fontpath = filter_url_create_path (directory, font);
+      fontpath = filter_url_create_path ({directory, font});
       filter_url_file_put_contents (fontpath, contents);
     }
   }
@@ -76,7 +78,10 @@ void export_html_book (string bible, int book, bool log)
   
   Filter_Text filter_text = Filter_Text (bible);
   filter_text.html_text_standard = new Html_Text (translate("Bible"));
-  filter_text.html_text_standard->customClass = Filter_Css::getClass (bible);
+  filter_text.html_text_standard->custom_class = Filter_Css::getClass (bible);
+  if (Database_Config_Bible::getExportHtmlNotesOnHover(bible)) {
+    filter_text.html_text_standard->have_popup_notes();
+  }
   
   
   // Load one book.
@@ -84,12 +89,9 @@ void export_html_book (string bible, int book, bool log)
   for (auto chapter : chapters) {
     // Get the USFM for this chapter.
     string usfm = database_bibles.getChapter (bible, book, chapter);
-    // Clean the word level attributes out.
-    usfm = usfm_remove_word_level_attributes (usfm);
-    // Trim it.
     usfm = filter_string_trim (usfm);
     // Use small chunks of USFM at a time for much better performance.
-    filter_text.addUsfmCode (usfm);
+    filter_text.add_usfm_code (usfm);
   }
   
   
@@ -97,10 +99,18 @@ void export_html_book (string bible, int book, bool log)
   filter_text.run (stylesheet);
   
   
-  // Save file.
-  filter_text.html_text_standard->save (filename);
+  // Save the html file.
+  filter_text.html_text_standard->save (filename_html);
   
   
+  // Save any images that were included.
+  for (auto src : filter_text.image_sources) {
+    string contents = database_bibleimages.get(src);
+    string filename = filter_url_create_path ({directory, src});
+    filter_url_file_put_contents(filename, contents);
+  }
+
+  
   // Clear the flag for this export.
   Database_State::clearExport (bible, book, Export_Logic::export_html);
 
