@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <database/logs.h>
 #include <database/state.h>
 #include <database/config/bible.h>
+#include <database/bibleimages.h>
 #include <filter/url.h>
 #include <filter/string.h>
 #include <filter/roles.h>
@@ -39,43 +40,42 @@
 void export_odt_book (string bible, int book, bool log)
 {
   // Create folders for the OpenDocument export.
-  string directory = filter_url_create_path (Export_Logic::bibleDirectory (bible), "opendocument");
+  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "opendocument"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
   // Filenames for the various types of OpenDocument files.
   string basename = Export_Logic::baseBookFileName (book);
-  string standardFilename = filter_url_create_path (directory, basename + "_standard.odt");
-  string textOnlyFilename = filter_url_create_path (directory, basename + "_text_only.odt");
-  string textAndCitationsFilename = filter_url_create_path (directory, basename + "_text_and_note_citations.odt");
-  string notesFilename = filter_url_create_path (directory, basename + "_notes.odt");
+  string standardFilename = filter_url_create_path ({directory, basename + "_standard.odt"});
+  string textOnlyFilename = filter_url_create_path ({directory, basename + "_text_only.odt"});
+  string textAndCitationsFilename = filter_url_create_path ({directory, basename + "_text_and_note_citations.odt"});
+  string notesFilename = filter_url_create_path ({directory, basename + "_notes.odt"});
 
   
   Database_Bibles database_bibles;
+  Database_BibleImages database_bibleimages;
   
   
   string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
   
   
   Filter_Text filter_text = Filter_Text (bible);
-  filter_text.odf_text_standard = new Odf_Text (bible);
-  filter_text.odf_text_text_only = new Odf_Text (bible);
-  filter_text.odf_text_text_and_note_citations = new Odf_Text (bible);
-  filter_text.odf_text_notes = new Odf_Text (bible);
+  filter_text.odf_text_standard = new odf_text (bible);
+  filter_text.odf_text_text_only = new odf_text (bible);
+  filter_text.odf_text_text_and_note_citations = new odf_text (bible);
+  filter_text.odf_text_notes = new odf_text (bible);
   
   
   if (book == 0) {
     // Load entire Bible, ordered.
     vector <int> books = filter_passage_get_ordered_books (bible);
-    for (auto book : books) {
-      vector <int> chapters = database_bibles.getChapters (bible, book);
+    for (auto book2 : books) {
+      vector <int> chapters = database_bibles.getChapters (bible, book2);
       for (auto chapter : chapters) {
-        string usfm = database_bibles.getChapter (bible, book, chapter);
-        // Filter it.
-        usfm = usfm_remove_word_level_attributes (usfm);
+        string usfm = database_bibles.getChapter (bible, book2, chapter);
         usfm = filter_string_trim (usfm);
         // Use small chunks of USFM at a time for much better performance.
-        filter_text.addUsfmCode (usfm);
+        filter_text.add_usfm_code (usfm);
       }
     }
   } else {
@@ -83,11 +83,9 @@ void export_odt_book (string bible, int book, bool log)
     vector <int> chapters = database_bibles.getChapters (bible, book);
     for (auto chapter : chapters) {
       string usfm = database_bibles.getChapter (bible, book, chapter);
-      // Filter it.
-      usfm = usfm_remove_word_level_attributes (usfm);
       usfm = filter_string_trim (usfm);
       // Use small chunks of USFM at a time for much better performance.
-      filter_text.addUsfmCode (usfm);
+      filter_text.add_usfm_code (usfm);
     }
   }
   
@@ -96,13 +94,18 @@ void export_odt_book (string bible, int book, bool log)
   filter_text.run (stylesheet);
   
   
-  // Save files.
+  // Save text files and optionally the images included in the text.
   filter_text.odf_text_standard->save (standardFilename);
   filter_text.odf_text_text_only->save (textOnlyFilename);
   filter_text.odf_text_text_and_note_citations->save (textAndCitationsFilename);
   filter_text.odf_text_notes->save (notesFilename);
-  
-  
+  for (auto src : filter_text.image_sources) {
+    string contents = database_bibleimages.get(src);
+    string path = filter_url_create_path ({directory, src});
+    filter_url_file_put_contents(path, contents);
+  }
+
+    
   // Securing the OpenDocument export implies that the exported files are zipped and secured with a password.
   // It uses the external zip binary.
   bool secure = Database_Config_Bible::getSecureOdtExport (bible);
