@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -39,11 +39,11 @@
 
 void export_onlinebible (string bible, bool log)
 {
-  string directory = filter_url_create_path (Export_Logic::bibleDirectory (bible), "onlinebible");
+  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "onlinebible"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
-  string filename = filter_url_create_path (directory, "bible.exp");
+  string filename = filter_url_create_path ({directory, "bible.exp"});
 
   
   Database_Bibles database_bibles;
@@ -59,9 +59,8 @@ void export_onlinebible (string bible, bool log)
     vector <int> chapters = database_bibles.getChapters (bible, book);
     for (auto chapter : chapters) {
       string chapter_data = database_bibles.getChapter (bible, book, chapter);
-      chapter_data = usfm_remove_word_level_attributes (chapter_data);
       chapter_data = filter_string_trim (chapter_data);
-      filter_text_bible.addUsfmCode (chapter_data);
+      filter_text_bible.add_usfm_code (chapter_data);
     }
   }
   filter_text_bible.run (stylesheet);
