@@ -1,3 +1,5 @@
+#pragma GCC system_header
+
 /**
  * Uri encode and decode (RFC1630, RFC1738, RFC2396)
  * http://www.codeguru.com/cpp/cpp/algorithms/strings/article.php/c12759/URI-Encoding-and-Decoding.htm
@@ -20,6 +22,10 @@
 
 #include <string>
 
+#pragma clang diagnostic ignored "-Wsign-conversion"
+#pragma clang diagnostic ignored "-Wimplicit-int-conversion"
+#pragma GCC diagnostic ignored "-Wconversion"
+
 #ifdef OLDCODE
 const char HEX2DEC[256] =
 {
