@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 // This function returns the directory of the git repository belonging to $object.
 string filter_git_directory (string object)
 {
-  return filter_url_create_root_path ("git", object);
+  return filter_url_create_root_path ({"git", object});
 }
 
 
@@ -67,10 +67,10 @@ void filter_git_commit_modification_to_git (string repository, string user, int
                                             string & oldusfm, string & newusfm)
 {
   string bookname = Database_Books::getEnglishFromId (book);
-  string bookdir = filter_url_create_path (repository, bookname);
-  string chapterdir = filter_url_create_path (bookdir, convert_to_string (chapter));;
+  string bookdir = filter_url_create_path ({repository, bookname});
+  string chapterdir = filter_url_create_path ({bookdir, convert_to_string (chapter)});
   if (!file_or_dir_exists (chapterdir)) filter_url_mkdir (chapterdir);
-  string datafile = filter_url_create_path (chapterdir, "data");
+  string datafile = filter_url_create_path ({chapterdir, "data"});
   string contents = filter_url_file_get_contents (datafile);
   if (contents != oldusfm) {
     filter_url_file_put_contents (datafile, oldusfm);
@@ -98,7 +98,7 @@ void filter_git_sync_modifications_to_git (string bible, string repository)
     
     bool iteration_initialized = false;
     string overall_old_usfm, overall_new_usfm;
-    int overall_book, overall_chapter;
+    int overall_book = 0, overall_chapter = 0;
     
     // Go through all the rowids for the user and the Bible.
     vector <int> rowids = Database_Git::get_rowids (user, bible);
@@ -153,7 +153,7 @@ void filter_git_sync_modifications_to_git (string bible, string repository)
 // This speeds up the filter.
 void filter_git_sync_bible_to_git (void * webserver_request, string bible, string repository)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   // First stage.
   // Read the chapters in the git repository,
@@ -162,24 +162,24 @@ void filter_git_sync_bible_to_git (void * webserver_request, string bible, strin
   vector <int> books = request->database_bibles()->getBooks (bible);
   vector <string> bookfiles = filter_url_scandir (repository);
   for (auto & bookname : bookfiles) {
-    string path = filter_url_create_path (repository, bookname);
+    string path = filter_url_create_path ({repository, bookname});
     if (filter_url_is_dir (path)) {
       int book = Database_Books::getIdFromEnglish (bookname);
       if (book) {
         if (in_array (book, books)) {
           // Book exists in the database: Check the chapters.
           vector <int> chapters = request->database_bibles()->getChapters (bible, book);
-          vector <string> chapterfiles = filter_url_scandir (filter_url_create_path (repository, bookname));
+          vector <string> chapterfiles = filter_url_scandir (filter_url_create_path ({repository, bookname}));
           for (auto & chaptername : chapterfiles) {
-            string path = filter_url_create_path (repository, bookname, chaptername);
-            if (filter_url_is_dir (path)) {
+            string chapter_path = filter_url_create_path ({repository, bookname, chaptername});
+            if (filter_url_is_dir (chapter_path)) {
               if (filter_string_is_numeric (chaptername)) {
                 int chapter = convert_to_int (chaptername);
-                string filename = filter_url_create_path (repository, bookname, chaptername, "data");
+                string filename = filter_url_create_path ({repository, bookname, chaptername, "data"});
                 if (file_or_dir_exists (filename)) {
                   if (!in_array (chapter, chapters)) {
                     // Chapter does not exist in the database.
-                    filter_url_rmdir (filter_url_create_path (repository, bookname, chaptername));
+                    filter_url_rmdir (filter_url_create_path ({repository, bookname, chaptername}));
                   }
                 }
               }
@@ -187,7 +187,7 @@ void filter_git_sync_bible_to_git (void * webserver_request, string bible, strin
           }
         } else {
           // Book does not exist in the database: Remove it from $git.
-          filter_url_rmdir (filter_url_create_path (repository, bookname));
+          filter_url_rmdir (filter_url_create_path ({repository, bookname}));
         }
       }
     }
@@ -200,13 +200,13 @@ void filter_git_sync_bible_to_git (void * webserver_request, string bible, strin
   books = request->database_bibles()->getBooks (bible);
   for (auto & book : books) {
     string bookname = Database_Books::getEnglishFromId (book);
-    string bookdir = filter_url_create_path (repository, bookname);
+    string bookdir = filter_url_create_path ({repository, bookname});
     if (!file_or_dir_exists (bookdir)) filter_url_mkdir (bookdir);
     vector <int> chapters = request->database_bibles()->getChapters (bible, book);
     for (auto & chapter : chapters) {
-      string chapterdir = filter_url_create_path (bookdir, convert_to_string (chapter));;
+      string chapterdir = filter_url_create_path ({bookdir, convert_to_string (chapter)});
       if (!file_or_dir_exists (chapterdir)) filter_url_mkdir (chapterdir);
-      string datafile = filter_url_create_path (chapterdir, "data");
+      string datafile = filter_url_create_path ({chapterdir, "data"});
       string contents = filter_url_file_get_contents (datafile);
       string usfm = request->database_bibles()->getChapter (bible, book, chapter);
       if (contents != usfm) filter_url_file_put_contents (datafile, usfm);
@@ -223,7 +223,7 @@ void filter_git_sync_bible_to_git (void * webserver_request, string bible, strin
 // This speeds up the filter.
 void filter_git_sync_git_to_bible (void * webserver_request, string repository, string bible)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   // Stage one:
   // Read the chapters in the git repository,
@@ -232,7 +232,7 @@ void filter_git_sync_git_to_bible (void * webserver_request, string repository,
   // This stage does not check the contents of the chapters.
   vector <string> bookfiles = filter_url_scandir (repository);
   for (auto & bookname : bookfiles) {
-    string bookpath = filter_url_create_path (repository, bookname);
+    string bookpath = filter_url_create_path ({repository, bookname});
     if (filter_url_is_dir (bookpath)) {
       int book = Database_Books::getIdFromEnglish (bookname);
       if (book) {
@@ -240,11 +240,11 @@ void filter_git_sync_git_to_bible (void * webserver_request, string repository,
         vector <int> chapters = request->database_bibles()->getChapters (bible, book);
         vector <string> chapterfiles = filter_url_scandir (bookpath);
         for (auto & chapterfile : chapterfiles) {
-          string chapterpath = filter_url_create_path (bookpath, chapterfile);
+          string chapterpath = filter_url_create_path ({bookpath, chapterfile});
           if (filter_url_is_dir (chapterpath)) {
             if (filter_string_is_numeric (chapterfile)) {
               int chapter = convert_to_int (chapterfile);
-              string filename = filter_url_create_path (chapterpath, "data");
+              string filename = filter_url_create_path ({chapterpath, "data"});
               if (file_or_dir_exists (filename)) {
                 if (!in_array (chapter, chapters)) {
                   // Chapter does not exist in the database: Add it.
@@ -273,13 +273,13 @@ void filter_git_sync_git_to_bible (void * webserver_request, string repository,
   vector <int> books = request->database_bibles()->getBooks (bible);
   for (auto & book : books) {
     string bookname = Database_Books::getEnglishFromId (book);
-    string bookdir = filter_url_create_path (repository, bookname);
+    string bookdir = filter_url_create_path ({repository, bookname});
     if (file_or_dir_exists (bookdir)) {
       vector <int> chapters = request->database_bibles()->getChapters (bible, book);
       for (auto & chapter : chapters) {
-        string chapterdir = filter_url_create_path (bookdir, convert_to_string (chapter));
+        string chapterdir = filter_url_create_path ({bookdir, convert_to_string (chapter)});
         if (file_or_dir_exists (chapterdir)) {
-          string datafile = filter_url_create_path (chapterdir, "data");
+          string datafile = filter_url_create_path ({chapterdir, "data"});
           string contents = filter_url_file_get_contents (datafile);
           string usfm = request->database_bibles()->getChapter (bible, book, chapter);
           if (contents != usfm) {
@@ -313,7 +313,7 @@ void filter_git_sync_git_chapter_to_bible (string repository, string bible, int
 {
   // Filename for the chapter.
   string bookname = Database_Books::getEnglishFromId (book);
-  string filename = filter_url_create_path (repository, bookname, convert_to_string (chapter), "data");
+  string filename = filter_url_create_path ({repository, bookname, convert_to_string (chapter), "data"});
   
   if (file_or_dir_exists (filename)) {
     
@@ -346,10 +346,8 @@ bool filter_git_remote_read (string url, string & error)
 }
 
 
-bool filter_git_remote_clone (string url, string path, int jobid, string & error)
+bool filter_git_remote_clone (string url, string path, [[maybe_unused]] int jobid, string & error)
 {
-  (void) jobid;
-
   // Clear a possible existing git repository directory.
   filter_url_rmdir (path);
 
@@ -378,10 +376,12 @@ bool filter_git_commit (string repository, string user, string message,
 {
   user = filter_git_user (user);
   string email = filter_git_email (user);
+  stringstream author;
+  author << "--author=" << quoted(user + " <" + email + ">");
   string out, err;
   int result = filter_shell_run (repository, "git",
                                 {"commit",
-                                 "--author=\"" + user + " <" + email + ">\"",
+                                 author.str(),
                                  "-a",
                                  "-m",
                                  message
@@ -462,8 +462,8 @@ Passage filter_git_get_passage (string line)
         int chapter = convert_to_int (bits [1]);
         string data = bits [2];
         if (data.find ("data") != string::npos) {
-          passage.book = book;
-          passage.chapter = chapter;
+          passage.m_book = book;
+          passage.m_chapter = chapter;
         }
       }
     }
@@ -474,12 +474,15 @@ Passage filter_git_get_passage (string line)
 
 // Reports information comparable to "git status".
 // Repository: "repository".
+// If $porcelain is given, it adds the --porcelain flag.
 // All changed files will be returned.
-vector <string> filter_git_status (string repository)
+vector <string> filter_git_status (string repository, bool porcelain)
 {
   vector <string> paths;
   string output, error;
-  filter_shell_run (repository, "git", {"status"}, &output, &error);
+  vector <string> parameters = {"status"};
+  if (porcelain) parameters.push_back("--porcelain");
+  filter_shell_run (repository, "git", parameters, &output, &error);
   filter_git_check_error (error);
   paths = filter_string_explode (output, '\n');
   return paths;
@@ -528,45 +531,46 @@ bool filter_git_resolve_conflicts (string repository, vector <string> & paths, s
   paths.clear();
 
   // Get the unmerged paths.
+  // Use the --porcelain parameter for a better API for scripting.
   vector <string> unmerged_paths;
-  vector <string> lines = filter_git_status (repository);
-  for (auto & line : lines) {
-    if (line.find ("both modified:") != string::npos) {
-      line = filter_string_trim (line);
-      line.erase (0, 15);
+  vector <string> lines = filter_git_status (repository, true);
+  for (auto line : lines) {
+    size_t pos = line.find ("UU ");
+    if (pos != string::npos) {
+      line.erase (0, 3);
       line = filter_string_trim (line);
       unmerged_paths.push_back (line);
     }
   }
-  
+
   // Deal with each unmerged path.
   for (auto & unmerged_path : unmerged_paths) {
-
+    
     string common_ancestor;
     filter_shell_run (repository, "git", {"show", ":1:" + unmerged_path}, &common_ancestor, &error);
 
     string head_version;
     filter_shell_run (repository, "git", {"show", ":2:" + unmerged_path}, &head_version, &error);
-    
+
     string merge_head_version;
     filter_shell_run (repository, "git", {"show", ":3:" + unmerged_path}, &merge_head_version, &error);
-    
+
     string mergeBase (common_ancestor);
     string userData (head_version);
     string serverData (merge_head_version);
     
-    vector <tuple <string, string, string, string, string>> conflicts;
+    vector <Merge_Conflict> conflicts;
     string mergedData = filter_merge_run (mergeBase, userData, serverData, true, conflicts);
     mergedData = filter_string_trim (mergedData);
-    filter_url_file_put_contents (filter_url_create_path (repository, unmerged_path), mergedData);
+    filter_url_file_put_contents (filter_url_create_path ({repository, unmerged_path}), mergedData);
     
     paths.push_back (unmerged_path);
   }
 
   if (!unmerged_paths.empty ()) {
     vector <string> messages;
-    string error;
-    filter_git_commit (repository, "", translate ("Bibledit fixed merge conflicts"), messages, error);
+    string error2;
+    filter_git_commit (repository, "", translate ("Bibledit fixed merge conflicts"), messages, error2);
   }
   
   // Done.
@@ -579,7 +583,7 @@ void filter_git_config (string repository)
 {
   // At times there's a stale index.lock file that prevents any collaboration.
   // This is to be removed.
-  string index_lock = filter_url_create_path (repository, ".git", "index.lock");
+  string index_lock = filter_url_create_path ({repository, ".git", "index.lock"});
   if (file_or_dir_exists (index_lock)) {
     Database_Logs::log ("Cleaning out index lock " + index_lock);
     filter_url_unlink (index_lock);
@@ -601,6 +605,10 @@ void filter_git_config (string repository)
 
   // Current versions of git ask the user to set the default push method.
   filter_git_config_set_string (repository, "push.default", "matching");
+  
+  // Newer version of git do not automatically fast-forward, so set that here.
+  filter_git_config_set_string (repository, "pull.ff", "yes");
+
 }
 
 
