@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -18,14 +18,22 @@
 
 
 #include <filter/merge.h>
+#pragma GCC diagnostic push
+#pragma clang diagnostic ignored "-Wsign-conversion"
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wold-style-cast"
 #include <dtl/dtl.hpp>
-using dtl::Diff3;
+#pragma GCC diagnostic pop
 #include <filter/string.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 #include <email/send.h>
 #include <filter/usfm.h>
 
 
+using dtl::Diff3;
 using namespace pugi;
 
 
@@ -104,7 +112,10 @@ string filter_merge_graphemes2lines (string data)
 }
 
 
-void filter_merge_detect_conflict (string base, string change, string prioritized_change, string result,
+void filter_merge_detect_conflict (string base,
+                                   string change,
+                                   string prioritized_change,
+                                   string result,
                                    vector <Merge_Conflict> & conflicts)
 {
   // Clean input.
@@ -150,7 +161,7 @@ void filter_merge_detect_conflict (string base, string change, string prioritize
       irregularity = true;
     }
   }
-  
+
   if (irregularity) {
     Merge_Conflict conflict;
     conflict.base = base;
@@ -249,7 +260,7 @@ string filter_merge_run_clever (string base, string change, string prioritized_c
                                 vector <Merge_Conflict> & conflicts)
 {
   // Get the verse numbers in the changed text.
-  vector <int> verses = usfm_get_verse_numbers (change);
+  vector <int> verses = filter::usfm::get_verse_numbers (change);
   
   vector <string> results;
   
@@ -259,9 +270,9 @@ string filter_merge_run_clever (string base, string change, string prioritized_c
   for (auto verse : verses) {
     
     // Gets the texts to merge for this verse.
-    string base_text = usfm_get_verse_text (base, verse);
-    string change_text = usfm_get_verse_text (change, verse);
-    string prioritized_change_text = usfm_get_verse_text (prioritized_change, verse);
+    string base_text = filter::usfm::get_verse_text (base, verse);
+    string change_text = filter::usfm::get_verse_text (change, verse);
+    string prioritized_change_text = filter::usfm::get_verse_text (prioritized_change, verse);
     
     // Check for combined verses.
     if (change_text == previous_change) continue;
@@ -293,3 +304,12 @@ string filter_merge_run_clever (string base, string change, string prioritized_c
   // Done.
   return filter_string_implode (results, "\n");
 }
+
+
+void filter_merge_add_book_chapter (vector <Merge_Conflict> & conflicts, int book, int chapter)
+{
+  for (auto & conflict : conflicts) {
+    conflict.book = book;
+    conflict.chapter = chapter;
+  }
+}
