@@ -28,29 +28,23 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <text/text.h>
 #include <esword/text.h>
 #include <tbsx/text.h>
+#include <filter/note.h>
 
 
-class Filter_Text_Passage_Marker_Value
+namespace filter::text {
+
+class passage_marker_value
 {
 public:
-  Filter_Text_Passage_Marker_Value (int book_in, int chapter_in, string verse_in, string marker_in, string value_in);
-  int book;
-  int chapter;
-  string verse;
-  string marker;
-  string value;
+  passage_marker_value (int book, int chapter, string verse, string marker, string value);
+  int m_book {0};
+  int m_chapter {0};
+  string m_verse {};
+  string m_marker {};
+  string m_value {};
 };
 
-
-class Filter_Text_Note_Citation
-{
-public:
-  Filter_Text_Note_Citation ();
-  Filter_Text_Note_Citation (vector <string> sequence_in, string restart_in);
-  vector <string> sequence;
-  string restart;
-  unsigned int pointer;
-};
+}
 
 
 class Filter_Text
@@ -58,16 +52,18 @@ class Filter_Text
 public:
   Filter_Text (string bible_in);
   ~Filter_Text ();
-
+  Filter_Text(const Filter_Text&) = delete;
+  Filter_Text operator=(const Filter_Text&) = delete;
+  
 private:
-  string bible;
+  string bible {};
 
 public:
   void add_usfm_code (string usfm);
 private:
   // Container holding USFM, alternating between markup and text.
-  vector <string> usfmMarkersAndText;
-  unsigned int usfmMarkersAndTextPointer;
+  vector <string> usfmMarkersAndText {};
+  unsigned int usfmMarkersAndTextPointer {0};
   bool unprocessedUsfmCodeAvailable ();
   void getUsfmNextChapter ();
   
@@ -75,163 +71,162 @@ public:
   void run (string stylesheet);
 private:
   // Container holding a chapter of USFM code, alternating between USFM and text.
-  vector <string> chapter_usfm_markers_and_text;
-  unsigned int chapter_usfm_markers_and_text_pointer;
+  vector <string> chapter_usfm_markers_and_text {};
+  unsigned int chapter_usfm_markers_and_text_pointer {0};
 
 public:
   void getStyles (string stylesheet);
 private:
   // A map of marker -> object with style information.
-  map <string, Database_Styles_Item> styles;
+  map <string, Database_Styles_Item> styles {};
   // Usually this is: c
-  string chapterMarker;
+  string chapterMarker {};
   // Array holding styles created in Odf_Text class.
-  vector <string> createdStyles;
+  vector <string> createdStyles {};
 
 public:
   void pre_process_usfm ();
 private:
   // Book identifier, e.g. 1, 2, 3, and so on.
-  int currentBookIdentifier;
+  int currentBookIdentifier {0};
   // Chapter number, e.g. 1, 2, 3, etc.
-  int currentChapterNumber;
+  int currentChapterNumber {0};
   // Verse number, e.g. "0", "1", "2", and so on.
-  string currentVerseNumber;
+  string currentVerseNumber {};
   string getCurrentPassageText ();
   // Map of (book, chapter number).
-  map <int, int> numberOfChaptersPerBook;
+  map <int, int> numberOfChaptersPerBook {};
   void process_usfm ();
   void processNote ();
   // Opening a new paragraph.
-  void new_paragraph (Database_Styles_Item style, bool keepWithNext);
+  void new_paragraph (const Database_Styles_Item & style, bool keepWithNext);
   void applyDropCapsToCurrentParagraph (int dropCapsLength);
   void putChapterNumberInFrame (string chapterText);
-  void createNoteCitation (Database_Styles_Item style);
-  string getNoteCitation (Database_Styles_Item style);
-  void resetNoteCitations (string moment);
-  void ensureNoteParagraphStyle (string marker, Database_Styles_Item style);
+  string getNoteCitation (const Database_Styles_Item & style);
+  void ensureNoteParagraphStyle (string marker, const Database_Styles_Item & style);
 
 public:
   // Container with objects (book, chapter, verse, marker, header value).
-  vector <Filter_Text_Passage_Marker_Value> runningHeaders;
+  vector <filter::text::passage_marker_value> runningHeaders {};
   // Container with objects (book, chapter, verse, marker, TOC value).
-  vector <Filter_Text_Passage_Marker_Value> longTOCs;
+  vector <filter::text::passage_marker_value> longTOCs {};
   // Container with objects (book, chapter, verse, marker, TOC value).
-  vector <Filter_Text_Passage_Marker_Value> shortTOCs;
+  vector <filter::text::passage_marker_value> shortTOCs {};
   // Container with objects (book, chapter, verse, marker, abbreviation value).
-  vector <Filter_Text_Passage_Marker_Value> bookAbbreviations;
+  vector <filter::text::passage_marker_value> bookAbbreviations {};
 
 public:
   // Vector with objects (book, chapter, verse, marker, label value).
-  vector <Filter_Text_Passage_Marker_Value> chapterLabels;
+  vector <filter::text::passage_marker_value> chapterLabels {};
   // Vector with object (book, chapter, verse, marker, marker value).
-  vector <Filter_Text_Passage_Marker_Value> publishedChapterMarkers;
+  vector <filter::text::passage_marker_value> publishedChapterMarkers {};
   // Vector with object (book, chapter, verse, marker, marker value).
-  vector <Filter_Text_Passage_Marker_Value> publishedVerseMarkers;
+  vector <filter::text::passage_marker_value> publishedVerseMarkers {};
 private:
   // String holding the chapter number or text to output at the first verse.
-  string output_chapter_text_at_first_verse;
+  string output_chapter_text_at_first_verse {};
 
 public:
   // Object for creating OpenDocument with text in standard form.
-  Odf_Text * odf_text_standard;
+  odf_text * odf_text_standard {nullptr};
   // Object for creating OpenDocument with text only.
-  Odf_Text * odf_text_text_only;
+  odf_text * odf_text_text_only {nullptr};
   // Object for creating OpenDocument with text and note citations.
-  Odf_Text * odf_text_text_and_note_citations;
+  odf_text * odf_text_text_and_note_citations {nullptr};
   // Object for creating OpenDocument with the notes only.
-  Odf_Text * odf_text_notes;
+  odf_text * odf_text_notes {nullptr};
 
 public:
   void produceInfoDocument (string path);
   void produceFalloutDocument (string path);
-  vector <string> info;
-  vector <string> fallout;
+  vector <string> info {};
+  vector <string> fallout {};
 private:
   void addToInfo (string text, bool next = false);
   void addToFallout (string text, bool next = false);
-  void addToWordList (vector <string>  & list);
-  vector <string> wordListGlossaryDictionary;
-  vector <string> hebrewWordList;
-  vector <string> greekWordList;
-  vector <string> subjectIndex;
+  void addToWordList (vector <string> & list);
+  vector <string> wordListGlossaryDictionary {};
+  vector <string> hebrewWordList {};
+  vector <string> greekWordList {};
+  vector <string> subjectIndex {};
 
 private:
-  map <string, Filter_Text_Note_Citation> notecitations; // Information for the citations for the notes.
-  string standardContentMarkerFootEndNote;
-  string standardContentMarkerCrossReference;
+  // Information for the citations for the notes.
+  filter::note::citations note_citations {};
+
+  string standardContentMarkerFootEndNote {};
+  string standardContentMarkerCrossReference {};
 
 public:
   // Object for creating standard web documents.
-  Html_Text * html_text_standard;
+  Html_Text * html_text_standard {nullptr};
   // Object for creating interlinked web documents.
-  Html_Text * html_text_linked;
+  Html_Text * html_text_linked {nullptr};
 
 public:
   // Object for creating the input file for the Online Bible compiler.
-  OnlineBible_Text * onlinebible_text;
+  OnlineBible_Text * onlinebible_text {nullptr};
 
 public:
   // Object for creating the Bible module for eSword.
-  Esword_Text * esword_text;
+  Esword_Text * esword_text {nullptr};
 
 public:
   // Object for exporting to plain text.
-  Text_Text * text_text;
+  Text_Text * text_text { nullptr };
 
 public:
   // Object for exporting to TBS online bible format.
-  Tbsx_Text * tbsx_text;
+  Tbsx_Text * tbsx_text { nullptr };
   
 public:
   void initializeHeadingsAndTextPerVerse (bool start_text_now);
   map <int, string> getVersesText ();
   // Vector with objects to hold verse numbers and the text of the headings.
-  map <int, string> verses_headings;
+  map <int, string> verses_headings {};
   // Markers that started the above paragraph start positions.
-  vector <string> paragraph_starting_markers;
+  vector <string> paragraph_starting_markers {};
   // Complete paragraphs keyed to verse numbers.
-  vector <map <int, string>> verses_paragraphs;
+  vector <map <int, string>> verses_paragraphs {};
 private:
   // Flags for headings per verse processor.
-  bool headings_text_per_verse_active;
-  bool heading_started;
+  bool headings_text_per_verse_active { false };
+  bool heading_started  { false };
   // Holds verse numbers and the plain text in that verse, without anything extra.
-  map <int, string> verses_text;
+  map <int, string> verses_text {};
   // Flag for text per verse processor.
-  bool text_started;
+  bool text_started {false};
   void storeVersesParagraphs ();
-  map <int, string> actual_verses_paragraph;
-
+  map <int, string> actual_verses_paragraph {};
   
 private:
-  string space_type_after_verse; // The type of space to follow a verse number.
-  map <int, bool> book_has_chapter_label; // Whether \cl was found in the book.
+  string space_type_after_verse {}; // The type of space to follow a verse number.
+  map <int, bool> book_has_chapter_label {}; // Whether \cl was found in the book.
   
 public:
   // The notes plain text.
-  vector <pair <string, string> > notes_plain_text;
+  vector <pair <string, string> > notes_plain_text {};
   // Holds the positions of the notes in the plain text, keyed to the verse numbers.
-  map <int, vector <int>> verses_text_note_positions;
+  map <int, vector <int>> verses_text_note_positions {};
 private:
   // Flag to keep track of open note.
-  bool note_open_now = false;
+  bool note_open_now { false };
   // The joined fragments.
-  string notes_plain_text_buffer;
+  string notes_plain_text_buffer {};
   // Handler.
   void notes_plain_text_handler ();
   
 public:
   // The images that have been encountered to use.
-  vector <string> image_sources;
+  vector <string> image_sources {};
 private:
   // Flag for whether the processor is now within figure markup.
-  bool is_within_figure_markup = false;
+  bool is_within_figure_markup { false };
   
 public:
 private:
   // Flag for whether to left-align certain poetry styles
   // in exports to OpenDocument format.
-  bool odt_left_align_verse_in_poetry_styles = false;
+  bool odt_left_align_verse_in_poetry_styles { false };
   
 };
