@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/date.h>
 #include <database/books.h>
 #include <database/logs.h>
-#ifndef HAVE_CLIENT
+#ifdef HAVE_CLOUD
 #include <curl/curl.h>
 #endif
 #include <mbedtls/net_sockets.h>
@@ -42,6 +42,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #endif
 
 
+// Internal function declarations.
+vector <string> filter_url_scandir_internal (string folder);
+string filter_url_dirname_internal (string url, const char * separator);
+string filter_url_basename_internal (string url, const char * separator);
+size_t filter_url_curl_write_function (void *ptr, size_t size, size_t count, void *stream);
+void filter_url_curl_debug_dump (const char *text, FILE *stream, unsigned char *ptr, size_t size);
+#ifdef HAVE_CLOUD
+int filter_url_curl_trace (CURL *handle, curl_infotype type, char *data, size_t size, void *userp);
+#endif
+
+
 // SSL/TLS globals.
 mbedtls_entropy_context filter_url_mbed_tls_entropy;
 mbedtls_ctr_drbg_context filter_url_mbed_tls_ctr_drbg;
@@ -635,9 +646,9 @@ string filter_url_file_get_contents(string filename)
     streamoff filesize = ifs.tellg();
     if (filesize == 0) return string();
     ifs.seekg(0, ios::beg);
-    vector <char> bytes((int)filesize);
-    ifs.read(&bytes[0], (int)filesize);
-    return string(&bytes[0], (int)filesize);
+    vector <char> bytes(static_cast<int> (filesize));
+    ifs.read(&bytes[0], static_cast<int> (filesize));
+    return string(&bytes[0], static_cast<int> (filesize));
   }
   catch (...) {
     return string();
@@ -739,7 +750,7 @@ int filter_url_filesize (string filename)
   struct stat buf;
   int rc = stat (filename.c_str (), &buf);
 #endif
-  return rc == 0 ? (int)(buf.st_size) : 0;
+  return rc == 0 ? static_cast<int> (buf.st_size) : 0;
 }
 
 
@@ -852,7 +863,7 @@ const char * filter_url_temp_dir ()
 // Returns the name of a temporary file.
 string filter_url_tempfile (const char * directory)
 {
-  string filename = convert_to_string (filter_date_seconds_since_epoch ()) + convert_to_string (filter_date_numerical_microseconds ()) + convert_to_string (filter_string_rand (10000000, 99999999));
+  string filename = convert_to_string (filter::date::seconds_since_epoch ()) + convert_to_string (filter::date::numerical_microseconds ()) + convert_to_string (filter_string_rand (10000000, 99999999));
   if (directory) {
     filename = filter_url_create_path ({directory, filename});
   } else {
@@ -927,7 +938,7 @@ string filter_url_build_http_query (string url, const string& parameter, const s
 
 size_t filter_url_curl_write_function (void *ptr, size_t size, size_t count, void *stream)
 {
-  ((string *) stream)->append ((char *) ptr, 0, size * count);
+  static_cast<string *>(stream)->append (static_cast<char *>(ptr), 0, size * count);
   return size * count;
 }
 
@@ -957,7 +968,7 @@ string filter_url_http_get (string url, string& error, [[maybe_unused]] bool che
       long http_code = 0;
       curl_easy_getinfo (curl, CURLINFO_RESPONSE_CODE, &http_code);
       if (http_code != 200) {
-        response.append ("http code " + convert_to_string ((int)http_code));
+        response.append ("http code " + convert_to_string (static_cast<int>(http_code)));
       }
     } else {
       response.clear ();
@@ -970,16 +981,89 @@ string filter_url_http_get (string url, string& error, [[maybe_unused]] bool che
 }
 
 
+// The debug function for libcurl, it dumps the data as specified.
+void filter_url_curl_debug_dump (const char *text, FILE *stream, unsigned char *ptr, size_t size)
+{
+  size_t i;
+  size_t c;
+  unsigned int width = 0x10;
+  
+  fprintf(stream, "%s, %10.10ld bytes (0x%8.8lx)\n", text, (long)size, (long)size);
+  
+  for (i = 0; i < size; i += width) {
+    fprintf(stream, "%4.4lx: ", (long)i);
+    
+    // Show hex to the left.
+    for (c = 0; c < width; c++) {
+      if (i + c < size) fprintf (stream, "%02x ", ptr[i + c]);
+      else fputs("   ", stream);
+    }
+    
+    // Show data on the right.
+    for (c = 0; (c < width) && (i + c < size); c++) {
+      char x = (ptr[i + c] >= 0x20 && ptr[i + c] < 0x80) ? ptr[i + c] : '.';
+      fputc (x, stream);
+    }
+
+    // Newline.
+    fputc ('\n', stream);
+  }
+}
+
+
+// The trace function for libcurl.
+#ifdef HAVE_CLOUD
+int filter_url_curl_trace (CURL *handle, curl_infotype type, char *data, size_t size, void *userp)
+{
+  const char *text;
+
+  // Prevent compiler warnings.
+  (void)handle;
+  (void)userp;
+  
+  switch (type) {
+    case CURLINFO_TEXT:
+      fprintf(stderr, "== Info: %s", data);
+    default: /* in case a new one is introduced to shock us */
+      return 0;
+      
+    case CURLINFO_HEADER_OUT:
+      text = "=> Send header";
+      break;
+    case CURLINFO_DATA_OUT:
+      text = "=> Send data";
+      break;
+    case CURLINFO_SSL_DATA_OUT:
+      text = "=> Send SSL data";
+      break;
+    case CURLINFO_HEADER_IN:
+      text = "<= Recv header";
+      break;
+    case CURLINFO_DATA_IN:
+      text = "<= Recv data";
+      break;
+    case CURLINFO_SSL_DATA_IN:
+      text = "<= Recv SSL data";
+      break;
+  }
+  
+  filter_url_curl_debug_dump(text, stderr, (unsigned char *)data, size);
+  return 0;
+}
+#endif
+
+
 // Sends a http POST request to $url.
 // burst: Set connection timing for burst mode, where the response comes after a relatively long silence.
-// It posts the $values.
+// It posts the $post_data as-t.
+// It appends the $values to the post data.
 // It returns the response from the server.
 // It writes any error to $error.
-string filter_url_http_post (string url, map <string, string> values, string& error, [[maybe_unused]] bool burst, [[maybe_unused]] bool check_certificate)
+string filter_url_http_post (const string & url, [[maybe_unused]] string post_data, const map <string, string> & post_values, string& error, [[maybe_unused]] bool burst, [[maybe_unused]] bool check_certificate, [[maybe_unused]] const vector <pair <string, string> > & headers)
 {
   string response;
 #ifdef HAVE_CLIENT
-  response = filter_url_http_request_mbed (url, error, values, "", check_certificate);
+  response = filter_url_http_request_mbed (url, error, post_values, "", check_certificate);
 #else
   // Get a curl handle.
   CURL *curl = curl_easy_init ();
@@ -987,24 +1071,39 @@ string filter_url_http_post (string url, map <string, string> values, string& er
     // First set the URL that is about to receive the POST.
     // This can be http or https.
     curl_easy_setopt (curl, CURLOPT_URL, url.c_str());
-    // Generate the post data.
-    string postdata;
-    for (auto & element : values) {
-      if (!postdata.empty ()) postdata.append ("&");
-      postdata.append (element.first);
-      postdata.append ("=");
-      postdata.append (filter_url_urlencode (element.second));
+    // Generate the post data, add it to the plain post data.
+    for (auto & element : post_values) {
+      if (!post_data.empty ()) post_data.append ("&");
+      post_data.append (element.first);
+      post_data.append ("=");
+      post_data.append (filter_url_urlencode (element.second));
     }
     // Specify the POST data to curl, e.g.: "name=foo&project=bar"
-    curl_easy_setopt (curl, CURLOPT_POSTFIELDS, postdata.c_str());
+    curl_easy_setopt (curl, CURLOPT_POSTFIELDS, post_data.c_str());
     // Callback for the server response.
     curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION, filter_url_curl_write_function);
     curl_easy_setopt (curl, CURLOPT_WRITEDATA, &response);
     // Further options.
     curl_easy_setopt (curl, CURLOPT_FOLLOWLOCATION, 1L);
+    // Enable the trace function.
+    // curl_easy_setopt(curl, CURLOPT_DEBUGFUNCTION, filter_url_curl_trace);
+    // The DEBUGFUNCTION has no effect until we enable VERBOSE.
     // curl_easy_setopt (curl, CURLOPT_VERBOSE, 1L);
     // Timeouts for very bad networks, see the GET routine above for an explanation.
     filter_url_curl_set_timeout (curl, burst);
+    // Whether to check the secure certificate.
+    // If the configuration of the site is not right, the certificate cannot be verified.
+    // That would result in resources not being fetched anymore.
+    if (!check_certificate) curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0L);
+    // Optional extra headers.
+    struct curl_slist *list = nullptr;
+    for (auto header : headers) {
+      string line = header.first + ": " + header.second;
+      list = curl_slist_append (list, line.c_str ());
+    }
+    if (list) {
+      curl_easy_setopt (curl, CURLOPT_HTTPHEADER, list);
+    }
     // Perform the request.
     CURLcode res = curl_easy_perform (curl);
     // Result check.
@@ -1019,6 +1118,7 @@ string filter_url_http_post (string url, map <string, string> values, string& er
       error = curl_easy_strerror (res);
     }
     // Always cleanup.
+    if (list) curl_slist_free_all (list);
     curl_easy_cleanup (curl);
   }
 #endif
@@ -1177,7 +1277,7 @@ void filter_url_download_file (string url, string filename, string& error,
       long http_code = 0;
       curl_easy_getinfo (curl, CURLINFO_RESPONSE_CODE, &http_code);
       if (http_code != 200) {
-        error.append ("http code " + convert_to_string ((int)http_code));
+        error.append ("http code " + convert_to_string (static_cast<int>(http_code)));
       }
     } else {
       error = curl_easy_strerror (res);
@@ -1234,7 +1334,7 @@ int filter_url_curl_debug_callback (void *curl_handle, int curl_info_type, char
 {
   if (curl_handle && userptr) {};
   bool log = true;
-  curl_infotype type = (curl_infotype) curl_info_type;
+  curl_infotype type = static_cast<curl_infotype>(curl_info_type);
   if (type == CURLINFO_SSL_DATA_OUT) log = false;
   if (type == CURLINFO_SSL_DATA_OUT) log = false;
   if (log) {
@@ -1254,7 +1354,7 @@ int filter_url_curl_debug_callback (void *curl_handle, int curl_info_type, char
 #else
 void filter_url_curl_set_timeout (void *curl_handle, bool burst)
 {
-  CURL * handle = (CURL *) curl_handle;
+  CURL * handle = static_cast<CURL *>(curl_handle);
   
   // There is a timeout on establishing a connection.
   curl_easy_setopt (handle, CURLOPT_CONNECTTIMEOUT, 10);
@@ -1543,13 +1643,13 @@ string filter_url_http_request_mbed (string url, string& error, const map <strin
 #ifdef HAVE_WINDOWS
     ret = setsockopt (comm_sock, SOL_SOCKET, SO_RCVTIMEO, tv, sizeof (tv));
 #else
-    ret = setsockopt (comm_sock, SOL_SOCKET, SO_RCVTIMEO, (struct timeval *)&tv, sizeof(struct timeval));
+    ret = setsockopt (comm_sock, SOL_SOCKET, SO_RCVTIMEO, const_cast<struct timeval *>(&tv), sizeof(struct timeval));
 #endif
     if (ret != 0) Database_Logs::log (strerror (errno));
 #ifdef HAVE_WINDOWS
     ret = setsockopt (comm_sock, SOL_SOCKET, SO_SNDTIMEO, tv, sizeof (tv));
 #else
-    ret = setsockopt (comm_sock, SOL_SOCKET, SO_SNDTIMEO, (struct timeval *)&tv, sizeof(struct timeval));
+    ret = setsockopt (comm_sock, SOL_SOCKET, SO_SNDTIMEO, const_cast<struct timeval *>(&tv), sizeof(struct timeval));
 #endif
     if (ret != 0) Database_Logs::log (strerror (errno));
   }
@@ -1616,7 +1716,7 @@ string filter_url_http_request_mbed (string url, string& error, const map <strin
       
       // Write the secure http request to the server.
       const char * output = request.c_str();
-      const unsigned char * buf = (const unsigned char *) output;
+      const unsigned char * buf = reinterpret_cast<const unsigned char *>(output);
       // The C function strlen () fails on null characters in the request, so take string::size()
       size_t len = request.size ();
       while (connection_healthy && (len > 0)) {
@@ -1645,7 +1745,7 @@ string filter_url_http_request_mbed (string url, string& error, const map <strin
     } else {
 
       // Send plain http.
-      if (send (sock, request.c_str(), request.length(), 0) != (int) request.length ()) {
+      if (send (sock, request.c_str(), request.length(), 0) != static_cast<int>(request.length ())) {
         error = "Sending request: ";
         error.append (strerror (errno));
         connection_healthy = false;
@@ -1685,7 +1785,7 @@ string filter_url_http_request_mbed (string url, string& error, const map <strin
 #ifdef HAVE_WINDOWS
         ret = (int)recv(sock, &cur, 1, 0);
 #else
-        ret = (int)read(sock, &cur, 1);
+        ret = static_cast<int>(read(sock, &cur, 1));
 #endif
       }
       if (ret > 0) {
@@ -1744,17 +1844,17 @@ string filter_url_http_request_mbed (string url, string& error, const map <strin
   for (auto & line : lines) {
     if (line.empty ()) continue;
     if (line.find ("HTTP") != string::npos) {
-      size_t pos = line.find (" ");
-      if (pos != string::npos) {
-        line.erase (0, pos + 1);
+      size_t pos2 = line.find (" ");
+      if (pos2 != string::npos) {
+        line.erase (0, pos2 + 1);
         int response_code = convert_to_int (line);
         if (response_code != 200) {
           error = "Response code: " + line;
-          return "";
+          return string();
         }
       } else {
         error = "Invalid response: " + line;
-        return "";
+        return string();
       }
     }
   }
@@ -1774,7 +1874,7 @@ void filter_url_ssl_tls_initialize ()
   mbedtls_ctr_drbg_init (&filter_url_mbed_tls_ctr_drbg);
   mbedtls_entropy_init (&filter_url_mbed_tls_entropy);
   const char *pers = "Client";
-  ret = mbedtls_ctr_drbg_seed (&filter_url_mbed_tls_ctr_drbg, mbedtls_entropy_func, &filter_url_mbed_tls_entropy, (const unsigned char *) pers, strlen (pers));
+  ret = mbedtls_ctr_drbg_seed (&filter_url_mbed_tls_ctr_drbg, mbedtls_entropy_func, &filter_url_mbed_tls_entropy, reinterpret_cast <const unsigned char *> (pers), strlen (pers));
   filter_url_display_mbed_tls_error (ret, NULL, false);
   // Wait until the trusted root certificates exist.
   // This is necessary as there's cases that the data is still being installed at this point.
@@ -1950,9 +2050,9 @@ bool filter_url_port_can_connect (string hostname, int port)
     // If it fails, try the next one.
     if (sock < 0) continue;
     // Try to connect.
-    int res = connect (sock, rp->ai_addr, rp->ai_addrlen);
+    int res2 = connect (sock, rp->ai_addr, rp->ai_addrlen);
     // If connected, set the flag.
-    if (res != -1) connected = true;
+    if (res2 != -1) connected = true;
     // Socket should be closed.
     if (sock) {
   #ifdef HAVE_WINDOWS
