@@ -30,23 +30,27 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <bb/logic.h>
 #include <locale/translate.h>
 #include <developer/logic.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
-
-
+#pragma GCC diagnostic pop
 using namespace pugi;
 
 
-BookChapterData::BookChapterData (int book_in, int chapter_in, string data_in)
+namespace filter::usfm {
+
+
+BookChapterData::BookChapterData (int book, int chapter, string data)
 {
-  book = book_in;
-  chapter = chapter_in;
-  data = data_in;
+  m_book = book;
+  m_chapter = chapter;
+  m_data = data;
 }
 
 
 // Returns the string $usfm as one long string.
 // $usfm may contain new lines, but the resulting long string won't.
-string usfm_one_string (string usfm)
+string one_string (string usfm)
 {
   string long_string = "";
   vector <string> usfm_lines = filter_string_explode (usfm, '\n');
@@ -73,7 +77,7 @@ string usfm_one_string (string usfm)
 //             ...
 // Output would be:     array ("\id ", "GEN", "\c ", "10", ...)
 // If $code does not start with a marker, this becomes visible in the output too.
-vector <string> usfm_get_markers_and_text (string code)
+vector <string> get_markers_and_text (string code)
 {
   vector <string> markers_and_text;
   code = filter_string_str_replace ("\n\\", "\\", code); // New line followed by backslash: leave new line out.
@@ -122,7 +126,7 @@ vector <string> usfm_get_markers_and_text (string code)
 // "\id "   -> "id"
 // "\add*"  -> "add"
 // "\+add*" -> "add"
-string usfm_get_marker (string usfm)
+string get_marker (string usfm)
 {
   if (usfm.empty ()) return usfm;
   size_t pos = usfm.find ("\\");
@@ -168,8 +172,8 @@ vector <BookChapterData> usfm_import (string input, string stylesheet)
   int chapter_number = 0;
   string chapter_data = "";
 
-  input = usfm_one_string (input);
-  vector <string> markers_and_text = usfm_get_markers_and_text (input);
+  input = one_string (input);
+  vector <string> markers_and_text = get_markers_and_text (input);
   bool retrieve_book_number_on_next_iteration = false;
   bool retrieve_chapter_number_on_next_iteration = false;
 
@@ -183,10 +187,10 @@ vector <BookChapterData> usfm_import (string input, string stylesheet)
       retrieve_chapter_number_on_next_iteration = false;
       chapter_number = convert_to_int (marker_or_text);
     }
-    string marker = usfm_get_marker (marker_or_text);
+    string marker = get_marker (marker_or_text);
     if (!marker.empty()) {
       // USFM marker found.
-      bool opener = usfm_is_opening_marker (marker_or_text);
+      bool opener = is_opening_marker (marker_or_text);
       bool store_chapter_data = false;
       if (marker == "id") {
         retrieve_book_number_on_next_iteration = true;
@@ -231,40 +235,40 @@ vector <BookChapterData> usfm_import (string input, string stylesheet)
 // 10-12b
 // 10,11a
 // 10,12
-vector <int> usfm_get_verse_numbers (string usfm)
+vector <int> get_verse_numbers (string usfm)
 {
   vector <int> verse_numbers = { 0 };
-  vector <string> markers_and_text = usfm_get_markers_and_text (usfm);
+  vector <string> markers_and_text = get_markers_and_text (usfm);
   bool extract_verse = false;
   for (string marker_or_text : markers_and_text) {
     if (extract_verse) {
-      string verse = usfm_peek_verse_number (marker_or_text);
+      string verse = peek_verse_number (marker_or_text);
       // Range of verses.
-      if (usfm_handle_verse_range (verse, verse_numbers));
+      if (handle_verse_range (verse, verse_numbers));
       // Sequence of verses.
-      else if (usfm_handle_verse_sequence (verse, verse_numbers));
+      else if (handle_verse_sequence (verse, verse_numbers));
       // Single verse.
       else verse_numbers.push_back (convert_to_int (verse));
       extract_verse = false;
     }
-    if (marker_or_text.substr (0, 2) == usfm_marker_v ()) extract_verse = true;
+    if (marker_or_text.substr (0, 2) == marker_v ()) extract_verse = true;
     string va_or_vp = marker_or_text.substr (0, 3);
-    if (va_or_vp == usfm_marker_va ()) extract_verse = false;
-    if (va_or_vp == usfm_marker_vp ()) extract_verse = false;
+    if (va_or_vp == marker_va ()) extract_verse = false;
+    if (va_or_vp == marker_vp ()) extract_verse = false;
   }
   return verse_numbers;
 }
 
 
 // Returns the chapter numbers found in $usfm.
-vector <int> usfm_get_chapter_numbers (string usfm)
+vector <int> get_chapter_numbers (string usfm)
 {
   vector <int> chapter_numbers = { 0 };
-  vector <string> markers_and_text = usfm_get_markers_and_text (usfm);
+  vector <string> markers_and_text = get_markers_and_text (usfm);
   bool extract_chapter = false;
   for (string marker_or_text : markers_and_text) {
     if (extract_chapter) {
-      string chapter = usfm_peek_verse_number (marker_or_text);
+      string chapter = peek_verse_number (marker_or_text);
       chapter_numbers.push_back (convert_to_int (chapter));
       extract_chapter = false;
     }
@@ -277,13 +281,13 @@ vector <int> usfm_get_chapter_numbers (string usfm)
 
 
 // Returns the verse numbers in the string of $usfm code at line number $line_number.
-vector <int> usfm_linenumber_to_versenumber (string usfm, unsigned int line_number)
+vector <int> linenumber_to_versenumber (string usfm, unsigned int line_number)
 {
   vector <int> verse_number = {0}; // Initial verse number.
   vector <string> lines = filter_string_explode (usfm, '\n');
   for (unsigned int i = 0; i < lines.size(); i++) {
     if (i <= line_number) {
-      vector <int> verse_numbers = usfm_get_verse_numbers (lines[i]);
+      vector <int> verse_numbers = get_verse_numbers (lines[i]);
       if (verse_numbers.size() >= 2) {
         verse_number = filter_string_array_diff (verse_numbers, {0});
       }
@@ -295,15 +299,15 @@ vector <int> usfm_linenumber_to_versenumber (string usfm, unsigned int line_numb
 
 // Returns the verse numbers in the string of $usfm code at offset $offset.
 // Offset is calculated with unicode_string_length to support UTF-8.
-vector <int> usfm_offset_to_versenumber (string usfm, unsigned int offset)
+vector <int> offset_to_versenumber (string usfm, unsigned int offset)
 {
-  unsigned int totalOffset = 0;
+  size_t totalOffset = 0;
   vector <string> lines = filter_string_explode (usfm, '\n');
-  for (unsigned int i = 0; i < lines.size(); i++) {
+  for (unsigned i = 0; i < lines.size(); i++) {
     size_t length = unicode_string_length (lines [i]);
     totalOffset += length;
     if (totalOffset >= offset) {
-      return usfm_linenumber_to_versenumber (usfm, i);
+      return linenumber_to_versenumber (usfm, i);
     }
     // Add 1 for new line.
     totalOffset += 1;
@@ -314,18 +318,18 @@ vector <int> usfm_offset_to_versenumber (string usfm, unsigned int offset)
 
 
 // Returns the offset within the $usfm code where $verse number starts.
-int usfm_versenumber_to_offset (string usfm, int verse)
+int versenumber_to_offset (string usfm, int verse)
 {
   // Verse number 0 starts at offset 0.
   if (verse == 0) return 0;
   int totalOffset = 0;
   vector <string> lines = filter_string_explode (usfm, '\n');
   for (string line : lines) {
-    vector <int> verses = usfm_get_verse_numbers (line);
+    vector <int> verses = get_verse_numbers (line);
     for (auto & v : verses) {
       if (v == verse) return totalOffset;
     }
-    totalOffset += unicode_string_length (line);
+    totalOffset += static_cast<int>(unicode_string_length (line));
     // Add 1 for new line.
     totalOffset += 1;
   }
@@ -335,14 +339,14 @@ int usfm_versenumber_to_offset (string usfm, int verse)
 
 // Returns the verse text given a $verse_number and $usfm code.
 // Handles combined verses.
-string usfm_get_verse_text (string usfm, int verse_number)
+string get_verse_text (string usfm, int verse_number)
 {
   vector <string> result;
   bool hit = (verse_number == 0);
 
   vector <string> lines = filter_string_explode (usfm, '\n');
   for (string line : lines) {
-    vector <int> verses = usfm_get_verse_numbers (line);
+    vector <int> verses = get_verse_numbers (line);
     if (verse_number == 0) {
       if (verses.size () != 1) hit = false;
       if (hit) result.push_back (line);
@@ -369,10 +373,10 @@ string usfm_get_verse_text (string usfm, int verse_number)
 // Gets the USFM for the $verse number for a Quill-based verse editor.
 // This means that preceding empty paragraphs will be included also.
 // And that empty paragraphs at the end will be omitted.
-string usfm_get_verse_text_quill (string usfm, int verse)
+string get_verse_text_quill (string usfm, int verse)
 {
   // Get the raw USFM for the verse, that is, the bit between the \v... markers.
-  string raw_verse_usfm = usfm_get_verse_text (usfm, verse);
+  string raw_verse_usfm = get_verse_text (usfm, verse);
   
   // Bail out if empty.
   if (raw_verse_usfm.empty ()) {
@@ -382,13 +386,13 @@ string usfm_get_verse_text_quill (string usfm, int verse)
   // Omit new paragraphs at the end.
   // In this context it is taken as opening USFM markers without content.
   string verse_usfm (raw_verse_usfm);
-  vector <string> markers_and_text = usfm_get_markers_and_text (verse_usfm);
+  vector <string> markers_and_text = get_markers_and_text (verse_usfm);
   while (true) {
     if (markers_and_text.empty ()) break;
     string code = markers_and_text.back ();
     markers_and_text.pop_back ();
-    if (!usfm_is_usfm_marker (code)) break;
-    if (!usfm_is_opening_marker (code)) break;
+    if (!is_usfm_marker (code)) break;
+    if (!is_opening_marker (code)) break;
     verse_usfm.erase (verse_usfm.size () - code.size ());
     verse_usfm = filter_string_trim (verse_usfm);
     if (verse_usfm.empty ()) break;
@@ -403,17 +407,17 @@ string usfm_get_verse_text_quill (string usfm, int verse)
   // Any empty paragraphs at the end of the previous verse USFM,
   // add them to the current verse's USFM.
   if (verse) {
-    string previous_verse_usfm = usfm_get_verse_text (usfm, verse - 1);
+    string previous_verse_usfm = get_verse_text (usfm, verse - 1);
     // For combined verses: The raw USFM fragments should differ to make sense.
     if (previous_verse_usfm != raw_verse_usfm) {
       if (!previous_verse_usfm.empty ()) {
-        markers_and_text = usfm_get_markers_and_text (previous_verse_usfm);
+        markers_and_text = get_markers_and_text (previous_verse_usfm);
         while (true) {
           if (markers_and_text.empty ()) break;
           string code = markers_and_text.back ();
           markers_and_text.pop_back ();
-          if (!usfm_is_usfm_marker (code)) break;
-          if (!usfm_is_opening_marker (code)) break;
+          if (!is_usfm_marker (code)) break;
+          if (!is_opening_marker (code)) break;
           verse_usfm.insert (0, code + "\n");
         }
       }
@@ -426,7 +430,7 @@ string usfm_get_verse_text_quill (string usfm, int verse)
 
 
 // Gets the chapter text given a book of $usfm code, and the $chapter_number.
-string usfm_get_chapter_text (string usfm, int chapter_number)
+string get_chapter_text (string usfm, int chapter_number)
 {
   // Empty input: Ready.
   if (usfm.empty ()) return usfm;
@@ -435,7 +439,7 @@ string usfm_get_chapter_text (string usfm, int chapter_number)
   if (chapter_number) {
     // Normal chapter marker (new line after the number).
     bool found = false;
-    string marker = usfm_get_opening_usfm ("c", false) + convert_to_string (chapter_number) + "\n";
+    string marker = get_opening_usfm ("c", false) + convert_to_string (chapter_number) + "\n";
     size_t pos = usfm.find (marker);
     // Was the chapter found?
     if (pos != string::npos) {
@@ -443,14 +447,14 @@ string usfm_get_chapter_text (string usfm, int chapter_number)
       usfm.erase (0, pos);
     }
     // Unusual chapter marker (space after the number).
-    marker = usfm_get_opening_usfm ("c", false) + convert_to_string (chapter_number) + " ";
+    marker = get_opening_usfm ("c", false) + convert_to_string (chapter_number) + " ";
     pos = usfm.find (marker);
     if (pos != string::npos) {
       found = true;
       usfm.erase (0, pos);
     }
     // Another observed unusual situation: A non-breaking space after the chapter number.
-    marker = usfm_get_opening_usfm ("c", false) + convert_to_string (chapter_number) + non_breaking_space_u00A0 ();
+    marker = get_opening_usfm ("c", false) + convert_to_string (chapter_number) + non_breaking_space_u00A0 ();
     pos = usfm.find (marker);
     if (pos != string::npos) {
       found = true;
@@ -462,7 +466,7 @@ string usfm_get_chapter_text (string usfm, int chapter_number)
   }
 
   // Look for any next chapter marker.
-  size_t pos = usfm.find (usfm_get_opening_usfm ("c", false), 1);
+  size_t pos = usfm.find (get_opening_usfm ("c", false), 1);
   if (pos != string::npos) {
     usfm.erase (pos);
   }
@@ -480,14 +484,14 @@ string usfm_get_chapter_text (string usfm, int chapter_number)
 // It ensures that the $exclude_usfm does not make it to the output of the function.
 // In case of $quill, it uses a routine optimized for a Quill-based editor.
 // This means that empty paragraphs at the end of the extracted USFM fragment are not included.
-string usfm_get_verse_range_text (string usfm, int verse_from, int verse_to, const string& exclude_usfm, bool quill)
+string get_verse_range_text (string usfm, int verse_from, int verse_to, const string& exclude_usfm, bool quill)
 {
   vector <string> bits;
   string previous_usfm;
   for (int vs = verse_from; vs <= verse_to; vs++) {
     string verse_usfm;
-    if (quill) verse_usfm = usfm_get_verse_text_quill (usfm, vs);
-    else verse_usfm = usfm_get_verse_text (usfm, vs);
+    if (quill) verse_usfm = get_verse_text_quill (usfm, vs);
+    else verse_usfm = get_verse_text (usfm, vs);
     // Do not include repeating USFM in the case of combined verse numbers in the input USFM code.
     if (verse_usfm == previous_usfm) continue;
     if (!verse_usfm.empty () && !previous_usfm.empty ()) {
@@ -509,7 +513,7 @@ string usfm_get_verse_range_text (string usfm, int verse_from, int verse_to, con
 
 
 // Returns true if the $code contains a USFM marker.
-bool usfm_is_usfm_marker (string code)
+bool is_usfm_marker (string code)
 {
   if (code.length () < 2) return false;
   if (code.substr (0, 1) == "\\") return true;
@@ -519,7 +523,7 @@ bool usfm_is_usfm_marker (string code)
 
 // Returns true if the marker in $usfm is an opening marker.
 // Else it returns false.
-bool usfm_is_opening_marker (string usfm)
+bool is_opening_marker (string usfm)
 {
   return usfm.find ("*") == string::npos;
 }
@@ -527,7 +531,7 @@ bool usfm_is_opening_marker (string usfm)
 
 // Returns true if the marker in $usfm is an embedded marker.
 // Else it returns false.
-bool usfm_is_embedded_marker (string usfm)
+bool is_embedded_marker (string usfm)
 {
   return usfm.find ( "+") != string::npos;
 }
@@ -536,7 +540,7 @@ bool usfm_is_embedded_marker (string usfm)
 // Returns the USFM book identifier.
 // $usfm: array of strings alternating between USFM code and subsequent text.
 // $pointer: if increased by one, it should point to the \id in $usfm.
-string usfm_get_book_identifier (const vector <string>& usfm, unsigned int pointer)
+string get_book_identifier (const vector <string>& usfm, unsigned int pointer)
 {
   string identifier = "XXX"; // Fallback value.
   if (++pointer < usfm.size ()) {
@@ -549,7 +553,7 @@ string usfm_get_book_identifier (const vector <string>& usfm, unsigned int point
 // Returns the text that follows a USFM marker.
 // $usfm: array of strings alternating between USFM code and subsequent text.
 // $pointer: should point to the marker in $usfm. It gets increased by one.
-string usfm_get_text_following_marker (const vector <string>& usfm, unsigned int & pointer)
+string get_text_following_marker (const vector <string>& usfm, unsigned int & pointer)
 {
   string text = ""; // Fallback value.
   ++pointer;
@@ -563,14 +567,14 @@ string usfm_get_text_following_marker (const vector <string>& usfm, unsigned int
 // Returns the text that follows a USFM marker.
 // $usfm: array of strings alternating between USFM code and subsequent text.
 // $pointer: should point to the marker in $usfm. Pointer is left as it is.
-string usfm_peek_text_following_marker (const vector <string>& usfm, unsigned int pointer)
+string peek_text_following_marker (const vector <string>& usfm, unsigned int pointer)
 {
-  return usfm_get_text_following_marker (usfm, pointer);
+  return get_text_following_marker (usfm, pointer);
 }
 
 
 // Returns the verse number in the $usfm code.
-string usfm_peek_verse_number (string usfm)
+string peek_verse_number (string usfm)
 {
   // Make it robust, even handling cases like \v 1-2“Moi - No space after verse number.
   string verseNumber = "";
@@ -603,7 +607,7 @@ string usfm_peek_verse_number (string usfm)
 // Takes a marker in the form of text only, like "id" or "add",
 // and converts it into opening USFM, like "\id " or "\add ".
 // Supports the embedded markup "+".
-string usfm_get_opening_usfm (string text, bool embedded)
+string get_opening_usfm (string text, bool embedded)
 {
   string embed = embedded ? "+" : "";
   return "\\" + embed + text + " ";
@@ -613,7 +617,7 @@ string usfm_get_opening_usfm (string text, bool embedded)
 // Takes a marker in the form of text only, like "add",
 // and converts it into closing USFM, like "\add*".
 // Supports the embedded markup "+".
-string usfm_get_closing_usfm (string text, bool embedded)
+string get_closing_usfm (string text, bool embedded)
 {
   string embed = embedded ? "+" : "";
   return "\\" + embed + text + "*";
@@ -624,7 +628,7 @@ string usfm_get_closing_usfm (string text, bool embedded)
 // It returns an empty string if the difference is below the limit set for the Bible.
 // It returns a short message specifying the difference if it exceeds that limit.
 // It fills $explanation with a longer message in case saving is not safe.
-string usfm_save_is_safe (void * webserver_request, string oldtext, string newtext, bool chapter, string & explanation)
+string save_is_safe (void * webserver_request, string oldtext, string newtext, bool chapter, string & explanation)
 {
   // Two texts are equal: safe.
   if (newtext == oldtext) return string();
@@ -655,9 +659,9 @@ string usfm_save_is_safe (void * webserver_request, string oldtext, string newte
   if (newtext.length() > oldtext.length()) allowed_percentage = 100;
 
   // The length of the new text should not differ more than a set percentage from the old text.
-  float existingLength = oldtext.length();
-  float newLength = newtext.length ();
-  int percentage = 100 * (newLength - existingLength) / existingLength;
+  float existingLength = static_cast <float> (oldtext.length());
+  float newLength = static_cast <float> (newtext.length ());
+  int percentage = static_cast<int> (100 * (newLength - existingLength) / existingLength);
   percentage = abs (percentage);
   if (percentage > 100) percentage = 100;
   if (percentage > allowed_percentage) {
@@ -706,7 +710,7 @@ string usfm_save_is_safe (void * webserver_request, string oldtext, string newte
 // It also is useful in cases where the session is deleted from the server,
 // where the text in the editors would get corrupted.
 // It also is useful in view of an unstable connection between browser and server, to prevent data corruption.
-string usfm_safely_store_chapter (void * webserver_request,
+string safely_store_chapter (void * webserver_request,
                                   string bible, int book, int chapter, string usfm, string & explanation)
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
@@ -718,7 +722,7 @@ string usfm_safely_store_chapter (void * webserver_request,
   if (usfm == existing) return "";
   
   // Safety check.
-  string message = usfm_save_is_safe (webserver_request, existing, usfm, true, explanation);
+  string message = save_is_safe (webserver_request, existing, usfm, true, explanation);
   if (!message.empty ()) return message;
 
   // Record the change in the journal.
@@ -740,7 +744,7 @@ string usfm_safely_store_chapter (void * webserver_request,
  // where the text in the editors would get corrupted.
 // It also is useful in view of an unstable connection between browser and server, to prevent data corruption.
 // It handles combined verses.
-string usfm_safely_store_verse (void * webserver_request,
+string safely_store_verse (void * webserver_request,
                                 string bible, int book, int chapter, int verse, string usfm,
                                 string & explanation, bool quill)
 {
@@ -749,7 +753,7 @@ string usfm_safely_store_verse (void * webserver_request,
   usfm = filter_string_trim (usfm);
 
   // Check that the USFM to be saved is for the correct verse.
-  vector <int> save_verses = usfm_get_verse_numbers (usfm);
+  vector <int> save_verses = get_verse_numbers (usfm);
   if ((verse != 0) && !save_verses.empty ()) {
     save_verses.erase (save_verses.begin());
   }
@@ -771,13 +775,13 @@ string usfm_safely_store_verse (void * webserver_request,
   
   // Get the existing USFM fragment for the verse to save.
   string existing_verse_usfm;
-  if (quill) existing_verse_usfm = usfm_get_verse_text_quill (chapter_usfm, verse);
-  else existing_verse_usfm = usfm_get_verse_text (chapter_usfm, verse);
+  if (quill) existing_verse_usfm = get_verse_text_quill (chapter_usfm, verse);
+  else existing_verse_usfm = get_verse_text (chapter_usfm, verse);
   existing_verse_usfm = filter_string_trim (existing_verse_usfm);
 
   // Check that there is a match between the existing verse numbers and the verse numbers to save.
-  vector <int> existing_verses = usfm_get_verse_numbers (existing_verse_usfm);
-  save_verses = usfm_get_verse_numbers (usfm);
+  vector <int> existing_verses = get_verse_numbers (existing_verse_usfm);
+  save_verses = get_verse_numbers (usfm);
   bool verses_match = true;
   if (save_verses.size () == existing_verses.size ()) {
     for (unsigned int i = 0; i < save_verses.size (); i++) {
@@ -802,7 +806,7 @@ string usfm_safely_store_verse (void * webserver_request,
   }
 
   // Check maximum difference between new and existing USFM.
-  string message = usfm_save_is_safe (webserver_request, existing_verse_usfm, usfm, false, explanation);
+  string message = save_is_safe (webserver_request, existing_verse_usfm, usfm, false, explanation);
   if (!message.empty ()) return message;
   
   // Store the new verse USFM in the existing chapter USFM.
@@ -829,7 +833,7 @@ string usfm_safely_store_verse (void * webserver_request,
 
 
 // Returns whether $usfm contains one or more empty verses.
-bool usfm_contains_empty_verses (string usfm)
+bool contains_empty_verses (string usfm)
 {
   usfm = filter_string_str_replace ("\n", "", usfm);
   if (usfm.empty ()) return false;
@@ -843,7 +847,7 @@ bool usfm_contains_empty_verses (string usfm)
   if (pos != string::npos) return true;
   pos = usfm.find ("\\v \\v");
   if (pos != string::npos) return true;
-  pos = usfm.find_last_of (usfm_marker_v ());
+  pos = usfm.find_last_of (marker_v ());
   if (pos == usfm.length () - 1) return true;
   return false;
 }
@@ -851,7 +855,7 @@ bool usfm_contains_empty_verses (string usfm)
 
 // This looks at the $fragment, whether it's a range of verses.
 // If so, it puts the all of the verses in $verses, and returns true.
-bool usfm_handle_verse_range (string verse, vector <int> & verses)
+bool handle_verse_range (string verse, vector <int> & verses)
 {
   if (verse.find ("-") != string::npos) {
     size_t position;
@@ -860,9 +864,9 @@ bool usfm_handle_verse_range (string verse, vector <int> & verses)
     start_range = verse.substr (0, position);
     verse.erase (0, ++position);
     end_range = verse;
-    unsigned int start_verse_i = convert_to_int(number_in_string(start_range));
-    unsigned int end_verse_i = convert_to_int(number_in_string(end_range));
-    for (unsigned int i = start_verse_i; i <= end_verse_i; i++) {
+    int start_verse_i = convert_to_int(number_in_string(start_range));
+    int end_verse_i = convert_to_int(number_in_string(end_range));
+    for (int i = start_verse_i; i <= end_verse_i; i++) {
       if (i == start_verse_i)
         verses.push_back (convert_to_int (start_range));
       else if (i == end_verse_i)
@@ -878,7 +882,7 @@ bool usfm_handle_verse_range (string verse, vector <int> & verses)
 
 // This looks at the $fragment, whether it's a sequence of verses.
 // If so, it puts the all of the verses in $verses, and returns true.
-bool usfm_handle_verse_sequence (string verse, vector <int> & verses)
+bool handle_verse_sequence (string verse, vector <int> & verses)
 {
   if (verse.find (",") != string::npos) {
     int iterations = 0;
@@ -905,82 +909,51 @@ bool usfm_handle_verse_sequence (string verse, vector <int> & verses)
 }
 
 
-const char * usfm_marker_v ()
+const char * marker_v ()
 {
   return R"(\v)";
 }
 
 
-const char * usfm_marker_va ()
+const char * marker_va ()
 {
   return R"(\va)";
 }
 
 
-const char * usfm_marker_vp ()
+const char * marker_vp ()
 {
   return R"(\vp)";
 }
 
 
-// This removes the word level attributes from $usfm.
-// See https://ubsicap.github.io/usfm/attributes/index.html
-// Within a character marker span,
-// an attributes list is separated from the text content by a vertical bar |.
-// Attributes are listed as pairs of name and corresponding value using the syntax:
-//   attribute = "value".
-// Example:
-//   \w gracious|lemma="grace"\w*
-string usfm_remove_w_attributes (string usfm)
+// Find and remove the word-level attributes.
+// https://ubsicap.github.io/usfm/attributes/index.html
+// Example: \+w Lord|strong="H3068"\+w*
+// It will dispose of e.g. this: |strong="H3068"
+// It handles the default attribute: \w gracious|grace\w*
+void remove_word_level_attributes (const string & marker,
+                                   vector <string> & container, unsigned int & pointer)
 {
-  // Check for a vertical bar at all in the input USFM.
-  // If it's not there, then there won't be any word-level attributes.
-  if (usfm.find ("|") != string::npos) {
-
-    // Flag whether a replacement was made.
-    bool keep_going = false;
-    
-    // In USFM 3.0 there's two character markers that support word level attributes.
-    // But the \fig is already handled elsewhere.
-    vector <string> supported_character_markers = { "w" };
-    for (auto & marker : supported_character_markers) {
-
-      // Support multiple replacements.
-      size_t last_pos = 0;
-      do {
-      
-        // Set flag.
-        keep_going = false;
-
-        // The opener should be there.
-        size_t opener_pos = usfm.find (usfm_get_opening_usfm (marker), last_pos);
-        if (opener_pos == string::npos) continue;
-        last_pos = opener_pos + 1;
-
-        // The closer should be there too.
-        size_t closer_pos = usfm.find (usfm_get_closing_usfm (marker), last_pos);
-        if (closer_pos == string::npos) continue;
-
-        // The vertical bar should be between the opener and closer.
-        size_t bar_pos = usfm.find ("|", last_pos);
-        if (bar_pos == string::npos) continue;
-        if (bar_pos < opener_pos) continue;
-        
-        // There may be situations without the vertical bar.
-        if (bar_pos < closer_pos) {
-          // Remove the word level attribute.
-          usfm.erase (bar_pos, closer_pos - bar_pos);
-        }
-
-        // Set flag.
-        keep_going = true;
-
-      } while (keep_going);
-    }
-  }
+  // USFM 3.0 has four markers providing attributes.
+  // https://ubsicap.github.io/usfm/attributes/index.html.
+  // Deal with those only, and don't deal with any others.
+  // Note that the \fig markup is handled elsewhere in this class.
+  if ((marker != "w") && (marker != "rb") && (marker != "xt")) return;
   
-  // Done.
-  return usfm;
+  // Check the text following this markup whether it contains word-level attributes.
+  string possible_markup = filter::usfm::peek_text_following_marker (container, pointer);
+  
+  // If the markup is too short to contain the required characters, then bail out.
+  if (possible_markup.length() < 4) return;
+  
+  // Look for the vertical bar. If it's not there, bail out.
+  size_t bar_position = possible_markup.find("|");
+  if (bar_position == string::npos) return;
+  
+  // Remove the fragment and store the remainder back into the object.
+  possible_markup.erase(bar_position);
+  container [pointer + 1] = possible_markup;
 }
 
 
@@ -989,7 +962,7 @@ string usfm_remove_w_attributes (string usfm)
 // https://ubsicap.github.io/usfm/characters/index.html#fig-fig
 // That means it is backwards compatible with USFM 1/2:
 // \fig DESC|FILE|SIZE|LOC|COPY|CAP|REF\fig*
-string usfm_extract_fig (string usfm, string & caption, string & alt, string& src, string& size, string& loc, string& copy, string& ref)
+string extract_fig (string usfm, string & caption, string & alt, string& src, string& size, string& loc, string& copy, string& ref)
 {
   // The resulting USFM where the \fig markup has been removed from.
   string usfm_out;
@@ -1000,13 +973,13 @@ string usfm_extract_fig (string usfm, string & caption, string & alt, string& sr
   string marker = "fig";
   
   // If the opener is there, it means the \fig markup could be there.
-  string opener = usfm_get_opening_usfm (marker);
+  string opener = get_opening_usfm (marker);
   size_t pos1 = usfm.find (opener);
   if (pos1 != string::npos) {
     usfm_out.append(usfm.substr(0, pos1));
     usfm.erase (0, pos1 + opener.length());
     // Erase the \fig* closing markup.
-    string closer = usfm_get_closing_usfm(marker);
+    string closer = get_closing_usfm(marker);
     size_t pos2 = usfm.find(closer);
     if (pos2 != string::npos) {
       usfm_out.append(usfm.substr(pos2 + closer.length()));
@@ -1065,7 +1038,7 @@ string usfm_extract_fig (string usfm, string & caption, string & alt, string& sr
 
 
 // Returns true if the marker is a standard "q." marker.
-bool usfm_is_standard_q_poetry (const string & marker)
+bool is_standard_q_poetry (const string & marker)
 {
   if (marker == "q") return true;
   if (marker == "q1") return true;
@@ -1073,3 +1046,6 @@ bool usfm_is_standard_q_poetry (const string & marker)
   if (marker == "q3") return true;
   return false;
 }
+
+
+} // End of namespace.
