@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,25 +17,19 @@
  */
 
 
-#ifndef INCLUDED_FONTS_LOGIC_H
-#define INCLUDED_FONTS_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Fonts_Logic
 {
 public:
   static vector <string> getFonts ();
-  static bool fontExists (string font);
-  static string getFontPath (string font);
+  static bool font_exists (string font);
+  static string get_font_path (string font);
   static void erase (string font);
-  static string getTextFont (string bible);
-  static bool isFont (string suffix);
+  static string get_text_font (string bible);
+  static bool is_font (string suffix);
 private:
   static string folder ();
 };
-
-
-#endif
