@@ -24,7 +24,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/books.h>
 #include <html/text.h>
 #include <locale/translate.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 
 
 using namespace pugi;
@@ -35,20 +38,20 @@ using namespace pugi;
 
 Html_Header::Html_Header (void * html_text)
 {
-  htmlText = html_text;
+  m_html_text = html_text;
 }
 
 
-void Html_Header::searchBackLink (string url, string text)
+void Html_Header::search_back_link (string url, string text)
 {
-  searchBackLinkUrl = url;
-  searchBackLinkText = text;
+  m_search_back_link_url = url;
+  m_search_back_link_text = text;
 }
 
 
 void Html_Header::create (const vector <pair <string, string> > & breadcrumbs)
 {
-  Html_Text * html_text = static_cast<Html_Text *>(htmlText);
+  Html_Text * html_text = static_cast<Html_Text *>(m_html_text);
   xml_node tableElement = html_text->new_table ();
   xml_node tableRowElement = html_text->new_table_row (tableElement);
   xml_node tableDataElement = html_text->new_table_data (tableRowElement);
@@ -72,10 +75,10 @@ void Html_Header::create (const vector <pair <string, string> > & breadcrumbs)
   inputElement = formElement.append_child ("input");
   inputElement.append_attribute ("type") = "hidden";
   inputElement.append_attribute ("name") = "url";
-  inputElement.append_attribute ("value") = searchBackLinkUrl.c_str ();
+  inputElement.append_attribute ("value") = m_search_back_link_url.c_str ();
   inputElement = formElement.append_child ("input");
   inputElement.append_attribute ("type") = "hidden";
   inputElement.append_attribute ("name") = "text";
-  inputElement.append_attribute ("value") = searchBackLinkText.c_str ();
+  inputElement.append_attribute ("value") = m_search_back_link_text.c_str ();
 }
 
