@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,26 +17,21 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_HTML_HEADER_H
-#define INCLUDED_HTML_HEADER_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <database/styles.h>
 
-
 class Html_Header
 {
 public:
   Html_Header (void * html_text);
-  void searchBackLink (string url, string text);
+  Html_Header(const Html_Header&) = delete;
+  Html_Header operator=(const Html_Header&) = delete;
+  void search_back_link (string url, string text);
   void create (const vector <pair <string, string> > & breadcrumbs);
 private:
-  void * htmlText;
-  string searchBackLinkUrl;
-  string searchBackLinkText;
+  void * m_html_text {nullptr};
+  string m_search_back_link_url {};
+  string m_search_back_link_text {};
 };
-
-
-#endif
-
