@@ -29,6 +29,11 @@ OTHER DEALINGS IN THE SOFTWARE.
 //   Sean Middleditch <sean@middleditch.us>
 //   rlyeh <https://github.com/r-lyeh>
 
+#pragma clang diagnostic ignored "-Wstring-conversion"
+#pragma clang diagnostic ignored "-Wimplicit-int-conversion"
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wconversion"
+
 #include "jsonxx.h"
 
 #include <cctype>
@@ -37,6 +42,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 #include <sstream>
 #include <vector>
 #include <limits>
+#include <exception>
 
 // Snippet that creates an assertion function that works both in DEBUG & RELEASE mode.
 // JSONXX_ASSERT(...) macro will redirect to this. assert() macro is kept untouched.
@@ -47,10 +53,14 @@ OTHER DEALINGS IN THE SOFTWARE.
 #endif
 #include <stdio.h>
 #include <cassert>
-void jsonxx::assertion( const char *file, int line, const char *expression, bool result ) {
-    if( !result ) {
-        fprintf( stderr, "[JSONXX] expression '%s' failed at %s:%d -> ", expression, file, line );
-        assert( 0 );
+void jsonxx::assertion (const char *file, int line, const char *expression, bool result)
+{
+    if (!result) {
+//        fprintf( stderr, "[JSONXX] expression '%s' failed at %s:%d -> ", expression, file, line );
+//        assert( 0 );
+      (void) file;
+      (void) line;
+      throw std::runtime_error (expression);
     }
 }
 #if defined(JSONXX_REENABLE_NDEBUG)
@@ -306,13 +316,16 @@ bool Object::parse(std::istream& input, Object& object) {
     do {
         std::string key;
         if(UnquotedKeys == Enabled) {
-            if (!parse_identifier(input, key)) {
-                if (Parser == Permissive) {
-                    if (input.peek() == '}')
-                        break;
-                }
-                return false;
-            }
+          // This code will never be executed
+          // because of the default setting for unquoted keys.
+          // To disable the warning, the code will be disabled just now.
+          //if (!parse_identifier(input, key)) {
+          //  if (Parser == Permissive) {
+          //    if (input.peek() == '}')
+          //      break;
+          //  }
+          //  return false;
+          //}
         }
         else {
             if (!parse_string(input, key)) {
