@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,11 @@
 #include <database/morphgnt.h>
 #include <database/strong.h>
 #include <database/hebrewlexicon.h>
+#include <database/abbottsmith.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 #include <webserver/request.h>
 
 
@@ -43,6 +47,10 @@ using namespace pugi;
 #define SHIN_STRONG 10007
 
 
+// Internal function declarations.
+string lexicon_logic_render_part_of_speech_pop_front (vector <string> & parts);
+
+
 // The names of the available lexicon resources.
 vector <string> lexicon_logic_resource_names ()
 {
@@ -56,10 +64,8 @@ vector <string> lexicon_logic_resource_names ()
 
 
 // Gets the HTMl for displaying the book/chapter/verse of the $lexicon.
-string lexicon_logic_get_html (void * webserver_request, string lexicon, int book, int chapter, int verse)
+string lexicon_logic_get_html ([[maybe_unused]] void * webserver_request, string lexicon, int book, int chapter, int verse)
 {
-  (void) webserver_request;
-
   string html;
   
   if (lexicon == HEBREW_ETCBC4_NAME) {
@@ -67,30 +73,31 @@ string lexicon_logic_get_html (void * webserver_request, string lexicon, int boo
     Database_Etcbc4 database_etcbc4;
     // Data from the ETCBC4 database.
     vector <int> rowids = database_etcbc4.rowids (book, chapter, verse);
+    stringstream ss;
     if (!rowids.empty ()) {
       string id = "lexicontxt" + prefix;
-      html.append ("<div id=\"" + id + "\">\n");
+      ss << "<div id=" << quoted(id) << ">" << endl;
       for (auto rowid : rowids) {
-        html.append ("<table class='interlinear rtl'>");
-        html.append ("<tr>");
-        html.append ("<td class=\"hebrew\">");
+        ss << "<table class='interlinear rtl'>";
+        ss << "<tr>";
+        ss << "<td class=" << quoted ("hebrew") << ">";
         string word = database_etcbc4.word (rowid);
-        string link = "<a href=\"" HEBREW_ETCBC4_PREFIX + convert_to_string (rowid) + "\">" + word + "</a>";
-        html.append (link);
-        html.append ("</td>");
-        html.append ("</tr>");
-        html.append ("<tr>");
-        html.append ("<td>");
+        ss << "<a href=" << quoted(HEBREW_ETCBC4_PREFIX + convert_to_string (rowid)) << ">" << word << "</a>";
+        ss << "</td>";
+        ss << "</tr>";
+        ss << "<tr>";
+        ss << "<td>";
         string gloss = database_etcbc4.gloss (rowid);
         gloss = escape_special_xml_characters (gloss);
-        html.append (gloss);
-        html.append ("</td>");
-        html.append ("</tr>");
-        html.append ("</table>");
+        ss << gloss;
+        ss << "</td>";
+        ss << "</tr>";
+        ss << "</table>";
       }
-      html.append ("</div>");
-      html.append (lexicon_logic_get_script (prefix));
+      ss << "</div>";
+      ss << lexicon_logic_get_script (prefix);
     }
+    html.append(ss.str());
   }
 
   if (lexicon == KJV_LEXICON_NAME) {
@@ -98,16 +105,17 @@ string lexicon_logic_get_html (void * webserver_request, string lexicon, int boo
     Database_Kjv database_kjv;
     vector <int> rowids = database_kjv.rowids (book, chapter, verse);
     if (!rowids.empty ()) {
+      stringstream ss;
       string id = "lexicontxt" + prefix;
-      html.append ("<div id=\"" + id + "\">\n");
+      ss << "<div id=" << quoted(id) << ">" << endl;
       for (size_t i = 0; i < rowids.size (); i++) {
         int rowid = rowids[i];
         string english = database_kjv.english (rowid);
-        string link = "<a href=\"" KJV_LEXICON_PREFIX + convert_to_string (rowid) + "\">" + english + "</a>";
-        html.append (link);
+        ss << "<a href=" << quoted(KJV_LEXICON_PREFIX + convert_to_string (rowid)) << ">" << english << "</a>";
       }
-      html.append ("</div>");
-      html.append (lexicon_logic_get_script (prefix));
+      ss << "</div>";
+      ss << lexicon_logic_get_script (prefix);
+      html.append(ss.str());
     }
   }
 
@@ -116,18 +124,19 @@ string lexicon_logic_get_html (void * webserver_request, string lexicon, int boo
     Database_OsHb database_oshb;
     vector <int> rowids = database_oshb.rowids (book, chapter, verse);
     if (!rowids.empty ()) {
+      stringstream ss;
       string id = "lexicontxt" + prefix;
-      html.append ("<div id=\"" + id + "\" class=\"hebrew\">\n");
+      ss << "<div id=" << quoted(id) << " class=" << quoted("hebrew") << ">" << endl;
       for (size_t i = 0; i < rowids.size (); i++) {
         int rowid = rowids[i];
         string word = database_oshb.word (rowid);
         // Give more spacing where needed.
         if (word == "׀") word = " ׀ ";
-        string link = "<a href=\"" OSHB_PREFIX + convert_to_string (rowid) + "\">" + word + "</a>";
-        html.append (link);
+        ss << "<a href=" << quoted(OSHB_PREFIX + convert_to_string (rowid)) << ">" << word << "</a>";
       }
-      html.append ("</div>");
-      html.append (lexicon_logic_get_script (prefix));
+      ss << "</div>";
+      ss << lexicon_logic_get_script (prefix);
+      html.append(ss.str());
     }
   }
   
@@ -136,17 +145,18 @@ string lexicon_logic_get_html (void * webserver_request, string lexicon, int boo
     Database_MorphGnt database_morphgnt;
     vector <int> rowids = database_morphgnt.rowids (book, chapter, verse);
     if (!rowids.empty ()) {
+      stringstream ss;
       string id = "lexicontxt" + prefix;
-      html.append ("<div id=\"" + id + "\" class=\"greek\">\n");
+      ss << "<div id=" << quoted(id) << " class=" << quoted("greek") << ">" << endl;
       for (size_t i = 0; i < rowids.size (); i++) {
-        if (i) html.append (" ");
+        if (i) ss << " ";
         int rowid = rowids[i];
         string word = database_morphgnt.word (rowid);
-        string link = "<a href=\"" SBLGNT_PREFIX + convert_to_string (rowid) + "\">" + word + "</a>";
-        html.append (link);
+        ss << "<a href=" << quoted(SBLGNT_PREFIX + convert_to_string (rowid)) << ">" << word << "</a>";
       }
-      html.append ("</div>");
-      html.append (lexicon_logic_get_script (prefix));
+      ss << "</div>";
+      ss << lexicon_logic_get_script (prefix);
+      html.append (ss.str());
     }
   }
   
@@ -278,7 +288,7 @@ void lexicon_logic_convert_morphhb_parsing_to_strong (string parsing,
 }
 
 
-string lexicon_logic_render_definition (string strong)
+string lexicon_logic_render_strongs_definition (string strong)
 {
   vector <string> renderings;
   Database_Strong database_strong;
@@ -291,7 +301,7 @@ string lexicon_logic_render_definition (string strong)
   vector <string> lines = filter_string_explode (definition, '\n');
   for (auto & line : lines) {
     line = filter_string_trim (line);
-    line = filter_string_str_replace ("  ", " ", line);
+    line = filter_string_collapse_whitespace (line);
     size_t position;
     // The first <w> element describes it.
     position = line.find ("<w");
@@ -301,7 +311,7 @@ string lexicon_logic_render_definition (string strong)
       // Part of speech.
       string pos = lexicon_logic_get_remove_attribute (line, "pos");
       if (!pos.empty ()) {
-        pos = lexicon_logic_render_part_of_speech (pos);
+        pos = lexicon_logic_render_strongs_part_of_speech (pos);
         renderings.push_back (pos);
       }
       // Pronounciation.
@@ -392,7 +402,7 @@ string lexicon_logic_render_definition (string strong)
             // Put the updated fragment back, with a link.
             string replacement;
             if (i) {
-              replacement = "<a href=\"" + language.substr (0, 1) + strongs + "\">" + strongs + "</a>";
+              replacement = R"(<a href=")" + language.substr (0, 1) + strongs + R"(">)" + strongs + "</a>";
             }
             line = filter_string_str_replace (see_strongsref, replacement, line);
           }
@@ -429,7 +439,7 @@ string lexicon_logic_render_part_of_speech_pop_front (vector <string> & parts)
 
 
 // Render the part of speech.
-string lexicon_logic_render_part_of_speech (string value)
+string lexicon_logic_render_strongs_part_of_speech (string value)
 {
   if (value == unicode_string_casefold (value)) {
     // Deal with Strong's parsings.
@@ -526,31 +536,31 @@ string lexicon_logic_render_part_of_speech (string value)
 }
 
 
-string lexicon_logic_render_part_of_speech_stem (string abbrev)
+string lexicon_logic_render_strongs_part_of_speech_stem (string abbrev)
 {
   return abbrev;
 }
 
 
-string lexicon_logic_render_part_of_speech_person (string abbrev)
+string lexicon_logic_render_strongs_part_of_speech_person (string abbrev)
 {
   return abbrev;
 }
 
 
-string lexicon_logic_render_part_of_speech_gender (string abbrev)
+string lexicon_logic_render_strongs_part_of_speech_gender (string abbrev)
 {
   return abbrev;
 }
 
 
-string lexicon_logic_render_part_of_speech_number (string abbrev)
+string lexicon_logic_render_strongs_part_of_speech_number (string abbrev)
 {
   return abbrev;
 }
 
 
-string lexicon_logic_render_part_of_speech_state (string abbrev)
+string lexicon_logic_render_strongs_part_of_speech_state (string abbrev)
 {
   return abbrev;
 }
@@ -1116,22 +1126,22 @@ string lexicon_logic_hebrew_morphology_render (string value)
   
   // A slash separates morphology items.
   vector <string> values = filter_string_explode (value, '/');
-  for (auto value : values) {
+  for (auto value2 : values) {
 
-    if (value.empty ()) continue;
+    if (value2.empty ()) continue;
     
     if (!renderings.empty ()) renderings.push_back (" + ");
     
     // Part of Speech
-    string part_of_speech = value.substr (0, 1);
-    value.erase (0, 1);
+    string part_of_speech = value2.substr (0, 1);
+    value2.erase (0, 1);
     if (part_of_speech == "A") {
       renderings.push_back ("adjective");
       // type gender number state
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_adjective (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_state (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_adjective (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_state (value2));
     }
     else if (part_of_speech == "C") {
       renderings.push_back ("conjunction");
@@ -1142,46 +1152,46 @@ string lexicon_logic_hebrew_morphology_render (string value)
     else if (part_of_speech == "N") {
       renderings.push_back ("noun");
       // type gender number state
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_noun (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_state (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_noun (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_state (value2));
     }
     else if (part_of_speech == "P") {
       renderings.push_back ("pronoun");
       // type person gender number
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_pronoun (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_person (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_pronoun (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_person (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value2));
     }
     else if (part_of_speech == "R") {
       renderings.push_back ("preposition");
       // type
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_preposition (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_preposition (value2));
     }
     else if (part_of_speech == "S") {
       renderings.push_back ("suffix");
       // type person gender number
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_suffix (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_person (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_suffix (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_person (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value2));
     }
     else if (part_of_speech == "T") {
       renderings.push_back ("particle");
       // type
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_particle (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_particle (value2));
     }
     else if (part_of_speech == "V") {
       renderings.push_back ("verb");
       // stem type person gender number state
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_stem (hebrew, aramaic, value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_verb_conjugation (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_person (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value));
-      renderings.push_back (lexicon_logic_hebrew_morphology_render_state (value));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_stem (hebrew, aramaic, value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_type_verb_conjugation (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_person (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_gender (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_number (value2));
+      renderings.push_back (lexicon_logic_hebrew_morphology_render_state (value2));
     }
     else {
       renderings.push_back ("unknown");
@@ -1462,3 +1472,81 @@ string lexicon_logic_hebrew_morphology_render_state (string & value)
   }
   return rendering;
 }
+
+
+struct abbott_smith_walker: xml_tree_walker
+{
+  string text {};
+
+  bool text_element_already_handled {false};
+  string previous_element_name {};
+
+  virtual bool for_each (xml_node& node)
+  {
+    // Details of the current node.
+    string clas = node.attribute ("class").value ();
+    string name = node.name ();
+
+    // Handle occurrences count in the New Testament.
+    if (name == "note") {
+      string type = node.attribute("type").value();
+      if (type == "occurrencesNT") {
+        text.append ("occurs ");
+        text.append (node.text().get());
+        text.append (" times in the New Testament, ");
+        text_element_already_handled = true;
+        return true;
+      }
+    }
+
+    // Handle sense indicators.
+    if (name == "sense") {
+      if (previous_element_name != "sense") text.append (" sense ");
+      string n = node.attribute("n").value();
+      if (!n.empty()) {
+        text.append (n);
+        text.append (" ");
+      }
+    }
+    
+    // Include node's text content.
+    if (name.empty()) {
+      if (!text_element_already_handled) {
+        text.append (node.value());
+      }
+      text_element_already_handled = false;
+    }
+
+    previous_element_name = name;
+    
+    // Continue parsing.
+    return true;
+  }
+};
+
+
+string lexicon_logic_render_abbott_smiths_definition (string lemma, string strong)
+{
+  vector <string> renderings;
+
+  Database_AbbottSmith database_abbottsmith;
+
+  string definition = database_abbottsmith.get (lemma, lexicon_logic_strong_number_cleanup (strong));
+  
+  xml_document document;
+  document.load_string (definition.c_str());
+  abbott_smith_walker tree_walker {};
+  document.traverse (tree_walker);
+  renderings.push_back (tree_walker.text);
+
+  string rendering = filter_string_implode (renderings, " ");
+  rendering = filter_string_trim (rendering);
+
+  // If any rendering is given, then prefix the name of the lexicon.
+  if (!rendering.empty ()) {
+    rendering.insert(0, "Abbott Smith; ");
+  }
+   
+  // Done.
+  return rendering;
+}
