@@ -92,10 +92,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <bb/logic.h>
 #include <ldap/logic.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <jsonxx/jsonxx.h>
+#pragma GCC diagnostic pop
 #include <read/index.h>
 #include <filter/css.h>
 #include <resource/comparative9edit.h>
+#include <resource/translated9edit.h>
 #include <images/index.h>
 
 
@@ -184,25 +188,25 @@ string menu_logic_main_categories (void * webserver_request, string & tooltip)
   if (workspace_index_acl (webserver_request)) {
     if ((config_logic_default_bibledit_configuration () || config_logic_indonesian_cloud_free ()) && !(config_logic_indonesian_cloud_free_simple ())) {
       string label = translate ("Workspace");
-      string tooltip;
-      menu_logic_workspace_category (webserver_request, &tooltip);
-      html.push_back (menu_logic_create_item (workspace_index_url (), label, true, tooltip, ""));
+      string tooltip2;
+      menu_logic_workspace_category (webserver_request, &tooltip2);
+      html.push_back (menu_logic_create_item (workspace_index_url (), label, true, tooltip2, ""));
       tooltipbits.push_back (label);
     }
   }
 
   string menutooltip;
-  int current_theme_index[2] = {convert_to_int (request->database_config_user ()->getCurrentTheme ()), 1};
+  int current_theme_index = request->database_config_user ()->getCurrentTheme ();
   string filename = current_theme_filebased_cache_filename (request->session_identifier);
   if (config_logic_indonesian_cloud_free_simple ()) {
     if (database_filebased_cache_exists (filename)) {
-      current_theme_index[0] = convert_to_int (database_filebased_cache_get (filename));
+      current_theme_index = convert_to_int (database_filebased_cache_get (filename));
     } else {
       database_filebased_cache_put (filename, "1");
-      current_theme_index[0] = 1;
+      current_theme_index = 1;
     }
   }
-  string color = Filter_Css::theme_picker (current_theme_index[0], current_theme_index[1]);
+  string color = Filter_Css::theme_picker (current_theme_index, 1);
 
   if (!menu_logic_translate_category (webserver_request, &menutooltip).empty ()) {
     if (config_logic_indonesian_cloud_free_simple ()) {
@@ -317,17 +321,17 @@ string menu_logic_basic_categories (void * webserver_request)
 
   vector <string> html;
 
-  int current_theme_index[2] = {convert_to_int (request->database_config_user ()->getCurrentTheme ()), 1};
+  int current_theme_index = request->database_config_user ()->getCurrentTheme ();
   string filename = current_theme_filebased_cache_filename (request->session_identifier);
   if (config_logic_indonesian_cloud_free_simple ()) {
     if (database_filebased_cache_exists (filename)) {
-      current_theme_index[0] = convert_to_int (database_filebased_cache_get (filename));
+      current_theme_index = convert_to_int (database_filebased_cache_get (filename));
     } else {
       database_filebased_cache_put (filename, "1");
-      current_theme_index[0] = 1;
+      current_theme_index = 1;
     }
   }
-  string color = Filter_Css::theme_picker (current_theme_index[0], current_theme_index[1]);
+  string color = Filter_Css::theme_picker (current_theme_index, 1);
 
   if (read_index_acl (webserver_request)) {
     html.push_back (menu_logic_create_item (read_index_url (), translate ("Read"), true, "", color));
@@ -355,17 +359,17 @@ string menu_logic_basic_categories (void * webserver_request)
     html.push_back (menu_logic_create_item (personalize_index_url (), "⋮", true, "", color));
   }
 
+#ifdef HAVE_CLOUD
   // When a user is not logged in, or a guest,
   // put the public feedback into the main menu, rather than in a sub menu.
   // This is the default configuration.
-  bool public_feedback_possible = true;
+  bool public_feedback_possible { true };
   // In the Indonesian Cloud Free, there's no public feedback possible,
   // since the aim is to keep things easy to understand for beginners.
   // Except when it's the Indonesian Cloud Free Simple.
   if (config_logic_indonesian_cloud_free ()) {
     public_feedback_possible = false;
   }
-#ifdef HAVE_CLOUD
   if (public_feedback_possible) {
     if (menu_logic_public_or_guest (webserver_request)) {
       if (!public_logic_bibles (webserver_request).empty ()) {
@@ -1006,6 +1010,12 @@ string menu_logic_settings_resources_category ([[maybe_unused]] void * webserver
     html.push_back (menu_logic_create_item (resource_comparative9edit_url (), translate ("Comparative"), true, "", ""));
   }
 #endif
+
+#ifdef HAVE_CLOUD
+  if (resource_translated9edit_acl (webserver_request)) {
+    html.push_back (menu_logic_create_item (resource_translated9edit_url (), translate ("Translated"), true, "", ""));
+  }
+#endif
   
   if (!html.empty ()) {
     html.insert (html.begin (), menu_logic_resources_text () + ": ");
