@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ int Notes_Logic::createNote (string bible, int book, int chapter, int verse, str
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
     Database_NoteActions database_noteactions;
-    Webserver_Request * request = (Webserver_Request *) webserver_request;
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
     database_noteactions.record (request->session_logic()->currentUser (), note_id, Sync_Logic::notes_put_create_initiate, "");
     database_noteactions.record (request->session_logic()->currentUser (), note_id, Sync_Logic::notes_put_summary, "");
     // The contents to submit to the server, take it from the database, as it was updated in the logic above.
@@ -84,7 +84,8 @@ void Notes_Logic::setContent (int identifier, const string& content)
 
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_contents, content);
   } else {
@@ -104,7 +105,8 @@ void Notes_Logic::addComment (int identifier, const string& comment)
   database_notes.add_comment (identifier, comment);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_comment, comment);
   } else {
@@ -120,7 +122,8 @@ void Notes_Logic::set_summary (int identifier, const string& summary)
   database_notes.set_summary (identifier, summary);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_summary, "");
   } else {
@@ -135,7 +138,8 @@ void Notes_Logic::subscribe (int identifier)
   database_notes.subscribe (identifier);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_subscribe, "");
   } else {
@@ -150,7 +154,8 @@ void Notes_Logic::unsubscribe (int identifier)
   database_notes.unsubscribe (identifier);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_unsubscribe, "");
   } else {
@@ -164,7 +169,8 @@ void Notes_Logic::assignUser (int identifier, const string& user)
   Database_Notes database_notes (webserver_request);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string myuser = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string myuser = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions;
     database_noteactions.record (myuser, identifier, Sync_Logic::notes_put_assign, user);
   } else {
@@ -182,7 +188,8 @@ void Notes_Logic::unassignUser (int identifier, const string& user)
   database_notes.unassign_user (identifier, user);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string myuser = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string myuser = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (myuser, identifier, Sync_Logic::notes_put_unassign, user);
   } else {
@@ -197,7 +204,8 @@ void Notes_Logic::setStatus (int identifier, const string& status)
   database_notes.set_status (identifier, status);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_status, "");
   } else {
@@ -213,7 +221,8 @@ void Notes_Logic::setPassages (int identifier, const vector <Passage> & passages
   database_notes.set_passages (identifier, passages);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_passages, "");
   } else {
@@ -229,7 +238,8 @@ void Notes_Logic::setRawSeverity (int identifier, int severity)
   database_notes.set_raw_severity (identifier, severity);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_severity, "");
   } else {
@@ -245,7 +255,8 @@ void Notes_Logic::setBible (int identifier, const string& bible)
   database_notes.set_bible (identifier, bible);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_bible, "");
   } else {
@@ -261,7 +272,8 @@ void Notes_Logic::markForDeletion (int identifier)
   trash_consultation_note (webserver_request, identifier);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_mark_delete, "");
   } else {
@@ -277,7 +289,8 @@ void Notes_Logic::unmarkForDeletion (int identifier)
   database_notes.unmark_for_deletion (identifier);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_unmark_delete, "");
   } else {
@@ -291,7 +304,8 @@ void Notes_Logic::erase (int identifier)
   Database_Notes database_notes (webserver_request);
   if (client_logic_client_enabled ()) {
     // Client: record the action in the database.
-    string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string user = request->session_logic ()->currentUser ();
     Database_NoteActions database_noteactions = Database_NoteActions ();
     database_noteactions.record (user, identifier, Sync_Logic::notes_put_delete, "");
   } else {
@@ -359,7 +373,7 @@ void Notes_Logic::notifyUsers (int identifier, int notification)
   if (client_logic_client_enabled ()) return;
 
   // Data objects.
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   
   // This note's Bible.
@@ -375,9 +389,9 @@ void Notes_Logic::notifyUsers (int identifier, int notification)
     }
 
     // Users to get subscribed to the note, or to whom the note is to be assigned.
-    vector <string> users = request->database_users ()->getUsers ();
+    vector <string> users = request->database_users ()->get_users ();
     for (const string & user : users) {
-      if (access_bible_read (webserver_request, bible, user)) {
+      if (AccessBible::Read (webserver_request, bible, user)) {
         if (request->database_config_user ()->getNotifyUserOfAnyConsultationNotesEdits (user)) {
           database_notes.subscribe_user (identifier, user);
         }
@@ -415,10 +429,10 @@ void Notes_Logic::notifyUsers (int identifier, int notification)
   // notify only the users with this specific notification set.
   if ((notification == notifyNoteDelete) || (notification == notifyMarkNoteForDeletion)) {
     recipients.clear ();
-    vector <string> users = request->database_users ()->getUsers ();
+    vector <string> users = request->database_users ()->get_users ();
     for (const auto & user : users) {
       if (request->database_config_user ()->getUserDeletedConsultationNoteNotification (user)) {
-        if (access_bible_read (webserver_request, bible, user)) {
+        if (AccessBible::Read (webserver_request, bible, user)) {
           recipients.push_back (user);
         }
       }
@@ -471,40 +485,41 @@ void Notes_Logic::emailUsers (int identifier, const string& label, string bible,
   // Send mail to all users.
   string summary = database_notes.get_summary (identifier);
   string passages = filter_passage_display_inline (database_notes.get_passages (identifier));
-  string contents = database_notes.get_contents (identifier);
+  stringstream contents;
+  contents << database_notes.get_contents (identifier);
 
   // Include links to the Cloud: One to the note, and one to the active workspace.
-  contents.append ("<br>\n");
-  contents.append ("<p>");
-  contents.append ("<a href=\"");
+  contents << "<br>" << endl;
+  contents << "<p>";
+  contents << "<a href=";
   string notelink = config_logic_site_url (webserver_request) + notes_note_url () + "?id=" + convert_to_string (identifier);
-  contents.append (notelink);
-  contents.append ("\">");
-  contents.append (translate ("View or respond online"));
-  contents.append ("</a>");
-  contents.append (" " + translate ("or") + " ");
+  contents << quoted (notelink);
+  contents << ">";
+  contents << translate ("View or respond online");
+  contents << "</a>";
+  contents << " " << translate ("or") << " ";
 
-  contents.append ("<a href=\"");
+  contents << "<a href=";
   string workspacelink = config_logic_site_url (webserver_request) + workspace_index_url () + "?note=" + convert_to_string (identifier);
-  contents.append (workspacelink);
-  contents.append ("\">");
-  contents.append (translate ("open the workspace online"));
-  contents.append ("</a>");
+  contents << quoted (workspacelink);
+  contents << ">";
+  contents << translate ("open the workspace online");
+  contents << "</a>";
 
-  contents.append ("</p>\n");
+  contents << "</p>" << endl;
   string mailto = "mailto:" + Database_Config_General::getSiteMailAddress () + "?subject=(CNID" + convert_to_string (identifier) + ")";
-  contents.append ("<p><a href=\"");
-  contents.append (mailto);
-  contents.append ("\">Respond by email</a></p>\n");
+  contents << "<p><a href=";
+  contents << quoted (mailto);
+  contents << ">Respond by email</a></p>" << endl;
 
   // Deal with possible postponing email till 9 PM.
-  int timestamp = filter_date_seconds_since_epoch ();
+  int timestamp = filter::date::seconds_since_epoch ();
   if (postpone) {
-    int localseconds = filter_date_local_seconds (timestamp);
-    float localhour = filter_date_numerical_hour (localseconds) + (float) filter_date_numerical_minute (localseconds) / 60;
+    int localseconds = filter::date::local_seconds (timestamp);
+    float localhour = static_cast<float>(filter::date::numerical_hour (localseconds)) + static_cast<float>(filter::date::numerical_minute (localseconds)) / 60;
     if (localhour < 21) {
       float difference = 21 - localhour;
-      timestamp += (3600 * difference) - 10;
+      timestamp += static_cast<int>(3600 * difference) - 10;
     }
   }
 
@@ -523,7 +538,7 @@ void Notes_Logic::emailUsers (int identifier, const string& label, string bible,
       subject.append (" | (CNID");
       subject.append (convert_to_string (identifier));
       subject.append (")");
-      email_schedule (user, subject, contents, timestamp);
+      email_schedule (user, subject, contents.str(), timestamp);
     }
   }
 }
@@ -543,7 +558,7 @@ bool Notes_Logic::handleEmailComment (string from, string subject, string body)
   if (pos == string::npos) return false;
   subject = subject.substr (0, pos);
   // Webserver request.
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   // At this stage, the subject contains an identifier.
   // Check that the identifier is an existing Consultation Note.
   int identifier = convert_to_int (subject);
@@ -561,7 +576,7 @@ bool Notes_Logic::handleEmailComment (string from, string subject, string body)
     username = filter_string_str_replace (".", " ", username);
   }
   // Clean the email's body.
-  string year = convert_to_string (filter_date_numerical_year (filter_date_seconds_since_epoch ()));
+  string year = convert_to_string (filter::date::numerical_year (filter::date::seconds_since_epoch ()));
   string sender = Database_Config_General::getSiteMailName();
   body = filter_string_extract_body (body, year, sender);
   // Remove any new lines from the body. This cleans up the email considerably,
@@ -570,16 +585,16 @@ bool Notes_Logic::handleEmailComment (string from, string subject, string body)
   body = filter_string_str_replace ("\n", " ", body);
   // Make comment on the consultation note.
   string sessionuser = request->session_logic ()->currentUser ();
-  request->session_logic ()->setUsername (username);
+  request->session_logic ()->set_username (username);
   addComment (identifier, body);
-  request->session_logic ()->setUsername (sessionuser);
+  request->session_logic ()->set_username (sessionuser);
   // Mail confirmation to the username.
   if (request->database_config_user()->getUserNotifyMeOfMyPosts (username)) {
-    string subject = translate("Your comment was posted");
-    subject.append (" [CNID");
-    subject.append (convert_to_string (identifier));
-    subject.append ("]");
-    email_schedule (username, subject, body);
+    string confirm_subject = translate("Your comment was posted");
+    confirm_subject.append (" [CNID");
+    confirm_subject.append (convert_to_string (identifier));
+    confirm_subject.append ("]");
+    email_schedule (username, confirm_subject, body);
   }
   // Log operation.
   Database_Logs::log ("Comment posted: " + body);
@@ -594,7 +609,7 @@ bool Notes_Logic::handleEmailComment (string from, string subject, string body)
 bool Notes_Logic::handleEmailNew (string from, string subject, string body)
 {
   // Webserver request.
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   // Store the original subject.
   string originalSubject = subject;
   // Check that the subject indicates that a new consultation note is to be created.
@@ -606,8 +621,7 @@ bool Notes_Logic::handleEmailNew (string from, string subject, string body)
   subject = filter_string_trim (subject);
   subject = filter_string_str_replace (".", " ", subject);
   subject = filter_string_str_replace (":", " ", subject);
-  subject = filter_string_str_replace ("   ", " ", subject);
-  subject = filter_string_str_replace ("  ", " ", subject);
+  subject = filter_string_collapse_whitespace (subject);
   // Check that the from address of the email belongs to an existing user.
   from = filter_string_extract_email (from);
   if (!request->database_users()->emailExists (from)) return false;
@@ -656,12 +670,12 @@ bool Notes_Logic::handleEmailNew (string from, string subject, string body)
   body = filter_string_extract_body (body);
   // Post the note.
   string sessionuser = request->session_logic()->currentUser ();
-  request->session_logic()->setUsername (username);
+  request->session_logic()->set_username (username);
   Database_Notes database_notes = Database_Notes(webserver_request);
   string bible = request->database_config_user()->getBible ();
   int identifier = database_notes.store_new_note (bible, book, chapter, verse, summary, body, false);
   handlerNewNote (identifier);
-  request->session_logic()->setUsername (sessionuser);
+  request->session_logic()->set_username (sessionuser);
   // Mail confirmation to the username.
   if (request->database_config_user()->getUserNotifyMeOfMyPosts (username)) {
     subject = translate("Your new note was posted");
@@ -688,7 +702,7 @@ void notes_logic_maintain_note_assignees (bool force)
   Webserver_Request webserver_request;
   
   Database_Users database_users;
-  vector <string> users = database_users.getUsers ();
+  vector <string> users = database_users.get_users ();
 
   // If even one user's assignees are absent, force rebuilding them for all users.
   for (auto & user : users) {
@@ -708,10 +722,10 @@ void notes_logic_maintain_note_assignees (bool force)
     for (auto & bible : bibles) {
       
       // Continue with this Bible if the user has access to it.
-      if (access_bible_read (&webserver_request, bible, user)) {
+      if (AccessBible::Read (&webserver_request, bible, user)) {
 
         for (auto & assignee : users) {
-          if (access_bible_read (&webserver_request, bible, assignee)) {
+          if (AccessBible::Read (&webserver_request, bible, assignee)) {
             assignees.push_back (assignee);
           }
         }
