@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <filter/roles.h>
 #include <filter/usfm.h>
 #include <filter/string.h>
+#include <filter/css.h>
 #include <webserver/request.h>
 #include <locale/translate.h>
 #include <database/notes.h>
@@ -46,11 +47,11 @@ bool notes_notes_acl (void * webserver_request)
 
 string notes_notes (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
 
   
-  string bible = access_bible_clamp (webserver_request, request->database_config_user()->getBible());
+  string bible = AccessBible::Clamp (webserver_request, request->database_config_user()->getBible());
   int book = Ipc_Focus::getBook (webserver_request);
   int chapter = Ipc_Focus::getChapter (webserver_request);
   int verse = Ipc_Focus::getVerse (webserver_request);
@@ -71,7 +72,7 @@ string notes_notes (void * webserver_request)
 
   
   // The Bibles the current user has access to.
-  vector <string> bibles = access_bible_bibles (webserver_request, request->session_logic()->currentUser ());
+  vector <string> bibles = AccessBible::Bibles (webserver_request, request->session_logic()->currentUser ());
   
   
   // The admin disables notes selection on Bibles,
@@ -93,30 +94,48 @@ string notes_notes (void * webserver_request)
         numeric_passages.push_back (filter_passage_to_integer (passage));
       }
       if (!numeric_passages.empty ()) {
-        double average = accumulate (numeric_passages.begin (), numeric_passages.end (), 0) / numeric_passages.size ();
-        passage_sort_key = round(average);
+        double average = static_cast<double>(accumulate (numeric_passages.begin (), numeric_passages.end (), 0)) / static_cast<double>(numeric_passages.size ());
+        passage_sort_key = static_cast<int> (round(average));
       }
       passage_sort_keys.push_back (passage_sort_key);
     }
-    quick_sort (passage_sort_keys, identifiers, 0, (int)identifiers.size ());
+    quick_sort (passage_sort_keys, identifiers, 0, static_cast <unsigned> (identifiers.size ()));
   }
 
 
   bool show_bible_in_notes_list = request->database_config_user ()->getShowBibleInNotesList ();
   bool show_note_status = request->database_config_user ()->getShowNoteStatus ();
-  string notesblock;
+  bool color_note_status = request->database_config_user ()->getUseColoredNoteStatusLabels ();
+  stringstream notesblock;
   for (auto & identifier : identifiers) {
 
     string summary = database_notes.get_summary (identifier);
     vector <Passage> passages = database_notes.get_passages (identifier);
     string verses = filter_passage_display_inline (passages);
     if (show_note_status) {
-      string status = database_notes.get_status (identifier);
-      verses.insert (0, status + " ");
+      string status_text = database_notes.get_status (identifier);
+      string raw_status;
+      if (color_note_status) {
+        // The class properties are in the stylesheet.
+        // Distinct colors were generated through https://mokole.com/palette.html.
+        raw_status = database_notes.get_raw_status (identifier);
+        raw_status = unicode_string_casefold (raw_status);
+        raw_status = filter_string_str_replace (" ", "", raw_status);
+        string css_class;
+        if (raw_status == "new") css_class = Filter_Css::distinction_set_notes (0);
+        else if (raw_status == "pending") css_class = Filter_Css::distinction_set_notes (1);
+        else if (raw_status == "inprogress") css_class = Filter_Css::distinction_set_notes (2);
+        else if (raw_status == "done") css_class = Filter_Css::distinction_set_notes (3);
+        else if (raw_status == "reopened") css_class = Filter_Css::distinction_set_notes (4);
+        else css_class = Filter_Css::distinction_set_notes (5);
+        if (!css_class.empty()) status_text.insert (0, R"(<span class=")" + css_class + R"(">)");
+        status_text.append ("</span>");
+      }
+      verses.insert (0, status_text + " ");
     }
     if (show_bible_in_notes_list) {
-      string bible = database_notes.get_bible (identifier);
-      verses.insert (0, bible + " ");
+      string note_bible = database_notes.get_bible (identifier);
+      verses.insert (0, note_bible + " ");
     }
     // A simple way to make it easier to see the individual notes in the list,
     // when the summaries of some notes are long, is to display the passage first.
@@ -124,10 +143,10 @@ string notes_notes (void * webserver_request)
 
     string verse_text;
     if (passage_inclusion_selector) {
-      vector <Passage> passages = database_notes.get_passages (identifier);
-      for (auto & passage : passages) {
-        string usfm = request->database_bibles()->getChapter (bible, passage.book, passage.chapter);
-        string text = usfm_get_verse_text (usfm, convert_to_int (passage.verse));
+      vector <Passage> include_passages = database_notes.get_passages (identifier);
+      for (auto & passage : include_passages) {
+        string usfm = request->database_bibles()->getChapter (bible, passage.m_book, passage.m_chapter);
+        string text = filter::usfm::get_verse_text (usfm, convert_to_int (passage.m_verse));
         if (!verse_text.empty ()) verse_text.append ("<br>");
         verse_text.append (text);
       }
@@ -137,16 +156,16 @@ string notes_notes (void * webserver_request)
     if (text_inclusion_selector) {
       content = database_notes.get_contents (identifier);
     }
-    
-    notesblock.append ("<a name=\"note" + convert_to_string (identifier) + "\"></a>\n");
-    notesblock.append ("<p><a href=\"note?id=" + convert_to_string (identifier) + "\">" + summary + "</a></p>\n");
-    if (!verse_text.empty ()) notesblock.append ("<p>" + verse_text + "</p>\n");
-    if (!content.empty ()) notesblock.append ("<p>" + content + "</p>\n");
+
+    notesblock << "<a name=" << quoted ("note" + convert_to_string (identifier)) << "></a>" << endl;
+    notesblock << "<p><a href=" << quoted ("note?id=" + convert_to_string (identifier)) << ">" << summary << "</a></p>" << endl;
+    if (!verse_text.empty ()) notesblock << "<p>" << verse_text << "</p>" << endl;
+    if (!content.empty ()) notesblock << "<p>" << content << "</p>" << endl;
   }
 
   
   if (identifiers.empty ()) {
     return translate("This selection does not display any notes.");
   }
-  return notesblock;
+  return notesblock.str();
 }
