@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ONLINEBIBLE_TEXT_H
-#define INCLUDED_ONLINEBIBLE_TEXT_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class OnlineBible_Text
 {
 public:
@@ -35,11 +32,7 @@ public:
   void save (string name);
   void storeData ();
 private:
-  string currentLine;
-  bool lineLoaded = false;
-  vector <string> output;
+  string currentLine {};
+  bool lineLoaded {false};
+  vector <string> output {};
 };
-
-
-#endif
-
