@@ -282,7 +282,7 @@ vector <string> Paratext_Logic::enabledBibles ()
 }
 
 
-void Paratext_Logic::synchronize ()
+void Paratext_Logic::synchronize (tasks::enums::paratext_sync method)
 {
   // The Bibles for which Paratext synchronization has been enabled.
   vector <string> bibles = enabledBibles ();
@@ -337,7 +337,7 @@ void Paratext_Logic::synchronize ()
       string paratext_book = paratext_books [book];
       if (paratext_book.empty ()) {
         Database_Logs::log (journalTag (bible, book, -1) + "The Paratext project does not have this book", Filter_Roles::translator ());
-        Database_Logs::log (journalTag (bible, book, -1) + "Looked for a file with " + usfm_get_opening_usfm("id") + Database_Books::getUsfmFromId (book) + " on the first line", Filter_Roles::translator ());
+        Database_Logs::log (journalTag (bible, book, -1) + "Looked for a file with " + filter::usfm::get_opening_usfm("id") + Database_Books::getUsfmFromId (book) + " on the first line", Filter_Roles::translator ());
         continue;
       }
       
@@ -346,9 +346,9 @@ void Paratext_Logic::synchronize ()
       map <int, string> ancestor_usfm;
       {
         string book_usfm = ancestor (bible, book);
-        vector <int> chapters = usfm_get_chapter_numbers (book_usfm);
+        vector <int> chapters = filter::usfm::get_chapter_numbers (book_usfm);
         for (auto chapter : chapters) {
-          string chapter_usfm = usfm_get_chapter_text (book_usfm, chapter);
+          string chapter_usfm = filter::usfm::get_chapter_text (book_usfm, chapter);
           ancestor_usfm [chapter] = chapter_usfm;
         }
       }
@@ -364,9 +364,9 @@ void Paratext_Logic::synchronize ()
         // It does that after syncing with Bibledit and editing the chapter in Paratext.
         // This looks like a bug in Paratext. Remove those empty lines.
         book_usfm = filter_string_str_replace ("\n\n", "\n", book_usfm);
-        vector <int> chapters = usfm_get_chapter_numbers (book_usfm);
+        vector <int> chapters = filter::usfm::get_chapter_numbers (book_usfm);
         for (auto chapter : chapters) {
-          string chapter_usfm = usfm_get_chapter_text (book_usfm, chapter);
+          string chapter_usfm = filter::usfm::get_chapter_text (book_usfm, chapter);
           paratext_usfm [chapter] = chapter_usfm;
         }
       }
@@ -388,22 +388,51 @@ void Paratext_Logic::synchronize ()
       
       for (int chapter : chapters) {
         
-        string usfm;
         string ancestor = ancestor_usfm [chapter];
         string bibledit = database_bibles.getChapter (bible, book, chapter);
         string paratext = paratext_usfm [chapter];
 
+        // Results of the merge or copy operations.
         vector <string> messages;
-        bool merged;
         vector <Merge_Conflict> conflicts;
-
-        // Run the synchronizer.
-        usfm = synchronize (ancestor, bibledit, paratext, messages, merged, conflicts);
+        string updated_usfm;
         
-        // If there was a result of syncing, set the ancestor and paratext data.
-        if (!usfm.empty ()) {
-          ancestor_usfm [chapter] = usfm;
-          paratext_usfm [chapter] = usfm;
+        // Handle the synchronization method.
+        switch (method) {
+          case tasks::enums::paratext_sync::none:
+          {
+            break;
+          }
+          case tasks::enums::paratext_sync::bi_directional:
+          {
+            // Run the merge synchronizer.
+            updated_usfm = synchronize (ancestor, bibledit, paratext, messages, conflicts);
+            break;
+          }
+          case tasks::enums::paratext_sync::bibledit_to_paratext:
+          {
+            // If there's a change between Bibledit and Paratext, take the Bibledit data.
+            if (bibledit != paratext) {
+              updated_usfm = bibledit;
+              messages.push_back (translate ("Copy Bibledit to Paratext"));
+            }
+            break;
+          }
+          case tasks::enums::paratext_sync::paratext_to_bibledit:
+          {
+            // If there's a change between Paratext and Bibledit, take the Paratext data.
+            if (paratext != bibledit) {
+              updated_usfm = paratext;
+              messages.push_back (translate ("Copy Paratext to Bibledit"));
+            }
+            break;
+          }
+        }
+
+        // If there was a result of syncing or copying, set the ancestor and paratext data.
+        if (!updated_usfm.empty ()) {
+          ancestor_usfm [chapter] = updated_usfm;
+          paratext_usfm [chapter] = updated_usfm;
         }
         
         // Messages for the logbook.
@@ -411,9 +440,9 @@ void Paratext_Logic::synchronize ()
           Database_Logs::log (journalTag (bible, book, chapter) + message, Filter_Roles::translator ());
         }
 
-        // Log the change due to a merge.
-        if (merged) {
-          bible_logic_log_change (bible, book, chapter, usfm, "", "Paratext", true);
+        // Log the change due to a merge or copy.
+        if (!updated_usfm.empty ()) {
+          bible_logic_log_change (bible, book, chapter, updated_usfm, "", "Paratext", true);
         }
 
         // If there's any conflicts, email full details about the conflict to the user.
@@ -422,13 +451,13 @@ void Paratext_Logic::synchronize ()
         bible_logic_merge_irregularity_mail ({ username }, conflicts);
         
         // Store the updated chapter in Bibledit.
-        if (!usfm.empty ()) {
+        if (!updated_usfm.empty ()) {
           // Set flag for saving to Paratext.
           book_is_updated = true;
           // Store it only in case the Bibledit data was updated.
           // https://github.com/bibledit/cloud/issues/339
-          if (usfm != bibledit) {
-            bible_logic_store_chapter (bible, book, chapter, usfm);
+          if (updated_usfm != bibledit) {
+            bible_logic_store_chapter (bible, book, chapter, updated_usfm);
           }
         }
 
@@ -470,12 +499,11 @@ void Paratext_Logic::synchronize ()
 
 string Paratext_Logic::synchronize (string ancestor, string bibledit, string paratext,
                                     vector <string> & messages,
-                                    bool & merged, vector <Merge_Conflict> & conflicts)
+                                    vector <Merge_Conflict> & conflicts)
 {
   string resulting_usfm;
 
   messages.clear ();
-  merged = false;
   conflicts.clear ();
   
   // If Bibledit has the chapter, and Paratext does not, take the Bibledit chapter.
@@ -513,7 +541,6 @@ string Paratext_Logic::synchronize (string ancestor, string bibledit, string par
   else if (!ancestor.empty ()) {
     resulting_usfm = filter_merge_run (ancestor, bibledit, paratext, true, conflicts);
     messages.push_back (translate ("Chapter merged"));
-    merged = true;
   }
   
   // Cannot merge the two.
