@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ bool public_login_acl (void * webserver_request)
 
 string public_login (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   string page;
@@ -115,13 +115,13 @@ string public_login (void * webserver_request)
 
     if (form_is_valid) {
       // For public login, the password is taken to be the same as the username.
-      if (request->session_logic()->attemptLogin (name, name, touch_enabled)) {
+      if (request->session_logic()->attempt_login (name, name, touch_enabled)) {
         // Log the login.
         Database_Logs::log ("User " + request->session_logic()->currentUser () + " logged in");
       } else {
         // Add a new user and login.
         request->database_users ()->add_user(name, name, Filter_Roles::guest (), email);
-        request->session_logic()->attemptLogin (name, name, touch_enabled);
+        request->session_logic()->attempt_login (name, name, touch_enabled);
         Database_Logs::log ("Public account created for user " + request->session_logic()->currentUser () + " with email " + email);
       }
     }
