@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,10 @@
 #include <pugixml/utils.h>
 #include <filter/string.h>
 #include <database/logs.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 
 
 using namespace pugi;
@@ -28,16 +31,16 @@ using namespace pugi;
 
 void pugixml_utils_error_logger (void * pugi_xml_parse_result, const string & xml)
 {
-  xml_parse_result * result = (xml_parse_result *) pugi_xml_parse_result;
+  xml_parse_result * result = static_cast<xml_parse_result *>(pugi_xml_parse_result);
   if (result->status == status_ok) return;
-  int start = result->offset - 10;
+  int start = static_cast<int>(result->offset - 10);
   if (start < 0) start = 0;
-  string fragment = xml.substr (start, 20);
+  string fragment = xml.substr (static_cast<size_t>(start), 20);
   fragment = filter_string_str_replace ("\n", "", fragment);
   string msg;
   msg.append (result->description());
   msg.append (" at offset ");
-  msg.append (convert_to_string ((size_t)result->offset));
+  msg.append (convert_to_string (static_cast<size_t>(result->offset)));
   msg.append (": ");
   msg.append (fragment);
   Database_Logs::log (msg);
