@@ -56,7 +56,7 @@ string resource_get (void * webserver_request)
   if (!s_resource.empty () && !s_book.empty () && !s_chapter.empty () && !s_verse.empty ()) {
 
 
-    unsigned int resource = convert_to_int (s_resource);
+    unsigned int resource = static_cast<unsigned>(convert_to_int (s_resource));
     int book = convert_to_int (s_book);
     int chapter = convert_to_int (s_chapter);
     int verse = convert_to_int (s_verse);
@@ -109,7 +109,7 @@ string resource_get (void * webserver_request)
             }
           }
         }
-        while ((int)chapters_before.size () > context_before) {
+        while (static_cast<int>(chapters_before.size()) > context_before) {
           chapters_before.erase (chapters_before.begin ());
           verses_before.erase (verses_before.begin ());
         }
@@ -141,7 +141,7 @@ string resource_get (void * webserver_request)
             }
           }
         }
-        while ((int)chapters_after.size () > context_after) {
+        while (static_cast<int>(chapters_after.size()) > context_after) {
           chapters_after.pop_back ();
           verses_after.pop_back ();
         }
