@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ bool resource_index_acl (void * webserver_request)
 
 string resource_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
   bool touch = request->session_logic ()->touchEnabled ();
@@ -65,8 +65,8 @@ string resource_index (void * webserver_request)
   
   
   vector <string> resources = request->database_config_user()->getActiveResources ();
-  
-  
+
+
   // If no resources are displayed, set a default selection of them.
   if (resources.empty ()) {
     resources = demo_logic_default_resources ();
@@ -83,7 +83,7 @@ string resource_index (void * webserver_request)
         resource = sword_logic_get_name (resource);
       }
     }
-    resourceblock.append ("<span id=\"name" + convert_to_string (i) + "\" class=\"small\">" + resource + "</span>\n");
+    resourceblock.append ("<span id=\"name" + convert_to_string (i) + "\" class=\"title\">" + resource + "</span>\n");
     resourceblock.append ("<span id=\"content" + convert_to_string (i) + "\" class=\"resource\"></span>\n");
     resourceblock.append ("<hr style=\"clear:both\">");
     resourceblock.append ("</div>\n");
@@ -91,7 +91,7 @@ string resource_index (void * webserver_request)
   view.set_variable ("resourceblock", resourceblock);
   
   
-  int resource_count = resources.size ();
+  size_t resource_count = resources.size ();
   string username = request->session_logic()->currentUser ();
   int window_position = config_globals_resource_window_positions [username];
   string script = "var resourceCount = " + convert_to_string (resource_count) + ";\n"
@@ -100,6 +100,20 @@ string resource_index (void * webserver_request)
   view.set_variable ("script", script);
   
   
+  bool can_organize_active_resources = true;
+  if (config_logic_indonesian_cloud_free ()) {
+    // In the Indonesian free Cloud, only Managers and higher roles can organize the resources.
+    // In that type of Cloud, all resources for all users are one and the same setting.
+    int level = request->session_logic()->currentLevel();
+    can_organize_active_resources = (level >= Filter_Roles::manager());
+  }
+  if (config_logic_indonesian_cloud_free_simple ()) {
+    // In the Indonesian Cloud Free Simple version, the organize zone is not enabled.
+    can_organize_active_resources = false;
+  }
+  if (can_organize_active_resources) view.enable_zone("organize");
+  
+  
   page += view.render ("resource", "index");
   page += Assets_Page::footer ();
   return page;
