@@ -26,7 +26,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/date.h>
 #include <database/config/general.h>
 #include <database/config/bible.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 #include <locale/translate.h>
 #include <tasks/logic.h>
 #include <rss/feed.h>
@@ -113,16 +116,16 @@ void rss_logic_execute_update (string user, string bible, int book, int chapter,
   string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
 
   // Get the combined verse numbers in old and new USFM.
-  vector <int> old_verse_numbers = usfm_get_verse_numbers (oldusfm);
-  vector <int> new_verse_numbers = usfm_get_verse_numbers (newusfm);
+  vector <int> old_verse_numbers = filter::usfm::get_verse_numbers (oldusfm);
+  vector <int> new_verse_numbers = filter::usfm::get_verse_numbers (newusfm);
   vector <int> verses = old_verse_numbers;
   verses.insert (verses.end (), new_verse_numbers.begin (), new_verse_numbers.end ());
   verses = array_unique (verses);
   sort (verses.begin(), verses.end());
 
   for (auto verse : verses) {
-    string old_verse_usfm = usfm_get_verse_text (oldusfm, verse);
-    string new_verse_usfm = usfm_get_verse_text (newusfm, verse);
+    string old_verse_usfm = filter::usfm::get_verse_text (oldusfm, verse);
+    string new_verse_usfm = filter::usfm::get_verse_text (newusfm, verse);
     if (old_verse_usfm != new_verse_usfm) {
       Filter_Text filter_text_old = Filter_Text (bible);
       Filter_Text filter_text_new = Filter_Text (bible);
@@ -156,8 +159,8 @@ string rss_logic_xml_path ()
 
 void rss_logic_update_xml (vector <string> titles, vector <string> authors, vector <string> descriptions)
 {
-  int seconds = filter_date_seconds_since_epoch ();
-  string rfc822time = filter_date_rfc822 (seconds);
+  int seconds = filter::date::seconds_since_epoch ();
+  string rfc822time = filter::date::rfc822 (seconds);
   string guid = convert_to_string (seconds);
   bool document_updated = false;
   xml_document document;
