@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -45,15 +45,14 @@ string search_originals_url ()
 bool search_originals_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return read;
 }
 
 
 string search_originals (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
 
   Database_OsHb database_oshb = Database_OsHb ();
@@ -106,10 +105,10 @@ string search_originals (void * webserver_request)
     // Include items if there are no more search hits than 30% of the total number of verses in the Hebrew or Greek.
     size_t maxcount = 0;
     if (type == "ot") {
-      maxcount = round (0.3 * 23145);
+      maxcount = static_cast<size_t> (round (0.3 * 23145));
     }
     if (type == "nt") {
-      maxcount = round (0.3 * 7957);
+      maxcount = static_cast<size_t> (round (0.3 * 7957));
     }
     
     
@@ -151,7 +150,7 @@ string search_originals (void * webserver_request)
       v_passages.push_back (passage);
       counts.push_back (count);
     }
-    quick_sort (counts, v_passages, 0, counts.size());
+    quick_sort (counts, v_passages, 0, static_cast<unsigned> (counts.size()));
     reverse (v_passages.begin(), v_passages.end());
 
     
@@ -170,9 +169,9 @@ string search_originals (void * webserver_request)
     
     // Get the and passage for this identifier.
     Passage passage = filter_integer_to_passage (id);
-    int book = passage.book;
-    int chapter = passage.chapter;
-    string verse = passage.verse;
+    int book = passage.m_book;
+    int chapter = passage.m_chapter;
+    string verse = passage.m_verse;
     
     // Get the plain text.
     string text = search_logic_get_bible_verse_text (bible, book, chapter, convert_to_int (verse));
