@@ -31,6 +31,7 @@
 #include <access/bible.h>
 #include <ipc/focus.h>
 #include <menu/logic.h>
+#include <dialog/list2.h>
 
 
 string search_replace2_url ()
@@ -52,11 +53,29 @@ string search_replace2 (void * webserver_request)
   // Build the advanced replace page.
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   string bible = request->database_config_user()->getBible ();
+  
+  // Set the user chosen Bible as the current Bible.
+  if (request->post.count ("bibleselect")) {
+    string bibleselect = request->post ["bibleselect"];
+    request->database_config_user ()->setBible (bibleselect);
+    return string();
+  }
+
   string page;
   Assets_Header header = Assets_Header (translate("Replace"), request);
   header.addBreadCrumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
   Assets_View view;
+
+  {
+    string bible_html;
+    vector <string> bibles = AccessBible::Bibles (request);
+    for (auto selectable_bible : bibles) {
+      bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
+    }
+    view.set_variable ("bibleoptags", Options_To_Select::mark_selected (bible, bible_html));
+  }
+
   view.set_variable ("bible", bible);
   string script = "var searchBible = \"" + bible + "\";";
   view.set_variable ("script", script);
