@@ -66,10 +66,10 @@ string search_replacego2 (void * webserver_request)
   
   // Get Bible and passage for this identifier.
   Passage passage = Passage::decode (id);
-  string bible = passage.bible;
-  int book = passage.book;
-  int chapter = passage.chapter;
-  int verse = convert_to_int (passage.verse);
+  string bible = passage.m_bible;
+  int book = passage.m_book;
+  int chapter = passage.m_chapter;
+  int verse = convert_to_int (passage.m_verse);
   
   
   // Check whether the user has write access to the book.
@@ -79,7 +79,7 @@ string search_replacego2 (void * webserver_request)
   
   // Get the old chapter and verse USFM.
   string old_chapter_usfm = request->database_bibles()->getChapter (bible, book, chapter);
-  string old_verse_usfm = usfm_get_verse_text (old_chapter_usfm, verse);
+  string old_verse_usfm = filter::usfm::get_verse_text (old_chapter_usfm, verse);
   
   
   // As a standard to compare against, get the plain text from the search database,
