@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,15 +38,14 @@ string search_replacepre_url ()
 bool search_replacepre_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return write;
 }
 
 
 string search_replacepre (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
   string siteUrl = config_logic_site_url (webserver_request);
@@ -61,10 +60,10 @@ string search_replacepre (void * webserver_request)
   
   // Get the Bible and passage for this identifier.
   Passage passage = Passage::decode (id);
-  string bible = passage.bible;
-  int book = passage.book;
-  int chapter = passage.chapter;
-  string verse = passage.verse;
+  string bible = passage.m_bible;
+  int book = passage.m_book;
+  int chapter = passage.m_chapter;
+  string verse = passage.m_verse;
   
   
   // Get the plain text.
@@ -93,7 +92,7 @@ string search_replacepre (void * webserver_request)
   
   // Check whether the user has write access to the book.
   string user = request->session_logic ()->currentUser ();
-  bool write = access_bible_book_write (webserver_request, user, bible, book);
+  bool write = AccessBible::BookWrite (webserver_request, user, bible, book);
 
   
   // Create output.
