@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -43,15 +43,14 @@ string search_strongs_url ()
 bool search_strongs_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return read;
 }
 
 
 string search_strongs (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
 
   Database_Kjv database_kjv = Database_Kjv ();
@@ -93,7 +92,7 @@ string search_strongs (void * webserver_request)
     vector <string> words = filter_string_explode (s_words, ' ');
     
     // Include items if there are no more search hits than 30% of the total number of verses in the KJV.
-    size_t maxcount = round (0.3 * 31102);
+    size_t maxcount = static_cast<size_t> (round (0.3 * 31102));
     
     // Store how often a verse occurs in an array.
     // The keys are the passages of the search results.
@@ -130,7 +129,7 @@ string search_strongs (void * webserver_request)
       i_passages.push_back (i_passage);
       counts.push_back (count);
     }
-    quick_sort (counts, i_passages, 0, counts.size());
+    quick_sort (counts, i_passages, 0, static_cast<unsigned int>(counts.size()));
     reverse (i_passages.begin(), i_passages.end());
 
     // Output the passage identifiers to the browser.
@@ -148,9 +147,9 @@ string search_strongs (void * webserver_request)
     
     // Get the and passage for this identifier.
     Passage passage = filter_integer_to_passage (id);
-    int book = passage.book;
-    int chapter = passage.chapter;
-    string verse = passage.verse;
+    int book = passage.m_book;
+    int chapter = passage.m_chapter;
+    string verse = passage.m_verse;
     
     // Get the plain text.
     string text = search_logic_get_bible_verse_text (bible, book, chapter, convert_to_int (verse));
