@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include <paratext/logic.h>
 #include <menu/logic.h>
 #include <config/globals.h>
+#include <tasks/enums.h>
 
 
 string sendreceive_index_url ()
@@ -63,7 +64,7 @@ bool sendreceive_index_acl (void * webserver_request)
 
 string sendreceive_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   if (request->query.count ("status")) {
@@ -90,13 +91,13 @@ string sendreceive_index (void * webserver_request)
   string bible;
   if (request->query.count ("bible")) {
     bible = request->query["bible"];
-    if (bible == "") {
+    if (bible.empty()) {
       Dialog_List dialog_list = Dialog_List ("index", translate("Select a Bible"), "", "");
-      vector <string> bibles = access_bible_bibles (request);
-      for (auto & bible : bibles) {
+      vector <string> bibles = AccessBible::Bibles (request);
+      for (auto & selectable_bible : bibles) {
         // Select Bibles the user has write access to.
-        if (access_bible_write (request, bible)) {
-          dialog_list.add_row (bible, "bible", bible);
+        if (AccessBible::Write (request, selectable_bible)) {
+          dialog_list.add_row (selectable_bible, "bible", selectable_bible);
         }
       }
       page += dialog_list.run ();
@@ -107,7 +108,7 @@ string sendreceive_index (void * webserver_request)
   }
   
   
-  bible = access_bible_clamp (request, request->database_config_user()->getBible ());
+  bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
   view.set_variable ("bible", bible);
 
 
@@ -151,14 +152,27 @@ string sendreceive_index (void * webserver_request)
     view.set_variable ("success", starting_to_sync);
   }
   
-  
-  if (request->query.count ("syncparatext")) {
-    if (sendreceive_paratext_queued ()) {
-      view.set_variable ("error", translate("Still synchronizing with Paratext."));
+
+  {
+    auto sync_method = tasks::enums::paratext_sync::none;
+    if (request->query.count ("syncparatext")) {
+      sync_method = tasks::enums::paratext_sync::bi_directional;
     }
-    sendreceive_queue_paratext ();
-    view.set_variable ("success", starting_to_sync);
-  }
+    if (request->query.count ("bibledit2paratext")) {
+      sync_method = tasks::enums::paratext_sync::bibledit_to_paratext;
+    }
+    if (request->query.count ("paratext2bibledit")) {
+      sync_method = tasks::enums::paratext_sync::paratext_to_bibledit;
+    }
+    if (sync_method != tasks::enums::paratext_sync::none) {
+      if (sendreceive_paratext_queued ()) {
+        view.set_variable ("error", translate("Still synchronizing with Paratext."));
+      } else {
+        sendreceive_queue_paratext (sync_method);
+        view.set_variable ("success", starting_to_sync);
+      }
+    }
+   }
   
   
 #ifdef HAVE_CLIENT
@@ -205,6 +219,10 @@ string sendreceive_index (void * webserver_request)
   } else {
     view.enable_zone ("gitwrite");
   }
+
+  
+  bool basic_mode = config_logic_basic_mode (request);
+  if (basic_mode) view.enable_zone("basicmode");
   
   page += view.render ("sendreceive", "index");
   page += Assets_Page::footer ();
