@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,21 @@
 #include <database/oshb.h>
 #include <filter/string.h>
 #include <filter/passage.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <pugixml/pugixml.hpp>
+#pragma GCC diagnostic pop
 
 
 using namespace pugi;
 
 
+// Local declarations.
+void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, xml_node node);
+void sources_morphhb_parse_unhandled_node (int book, int chapter, int verse, xml_node node);
+void sources_morphhb_parse ();
+
+
 void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, xml_node node)
 {
   string lemma = node.attribute ("lemma").value ();
@@ -97,7 +106,7 @@ void sources_morphhb_parse ()
     string file = "sources/morphhb/" + books[bk] + ".xml";
     cout << file << endl;
 
-    int book = bk + 1;
+    int book = static_cast<int>(bk + 1);
 
     xml_document document;
     document.load_file (file.c_str());
@@ -122,23 +131,23 @@ void sources_morphhb_parse ()
 
           if (word_stored) database_oshb.store (book, chapter, verse, "", " ", "");
 
-          string node_name = node.name ();
+          string child_node_name = node.name ();
 
-          if (node_name == "w") {
+          if (child_node_name == "w") {
             sources_morphhb_parse_w_element (&database_oshb, book, chapter, verse, node);
           }
           
-          else if (node_name == "seg") {
+          else if (child_node_name == "seg") {
             string word = node.child_value ();
             database_oshb.store (book, chapter, verse, "", word, "");
           }
           
-          else if (node_name == "note") {
+          else if (child_node_name == "note") {
             for (xml_node variant_node : node.children ()) {
-              string node_name = variant_node.name ();
-              if (node_name == "catchWord") {
+              string variant_node_name = variant_node.name ();
+              if (variant_node_name == "catchWord") {
                 sources_morphhb_parse_w_element (&database_oshb, book, chapter, verse, node);
-              } else if (node_name == "rdg") {
+              } else if (variant_node_name == "rdg") {
                 for (xml_node w_node : variant_node.children ()) {
                   database_oshb.store (book, chapter, verse, "", "/", "");
                   sources_morphhb_parse_w_element (&database_oshb, book, chapter, verse, w_node);
