@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,18 +37,17 @@
 // It may be passed a manual year and manual month.
 // In those cases it will mail the burndown chart to the subscribed users.
 // Else it decides on its own whether to mail the chart to the users.
-void sprint_burndown (string bible, int manualyear, int manualmonth)
+void sprint_burndown ([[maybe_unused]] string bible,
+                      [[maybe_unused]] int manualyear,
+                      [[maybe_unused]] int manualmonth)
 {
-  (void) bible;
-  (void) manualyear;
-  (void) manualmonth;
 #ifdef HAVE_CLOUD
-  int localseconds = filter_date_local_seconds (filter_date_seconds_since_epoch ());
-  int year = filter_date_numerical_year (localseconds);
-  int month = filter_date_numerical_month (localseconds);
-  int monthday = filter_date_numerical_month_day (localseconds); // 1 to 31.
-  int weekday = filter_date_numerical_week_day (localseconds); // 0 (for Sunday) through 6 (for Saturday).
-  int hour = filter_date_numerical_hour (localseconds);
+  int localseconds = filter::date::local_seconds (filter::date::seconds_since_epoch ());
+  int year = filter::date::numerical_year (localseconds);
+  int month = filter::date::numerical_month (localseconds);
+  int monthday = filter::date::numerical_month_day (localseconds); // 1 to 31.
+  int weekday = filter::date::numerical_week_day (localseconds); // 0 (for Sunday) through 6 (for Saturday).
+  int hour = filter::date::numerical_hour (localseconds);
   bool sprintstart = false;
   bool sprintfinish = false;
   bool email = false;
@@ -58,12 +57,12 @@ void sprint_burndown (string bible, int manualyear, int manualmonth)
   // Every Friday at 2 PM (14:00h) it sends email about the sprint progress.
   if ((weekday == 5) && (hour == 14)) email = true;
   // On the first business day of the month, at 10 AM, send email about the start of the sprint.
-  if (filter_date_is_first_business_day_of_month (monthday, weekday) && (hour == 10)) {
+  if (filter::date::is_first_business_day_of_month (monthday, weekday) && (hour == 10)) {
     email = true;
     sprintstart = true;
   }
   // On the last business day of the month, at 2 PM (14:00h), send email about the end of the sprint.
-  if ((monthday == filter_date_get_last_business_day_of_month (year, month)) && (hour == 14)) {
+  if ((monthday == filter::date::get_last_business_day_of_month (year, month)) && (hour == 14)) {
     email = true;
     sprintfinish = true;
   }
@@ -88,9 +87,9 @@ void sprint_burndown (string bible, int manualyear, int manualmonth)
   if (hour <= 6) {
     localseconds -= (3600 * 6);
   }
-  year = filter_date_numerical_year (localseconds);
-  month = filter_date_numerical_month (localseconds);
-  monthday = filter_date_numerical_month_day (localseconds); // 1 to 31.
+  year = filter::date::numerical_year (localseconds);
+  month = filter::date::numerical_month (localseconds);
+  monthday = filter::date::numerical_month_day (localseconds); // 1 to 31.
   
   
   // It sending the planning manually, update the date.
@@ -102,70 +101,70 @@ void sprint_burndown (string bible, int manualyear, int manualmonth)
   
   
   vector <string> bibles = {bible};
-  if (bible == "") {
+  if (bible.empty()) {
     bibles = request.database_bibles()->getBibles ();
   }
   
 
-  for (auto bible : bibles) {
+  for (auto bible2 : bibles) {
 
     
     // Get the total number of tasks for this sprint,
     // and the average percentage of completion of them,
     // and store this information in the sprint history table.
-    vector <int> ids = database_sprint.getTasks (bible, year, month);
+    vector <int> ids = database_sprint.getTasks (bible2, year, month);
     vector <int> percentages;
     for (auto id : ids) {
       percentages.push_back (database_sprint.getComplete (id));
     }
-    int tasks = ids.size ();
+    int task_count = static_cast<int>(ids.size ());
     int complete = 0;
-    if (tasks != 0) {
+    if (task_count != 0) {
       for (auto percentage : percentages) complete += percentage;
-      complete = round ((float) complete / (float) tasks);
+      complete = static_cast<int> (round (static_cast<float>(complete) / static_cast<float>(task_count)));
     }
-    database_sprint.logHistory (bible, year, month, monthday, tasks, complete);
+    database_sprint.logHistory (bible2, year, month, monthday, task_count, complete);
     
     
     // Send email if requested.
     if (email) {
-      if (tasks) {
+      if (task_count) {
         // Only mail if the current sprint contains tasks.
-        string scategories = Database_Config_Bible::getSprintTaskCompletionCategories (bible);
+        string scategories = Database_Config_Bible::getSprintTaskCompletionCategories (bible2);
         vector <string> categories = filter_string_explode (scategories, '\n');
-        int category_count = categories.size();
-        int category_percentage = round (100 / category_count);
-        vector <string> users = request.database_users ()->getUsers ();
+        int category_count = static_cast<int>(categories.size());
+        int category_percentage = static_cast<int>(round (100 / category_count));
+        vector <string> users = request.database_users ()->get_users ();
         for (auto user : users) {
           if (request.database_config_user()->getUserSprintProgressNotification (user)) {
             
             string subject = translate("Team's progress in Sprint");
             if (sprintstart) subject = translate("Sprint has started");
             if (sprintfinish) subject = translate("Sprint has finished");
-            subject +=  " | " + bible;
+            subject +=  " | " + bible2;
             
             vector <string> body;
             
-            body.push_back ("<h4>" + bible + "</h4>");
+            body.push_back ("<h4>" + bible2 + "</h4>");
             body.push_back ("<h4>" + locale_logic_month (month) + "</h4>");
             body.push_back ("<h4>" + translate("Sprint Planning and Team's Progress") + "</h4>");
             body.push_back ("<table>");
-            vector <int> tasks = database_sprint.getTasks (bible, year, month);
+            vector <int> tasks = database_sprint.getTasks (bible2, year, month);
             for (auto id : tasks) {
               body.push_back ("<tr>");
               string title = database_sprint.getTitle (id);
               body.push_back ("<td>" + title + "</td>");
-              int complete = database_sprint.getComplete (id);
+              int complete_cnt = database_sprint.getComplete (id);
               string text;
-              for (int i = 0; i < round (complete / category_percentage); i++) text.append ("▓");
-              for (int i = 0; i < category_count - round (complete / category_percentage); i++) text.append ("▁");
+              for (int i = 0; i < round (complete_cnt / category_percentage); i++) text.append ("▓");
+              for (int i = 0; i < category_count - round (complete_cnt / category_percentage); i++) text.append ("▁");
               body.push_back ("<td>" + text + "</td>");
               body.push_back ("</tr>");
             }
             body.push_back ("</table>");
             
             body.push_back ("<h4>" + translate("Sprint Burndown Chart - Remaining Tasks") + "</h4>");
-            string burndownchart = sprint_create_burndown_chart (bible, year, month);
+            string burndownchart = sprint_create_burndown_chart (bible2, year, month);
             body.push_back ("<p>" + burndownchart + "</p>");
             
             if (!body.empty ()) {
@@ -187,26 +186,25 @@ void sprint_burndown (string bible, int manualyear, int manualmonth)
 
 
 // This function creates a text-based burndown chart for sprint $bible / $year / $month.
-string sprint_create_burndown_chart (string bible, int year, int month)
+string sprint_create_burndown_chart ([[maybe_unused]] string bible,
+                                     [[maybe_unused]] int year,
+                                     [[maybe_unused]] int month)
 {
 #ifdef HAVE_CLIENT
-  (void) bible;
-  (void) year;
-  (void) month;
-  return "";
+  return string();
 #endif
   
 #ifdef HAVE_CLOUD
   
   // Get the seconds for the first of the month.
-  int seconds = filter_date_seconds_since_epoch (year, month, 1);
+  int seconds = filter::date::seconds_since_epoch (year, month, 1);
   
   // The business days in the month for on the X-axis.
   vector <int> days_in_month;
-  for (unsigned int day = 1; day <= 31; day++) {
-    int mymonth = filter_date_numerical_month (seconds);
+  for (int day = 1; day <= 31; day++) {
+    int mymonth = filter::date::numerical_month (seconds);
     if (mymonth == month) {
-      if (filter_date_is_business_day (year, month, day)) {
+      if (filter::date::is_business_day (year, month, day)) {
         days_in_month.push_back (day);
       }
     }
@@ -223,7 +221,7 @@ string sprint_create_burndown_chart (string bible, int year, int month)
       if (day == item.day) {
         int tasks = item.tasks;
         int complete = item.complete;
-        tasks = round (tasks * (100 - complete) / 100);
+        tasks = static_cast <int> (round (tasks * (100 - complete) / 100));
         data [day] = tasks;
       }
     }
@@ -250,7 +248,7 @@ string sprint_create_burndown_chart (string bible, int year, int month)
                                       
   // Write "days" below the X-axis.
   lines.push_back ("<tr>");
-  int columncount = data.size ();
+  int columncount = static_cast<int>(data.size ());
   string text = translate("days");
   lines.push_back ("<td colspan=\"" + convert_to_string (columncount) + "\">" + text + "</td>");
   lines.push_back ("</tr>");
