@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,33 +17,29 @@
  */
 
 
-#ifndef INCLUDED_STYLES_CSS_H
-#define INCLUDED_STYLES_CSS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Styles_Css
 {
 public:
-  Styles_Css (void * webserver_request_in, string stylesheet_in);
+  Styles_Css (void * webserver_request, string stylesheet);
+  Styles_Css(const Styles_Css&) = delete;
+  Styles_Css operator=(const Styles_Css&) = delete;
   void editor ();
   void exports ();
   void generate ();
   string css (string path = "");
   void customize (const string& bible);
 private:
-  void * webserver_request;
-  string stylesheet;
-  vector <string> code;
-  bool editor_enabled = false; // Whether to generate CSS for the Bible text editor.
-  bool exports_enabled = false; // Whether to generate CSS for exported Bibles.
+  void * m_webserver_request {nullptr};
+  string m_stylesheet {};
+  vector <string> m_code {};
+  bool editor_enabled {false}; // Whether to generate CSS for the Bible text editor.
+  bool exports_enabled {false}; // Whether to generate CSS for exported Bibles.
   void evaluate (void * database_styles_item);
   void add (void * database_styles_item, bool paragraph, bool keepwithnext);
   void add_exports_styles ();
   void add_editor_styles ();
 };
-
-
-#endif
