@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ bool styles_sheetm_acl (void * webserver_request)
 
 string styles_sheetm (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   string page;
   
@@ -97,21 +97,21 @@ string styles_sheetm (void * webserver_request)
     if (write) database_styles.deleteMarker (name, del);
   }
 
-  vector <string> markerblock;
+  stringstream markerblock;
   map <string, string> markers_names = database_styles.getMarkersAndNames (name);
   for (auto & item : markers_names) {
     string marker = item.first;
     string marker_name = item.second;
     marker_name = translate (marker_name);
-    markerblock.push_back ("<tr>");
-    markerblock.push_back ("<td><a href=\"view?sheet=" + name + "&style=" + marker + "\">" + marker + "</a></td>");
-    markerblock.push_back ("<td>" + marker_name + "</td>");
-    markerblock.push_back ("<td>[<a href=\"?name=" + name + "&delete=" + marker + "\">" + translate("delete") + "]</a></td>");
-    markerblock.push_back ("</tr>");
+    markerblock << "<tr>";
+    markerblock << R"(<td><a href=")" << "view?sheet=" << name << "&style=" << marker << R"(">)"  << marker << "</a></td>";
+    markerblock << "<td>" << marker_name << "</td>";
+    markerblock << R"(<td>[<a href=")" << "?name=" << name << "&delete=" << marker << R"(">)" << translate("delete") << "]</a></td>";
+    markerblock << "</tr>";
   }
-  view.set_variable ("markerblock", filter_string_implode (markerblock, "\n"));
+  view.set_variable ("markerblock", markerblock.str());
   
-  string folder = filter_url_create_root_path (database_logic_databases (), "styles", name);
+  string folder = filter_url_create_root_path ({database_logic_databases (), "styles", name});
   view.set_variable ("folder", folder);
 
   page += view.render ("styles", "sheetm");
