@@ -86,7 +86,7 @@ string styles_view (void * webserver_request)
   
   
   // Whether a style was edited.
-  bool style_is_edited = false;
+  bool style_is_edited { false };
 
   
   // The style's name.
@@ -199,14 +199,14 @@ string styles_view (void * webserver_request)
   if (request->query.count ("subtype")) {
     string s = request->query["subtype"];
     subtype = convert_to_int (s);
-    if (s == "") {
+    if (s.empty()) {
       Dialog_List dialog_list = Dialog_List ("view", translate("Would you like to change the sub type of this style?"), "", "");
       dialog_list.add_query ("sheet", sheet);
       dialog_list.add_query ("style", style);
-      Database_Styles_Item marker_data = database_styles.getMarkerData (sheet, style);
-      int type = marker_data.type;
+      Database_Styles_Item style_data = database_styles.getMarkerData (sheet, style);
+      int type2 = style_data.type;
       for (int i = 0; i < 99; i++) {
-        string text = styles_logic_subtype_text (type, i);
+        string text = styles_logic_subtype_text (type2, i);
         if (text.length () > 2) {
           dialog_list.add_row (text, "subtype", convert_to_string (i));
         }
@@ -263,9 +263,9 @@ string styles_view (void * webserver_request)
       Dialog_List dialog_list = Dialog_List ("view", translate("Would you like to change whether this style is in italics?"), "", "");
       dialog_list.add_query ("sheet", sheet);
       dialog_list.add_query ("style", style);
-      Database_Styles_Item marker_data = database_styles.getMarkerData (sheet, style);
+      Database_Styles_Item style_item = database_styles.getMarkerData (sheet, style);
       int last_value = ooitOn;
-      if (styles_logic_italic_bold_underline_smallcaps_are_full (marker_data.type, marker_data.subtype))
+      if (styles_logic_italic_bold_underline_smallcaps_are_full (style_item.type, style_item.subtype))
         last_value = ooitToggle;
       for (int i = 0; i <= last_value; i++) {
         dialog_list.add_row (styles_logic_off_on_inherit_toggle_text (i), "italic", convert_to_string (i));
@@ -291,9 +291,9 @@ string styles_view (void * webserver_request)
       Dialog_List dialog_list = Dialog_List ("view", translate("Would you like to change whether this style is in bold?"), "", "");
       dialog_list.add_query ("sheet", sheet);
       dialog_list.add_query ("style", style);
-      Database_Styles_Item marker_data = database_styles.getMarkerData (sheet, style);
+      Database_Styles_Item style_data = database_styles.getMarkerData (sheet, style);
       int last_value = ooitOn;
-      if (styles_logic_italic_bold_underline_smallcaps_are_full (marker_data.type, marker_data.subtype))
+      if (styles_logic_italic_bold_underline_smallcaps_are_full (style_data.type, style_data.subtype))
         last_value = ooitToggle;
       for (int i = 0; i <= last_value; i++) {
         dialog_list.add_row (styles_logic_off_on_inherit_toggle_text (i), "bold", convert_to_string (i));
@@ -319,7 +319,7 @@ string styles_view (void * webserver_request)
       Dialog_List dialog_list = Dialog_List ("view", translate("Would you like to change whether this style is underlined?"), "", "");
       dialog_list.add_query ("sheet", sheet);
       dialog_list.add_query ("style", style);
-      Database_Styles_Item marker_data = database_styles.getMarkerData (sheet, style);
+      Database_Styles_Item style_data = database_styles.getMarkerData (sheet, style);
       int last_value = ooitOn;
       if (styles_logic_italic_bold_underline_smallcaps_are_full (type, subtype))
         last_value = ooitToggle;
@@ -347,9 +347,9 @@ string styles_view (void * webserver_request)
       Dialog_List dialog_list = Dialog_List ("view", translate("Would you like to change whether this style is in small caps?"), "", "");
       dialog_list.add_query ("sheet", sheet);
       dialog_list.add_query ("style", style);
-      Database_Styles_Item marker_data = database_styles.getMarkerData (sheet, style);
+      Database_Styles_Item style_data = database_styles.getMarkerData (sheet, style);
       int last_value = ooitOn;
-      if (styles_logic_italic_bold_underline_smallcaps_are_full (marker_data.type, marker_data.subtype))
+      if (styles_logic_italic_bold_underline_smallcaps_are_full (style_data.type, style_data.subtype))
         last_value = ooitToggle;
       for (int i = 0; i <= last_value; i++) {
         dialog_list.add_row (styles_logic_off_on_inherit_toggle_text (i), "smallcaps", convert_to_string (i));
@@ -378,7 +378,7 @@ string styles_view (void * webserver_request)
     }
   }
   view.set_variable ("superscript_value", styles_logic_off_on_inherit_toggle_text (superscript));
-  view.set_variable ("superscript_toggle", convert_to_string (!(bool) superscript));
+  view.set_variable ("superscript_toggle", convert_to_string (!static_cast<bool> (superscript)));
   
 
   // Whether a list of the following paragraph treats are relevant.
@@ -532,44 +532,30 @@ string styles_view (void * webserver_request)
   if (styles_logic_color_is_relevant (type, subtype)) view.enable_zone ("color_relevant");
   
   string color = marker_data.color;
-  if (request->query.count ("textcolor")) {
-    color = request->query["color"];
-    if (color == "") {
-      Dialog_Color dialog_color = Dialog_Color ("view", translate("Please specify a new color"));
-      dialog_color.add_query ("textcolor", "true");
-      dialog_color.add_query ("sheet", sheet);
-      dialog_color.add_query ("style", style);
-      page += dialog_color.run ();
-      return page;
-    } else {
-      if (color.find ("#") == string::npos) color.insert (0, "#");
-      if (color.length () != 7) color = "#000000";
-      if (write) {
-        database_styles.updateColor (sheet, style, color);
-        style_is_edited = true;
-      }
+  if (request->query.count ("fgcolor")) {
+    color = request->query["fgcolor"];
+    if (color.find ("#") == string::npos) color.insert (0, "#");
+    if (color.length () != 7) color = "#000000";
+    if (write) {
+      database_styles.updateColor (sheet, style, color);
+      style_is_edited = true;
+      if (style_is_edited) {};
     }
+    return string();
   }
   view.set_variable ("color", color);
 
   string backgroundcolor = marker_data.backgroundcolor;
-  if (request->query.count ("backgroundcolor")) {
-    backgroundcolor = request->query["color"];
-    if (backgroundcolor == "") {
-      Dialog_Color dialog_color = Dialog_Color ("view", translate("Please specify a new color"));
-      dialog_color.add_query ("backgroundcolor", "true");
-      dialog_color.add_query ("sheet", sheet);
-      dialog_color.add_query ("style", style);
-      page += dialog_color.run ();
-      return page;
-    } else {
-      if (backgroundcolor.find ("#") == string::npos) backgroundcolor.insert (0, "#");
-      if (backgroundcolor.length () != 7) backgroundcolor = "#FFFFFF";
-      if (write) {
-        database_styles.updateBackgroundColor (sheet, style, backgroundcolor);
-        style_is_edited = true;
-      }
+  if (request->query.count ("bgcolor")) {
+    color = request->query["bgcolor"];
+    if (color.find ("#") == string::npos) color.insert (0, "#");
+    if (color.length () != 7) color = "#FFFFFF";
+    if (write) {
+      database_styles.updateBackgroundColor (sheet, style, color);
+      style_is_edited = true;
+      if (style_is_edited) {};
     }
+    return string();
   }
   view.set_variable ("backgroundcolor", backgroundcolor);
 
