@@ -43,7 +43,7 @@ string sync_resources (void * webserver_request)
   if (!sync_logic.security_okay ()) {
     // When the Cloud enforces https, inform the client to upgrade.
     request->response_code = 426;
-    return "";
+    return string();
   }
 
   // If the client's IP address very recently made a prioritized server call,
@@ -108,5 +108,5 @@ string sync_resources (void * webserver_request)
   // Bad request. Delay flood of bad requests.
   this_thread::sleep_for (chrono::seconds (1));
   request->response_code = 400;
-  return "";
+  return string();
 }
