@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,13 +33,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <export/logic.h>
 #include <developer/logic.h>
 #include <setup/logic.h>
+#include <journal/logic.h>
 
 
 // CPU-intensive actions run at night.
 // This keeps the site more responsive during the day.
 
 
-// The order for running the following nightly scripts is important.
+// The order in which the following nightly scripts run is important.
 // Any of those scripts may influence the subsequent ones.
 // The order is such that all information generated is as recent as possible.
 // More important tasks are done first, and the less important ones at the end.
@@ -48,9 +49,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 void timer_index ()
 {
-  int previous_second = -1;
-  int previous_minute = -1;
-  int previous_fraction = -1;
+  int previous_second { -1 };
+  int previous_minute { -1 };
+  int previous_fraction { -1 };
+  [[maybe_unused]] int google_translate_authentication_token_age_minute { 0 };
+  
+#ifdef HAVE_CLOUD
+  // Right after startup, update the Google Translate access token.
+  tasks_logic_queue(GETGOOGLEACCESSTOKEN);
+#endif
+  
   while (config_globals_webserver_running) {
 
     try {
@@ -63,11 +71,11 @@ void timer_index ()
       if (!config_globals_data_initialized) continue;
       
       // The current time, localized.
-      int local_seconds = filter_date_local_seconds (filter_date_seconds_since_epoch ());
-      int second = filter_date_numerical_second (local_seconds);
-      int minute = filter_date_numerical_minute (local_seconds);
-      int hour = filter_date_numerical_hour (local_seconds);
-      int weekday = filter_date_numerical_week_day (local_seconds);
+      int local_seconds = filter::date::local_seconds (filter::date::seconds_since_epoch ());
+      int second = filter::date::numerical_second (local_seconds);
+      int minute = filter::date::numerical_minute (local_seconds);
+      int hour = filter::date::numerical_hour (local_seconds);
+      [[maybe_unused]] int weekday = filter::date::numerical_week_day (local_seconds);
       
       // Run once per second.
       if (second == previous_second) continue;
@@ -79,6 +87,8 @@ void timer_index ()
       // Every second:
       // Check whether client sends/receives Bibles and Consultation Notes and other stuff.
       sendreceive_queue_sync (minute, second);
+      // Log any connections that have come in.
+      developer_logic_log_network_write ();
 
       // Run the part below every so many seconds.
       int fraction = second / 5;
@@ -89,7 +99,7 @@ void timer_index ()
       // Run the part below once per minute.
       if (minute == previous_minute) continue;
       previous_minute = minute;
-      
+
       // Every minute send out queued email.
       tasks_logic_queue (SENDEMAIL);
 
@@ -101,14 +111,14 @@ void timer_index ()
       }
 #endif
 
-      // At the nineth minute after every full hour rotate the journal.
+      // At the ninth minute after every full hour rotate the journal.
       // The nine is chosen, because the journal rotation will summarize the send/receive messages.
       // In case send/receive happens every five minutes, it is expected that under normal circumstances
       // the whole process of sending/receivning will be over, so summarization can then be done.
       if (minute == 9) tasks_logic_queue (ROTATEJOURNAL);
       
       // Sending and receiving Bibles to and from the git repository.
-      // On a production website running on an inexpensive virtual private server
+      // On a production website running on an inexpensive virtual private server,
       // with 512 Mbyte of memory and a fast network connection,
       // sending and receiving two Bibles takes more than 15 minutes when there are many changes.
       bool sendreceive = ((hour == 0) && (minute == 5));
@@ -134,13 +144,26 @@ void timer_index ()
         checks_logic_start_all ();
       }
 #endif
-      
+
       // Database maintenance and trimming.
       // It takes a few minutes on a production machine.
       if ((hour == 0) && (minute == 50)) {
         tasks_logic_queue (MAINTAINDATABASE);
       }
-      
+
+#ifdef HAVE_CLOUD
+      // File cache trimming.
+      // https://github.com/bibledit/cloud/issues/364
+      // This used to be done once a day, and the trimming left files for multiple days.
+      // This way of doing things led to a full disk when disk space was tight.
+      // The new way of trimming on the Cloud is to do the trimming every hour.
+      // And to leave files in the files cache for only a couple of hours.
+      if (minute == 10) {
+        tasks_logic_queue (TRIMCACHES);
+      }
+
+#endif
+
 #ifdef HAVE_CLOUD
       // Export the Bibles to the various output formats.
       // This may take an hour on a production machine.
@@ -150,7 +173,7 @@ void timer_index ()
       }
 #endif
       
-      // Delete temporal files older than a few days.
+      // Delete expired temporal files.
       if ((hour == 2) && (minute == 0)) {
         tasks_logic_queue (CLEANTMPFILES);
       }
@@ -213,6 +236,16 @@ void timer_index ()
       }
 #endif
 
+      
+#ifdef HAVE_CLOUD
+      // In the free Indonesian Cloud configuration, expire free users after so many days.
+      if (config_logic_indonesian_cloud_free ()) {
+        if ((hour == 3) && (minute == 10)) {
+          tasks_logic_queue (EXPIREINDONESIANFREEUSERS);
+        }
+      }
+#endif
+
 	
 #ifdef HAVE_CLOUD
       // Update SWORD modules and other web resources once a week.
@@ -238,9 +271,17 @@ void timer_index ()
       }
 #endif
 
-      // Suppress compiler warning on client.
-      (void) weekday;
-      
+#ifdef HAVE_CLOUD
+      // Keep the Google Translate access token current.
+      // From experiments it appears that the token is valid for one hour.
+      // So before the hour has expired, renew the token again.
+      google_translate_authentication_token_age_minute++;
+      if (google_translate_authentication_token_age_minute > 50) {
+        tasks_logic_queue(GETGOOGLEACCESSTOKEN);
+        google_translate_authentication_token_age_minute = 0;
+      }
+#endif
+
     } catch (exception & e) {
       Database_Logs::log (e.what ());
     } catch (exception * e) {
