@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ bool webbible_search_acl (void * webserver_request)
 
 string webbible_search (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   Assets_View view;
@@ -82,7 +82,7 @@ string webbible_search (void * webserver_request)
   view.set_variable ("hitCount", convert_to_string (passages.size ()));
   
   
-  string hitsblock;
+  stringstream hitsblock;
   
   
   // Go through the search hits.
@@ -90,11 +90,11 @@ string webbible_search (void * webserver_request)
     
     
     // Get the passage of this search hit.
-    if (passage.book == 0) continue;
-    string bible = passage.bible;
-    int book = passage.book;
-    int chapter = passage.chapter;
-    string verse = passage.verse;
+    if (passage.m_book == 0) continue;
+    string bible = passage.m_bible;
+    int book = passage.m_book;
+    int chapter = passage.m_chapter;
+    string verse = passage.m_verse;
     
     
     // The title.
@@ -103,11 +103,11 @@ string webbible_search (void * webserver_request)
     
     
     // The URL.
-    string url = "/exports/" + bible + "/web/" + filter_url_html_file_name_bible ("", book, chapter);
+    string url = "/exports/" + bible + "/web/" + filter_url_html_file_name_bible (string(), book, chapter);
     
     
     // Output title and URL.
-    hitsblock.append ("<p style=\"margin-top: 0.75em; margin-bottom: 0em\"><a href=\"" + url + "\">" + title + "</a></p>\n");
+    hitsblock << "<p style=" << quoted ("margin-top: 0.75em; margin-bottom: 0em") << "><a href=" << quoted (url) << ">" << title << "</a></p>" << endl;
     
     
     // The excerpt.
@@ -118,12 +118,12 @@ string webbible_search (void * webserver_request)
       string markedLine = filter_string_markup_words (queryWords, line);
       if (markedLine != line) {
         // Store this bit of the excerpt.
-        hitsblock.append ("<p style=\"margin-top: 0em; margin-bottom: 0em\">" + markedLine + "</p>\n");
+        hitsblock << "<p style=" << quoted ("margin-top: 0em; margin-bottom: 0em") << ">" << markedLine << "</p>" << endl;
       }
     }
   }
   
-  view.set_variable ("hitsblock", hitsblock);
+  view.set_variable ("hitsblock", hitsblock.str());
   
   return view.render ("webbb", "search");
 }
