@@ -17,6 +17,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
+#include <webserver/webserver.h>
 #include <webserver/http.h>
 #include <bootstrap/bootstrap.h>
 #include <webserver/request.h>
@@ -41,6 +42,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #endif
 
 
+// Internal function declarations.
+int get_line (int sock, char *buf, int size);
+void webserver_process_request (int connfd, string clientaddress);
+void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_context client_fd);
+
+
 // Gets a line from a socket.
 // The line may end with a newline, a carriage return, or a CR-LF combination.
 // It terminates the string read with a null character.
@@ -58,7 +65,7 @@ int get_line (int sock, char *buf, int size)
   char character = '\0';
   int n = 0;
   while ((i < size - 1) && (character != '\n')) {
-    n = (int) recv (sock, &character, 1, 0);
+    n = static_cast<int> (recv (sock, &character, 1, 0));
     if (n > 0) {
       if (character == '\r') {
         /*
@@ -67,7 +74,7 @@ int get_line (int sock, char *buf, int size)
         // So it's safe to throw the \r away, as we're sure the \n follows.
         continue;
         */
-        n = (int) recv (sock, &character, 1, MSG_PEEK);
+        n = static_cast<int> (recv (sock, &character, 1, MSG_PEEK));
         if ((n > 0) && (character == '\n')) {
           recv (sock, &character, 1, 0);
         } else {
@@ -135,7 +142,7 @@ void webserver_process_request (int connfd, string clientaddress)
           bool done_reading = false;
           int total_bytes_read = 0;
           do {
-            bytes_read = (int)recv(connfd, buffer, BUFFERSIZE, 0);
+            bytes_read = static_cast<int> (recv(connfd, buffer, BUFFERSIZE, 0));
             for (int i = 0; i < bytes_read; i++) {
               postdata += buffer [i];
             }
@@ -178,18 +185,18 @@ void webserver_process_request (int connfd, string clientaddress)
             open
 #endif
             (request.stream_file.c_str(), O_RDONLY);
-            unsigned char buffer [1024];
+            unsigned char streambuffer [1024];
             int bytecount;
             do {
-              bytecount = (int)
+              bytecount = static_cast<int> (
 #ifdef HAVE_WINDOWS
               _read
 #else
               read
 #endif
-              (filefd, buffer, 1024);
+              (filefd, streambuffer, 1024));
               if (bytecount > 0) {
-                [[maybe_unused]] auto sendbytes = (int)send (connfd, (const char *)buffer, bytecount, 0);
+                [[maybe_unused]] auto sendbytes = send (connfd, reinterpret_cast<const char *> (streambuffer), static_cast<size_t>(bytecount), 0);
               }
             }
             while (bytecount > 0);
@@ -255,7 +262,7 @@ void http_server ()
   // The function is used to allow the local address to  be reused
   // when the server is restarted before the required wait time expires.
   int optval = 1;
-  int result = setsockopt (listenfd, SOL_SOCKET, SO_REUSEADDR, (const char *) &optval, sizeof (int));
+  int result = setsockopt (listenfd, SOL_SOCKET, SO_REUSEADDR, reinterpret_cast<const char *> ( &optval), sizeof (int));
   if (result != 0) {
     string error = "Error setting socket option: ";
     error.append (strerror (errno));
@@ -280,9 +287,9 @@ void http_server ()
   serveraddr.sin6_flowinfo = 0;
   serveraddr.sin6_family = AF_INET6;
   serveraddr.sin6_addr = in6addr_any;
-  serveraddr.sin6_port = htons (convert_to_int (config_logic_http_network_port ()));
+  serveraddr.sin6_port = htons (static_cast<uint16_t>(convert_to_int (config_logic_http_network_port ())));
 #endif
-  result = mybind (listenfd, (struct sockaddr *) &serveraddr, sizeof (serveraddr));
+  result = mybind (listenfd, reinterpret_cast<struct sockaddr *>(&serveraddr), sizeof (serveraddr));
   if (result != 0) {
     string error = "Error binding server to socket: ";
     error.append (strerror (errno));
@@ -308,7 +315,7 @@ void http_server ()
     // Socket and file descriptor for the client connection.
     struct sockaddr_in6 clientaddr6;
     socklen_t clientlen = sizeof (clientaddr6);
-    int connfd = accept (listenfd, (struct sockaddr *)&clientaddr6, &clientlen);
+    int connfd = accept (listenfd, reinterpret_cast<struct sockaddr *>(&clientaddr6), &clientlen);
     if (connfd > 0) {
 
       // Socket receive timeout, plain http.
@@ -501,7 +508,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
       // Get client's remote IPv4 address in dotted notation and put it in the webserver request object.
       struct sockaddr_in addr;
       socklen_t addr_size = sizeof(struct sockaddr_in);
-      getpeername (client_fd.fd, (struct sockaddr *)&addr, &addr_size);
+      getpeername (client_fd.fd, reinterpret_cast<struct sockaddr *>(&addr), &addr_size);
       char remote_address [256];
       inet_ntop (AF_INET, &addr.sin_addr.s_addr, remote_address, sizeof (remote_address));
       request.remote_address = remote_address;
@@ -554,7 +561,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         if (ret == 0) header_parsed = false; // 0: EOF
         if (ret < 0) connection_healthy = false;
         if (connection_healthy && header_parsed) {
-          char c = buffer [0];
+          char c = static_cast <char> (buffer [0]);
           // The request contains a carriage return (\r) and a new line feed (\n).
           // The traditional order of this is \r\n.
           // Therefore when a \r is encountered, just disregard it.
@@ -588,7 +595,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           if (ret == 0) done_reading = true; // 0: EOF
           if (ret < 0) connection_healthy = false;
           if (connection_healthy && !done_reading) {
-            char c = buffer [0];
+            char c = static_cast <char> (buffer [0]);
             postdata += c;
             total_bytes_read ++;
           }
@@ -610,7 +617,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
       
       // Write the response to the browser.
       const char * output = request.reply.c_str();
-      const unsigned char * buf = (const unsigned char *) output;
+      const unsigned char * buf = reinterpret_cast<const unsigned char *>(output);
       // The C function strlen () fails on null characters in the reply, so take string::size()
       size_t len = request.reply.size ();
       while (connection_healthy && (len > 0)) {
@@ -624,7 +631,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         ret = mbedtls_ssl_write (&ssl, buf, len);
         if (ret > 0) {
           buf += ret;
-          len -= ret;
+          len -= static_cast <size_t> (ret);
         } else {
           // When it returns MBEDTLS_ERR_SSL_WANT_WRITE/READ,
           // it must be called later with the *same* arguments,
@@ -650,16 +657,16 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         unsigned char buffer [1024];
         int bytecount;
         do {
-          bytecount = (int)
+          bytecount = static_cast<int>(
 #ifdef HAVE_WINDOWS
           _read
 #else
           read
 #endif
-          (filefd, buffer, 1024);
-          int len = bytecount;
-          const unsigned char * buf = (const unsigned char *) &buffer;
-          while (connection_healthy && (len > 0)) {
+          (filefd, buffer, 1024));
+          int remaining_length = bytecount;
+          const unsigned char * buffer_ptr = reinterpret_cast<const unsigned char *>(&buffer);
+          while (connection_healthy && (remaining_length > 0)) {
             // Function
             // int ret = mbedtls_ssl_write (&ssl, buf, len)
             // will do partial writes in some cases.
@@ -667,10 +674,10 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
             // the function must be called again with updated arguments:
             // buf + ret, len - ret
             // until it returns a value equal to the last 'len' argument.
-            ret = mbedtls_ssl_write (&ssl, buf, len);
+            ret = mbedtls_ssl_write (&ssl, buffer_ptr, static_cast<size_t>(remaining_length));
             if (ret > 0) {
-              buf += ret;
-              len -= ret;
+              buffer_ptr += ret;
+              remaining_length -= ret;
             } else {
               // When it returns MBEDTLS_ERR_SSL_WANT_WRITE/READ,
               // it must be called later with the *same* arguments,
@@ -698,6 +705,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
           filter_url_display_mbed_tls_error (ret, NULL, true);
           connection_healthy = false;
+          if (connection_healthy) {}; // Suppress static analyzer warning about unused code.
           break;
         }
       }
@@ -780,7 +788,7 @@ void https_server ()
 
   // Seed the random number generator.
   const char *pers = "Cloud";
-  ret = mbedtls_ctr_drbg_seed( &ctr_drbg, mbedtls_entropy_func, &entropy, (const unsigned char *) pers, strlen (pers));
+  ret = mbedtls_ctr_drbg_seed( &ctr_drbg, mbedtls_entropy_func, &entropy, reinterpret_cast<const unsigned char *> (pers), strlen (pers));
   if (ret != 0) {
     filter_url_display_mbed_tls_error (ret, NULL, true);
     return;
